@@ -152,10 +152,8 @@ function logo_migrer_en_base($objet, $time_limit) {
 
 	$dir_logos_erreurs = sous_repertoire(_DIR_IMG, 'logo_erreurs');
 	$dir_logos = sous_repertoire(_DIR_IMG, 'logo');
-	$formats_logos = ['jpg', 'png', 'svg', 'gif'];
-	if (isset($GLOBALS['formats_logos'])) {
-		$formats_logos = $GLOBALS['formats_logos'];
-	}
+	include_spip('inc/filtres_images_lib_mini');
+	$formats_logos = _image_extensions_logos(['objet' => $objet]);
 
 
 	$trouver_table = charger_fonction('trouver_table', 'base');
