@@ -7,7 +7,6 @@
  *  Arnaud Martin, Antoine Pitrou, Philippe Rivière, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribué sous licence GNU/GPL.     *
- *  Pour plus de détails voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
 /**
@@ -115,6 +114,28 @@ function rubrique_inserer($id_parent, $set = null) {
 	propager_les_secteurs();
 	calculer_langues_rubriques();
 
+	// Appeler une notification
+	if ($notifications = charger_fonction('notifications', 'inc')) {
+		$notifications(
+			'rubrique_inserer',
+			$id_rubrique,
+			[
+				'id_parent' => $id_parent,
+				'champs' => $champs,
+			]
+		);
+		$notifications(
+			'objet_inserer',
+			$id_rubrique,
+			[
+				'objet' => 'rubrique',
+				'id_objet' => $id_rubrique,
+				'id_parent' => $id_parent,
+				'champs' => $champs,
+			]
+		);
+	}
+	
 	return $id_rubrique;
 }
 
@@ -128,7 +149,7 @@ function rubrique_inserer($id_parent, $set = null) {
  * @return bool|string
  *     - false  : Aucune modification, aucun champ n'est à modifier
  *     - chaîne vide : Vide si tout s'est bien passé
- *     - chaîne : Texte d'un message d'erreur
+ *     - chaîne : texte d'un message d'erreur
  */
 function rubrique_modifier($id_rubrique, $set = null) {
 	include_spip('inc/autoriser');
@@ -234,7 +255,7 @@ function editer_rubrique_breves($id_rubrique, $id_parent, $c = []) {
  * @global array $GLOBALS ['visiteur_session']
  * @return string
  *     Chaîne vide : aucune erreur
- *     Chaîne : Texte du message d'erreur
+ *     Chaîne : texte du message d'erreur
  */
 function rubrique_instituer($id_rubrique, $c) {
 	// traitement de la rubrique parente
@@ -278,6 +299,28 @@ function rubrique_instituer($id_rubrique, $c) {
 				}
 
 				calculer_langues_rubriques();
+				
+				// Appeler une notification
+				if ($notifications = charger_fonction('notifications', 'inc')) {
+					$notifications(
+						'rubrique_instituer',
+						$id_rubrique,
+						[
+							'statut_ancien' => $statut_ancien,
+							'id_parent_ancien' => $old_parent,
+						]
+					);
+					$notifications(
+						'objet_instituer',
+						$id_rubrique,
+						[
+							'objet' => 'rubrique',
+							'id_objet' => $id_rubrique,
+							'statut_ancien' => $statut_ancien,
+							'id_parent_ancien' => $old_parent,
+						]
+					);
+				}
 			}
 		}
 	}
