@@ -242,14 +242,7 @@ function envoyer_inscription_dist($desc, $nom, $mode, $options = []) {
 	$contexte = array_merge($desc, $options);
 	$contexte['nom'] = $nom;
 	$contexte['mode'] = $mode;
-	$contexte['url_confirm'] = generer_url_action('confirmer_inscription', '', true, true);
-	$contexte['url_confirm'] = parametre_url($contexte['url_confirm'], 'email', $desc['email']);
-	$contexte['url_confirm'] = parametre_url($contexte['url_confirm'], 'jeton', $desc['jeton']);
-	// S'il y a l'option redirect, on l'ajoute directement ici
-	if (isset($options['redirect'])) {
-		$contexte['url_confirm'] = parametre_url($contexte['url_confirm'], 'redirect', $options['redirect']);
-	}
-	
+
 	$token = auteur_attribuer_jeton($desc['id_auteur']);
 
 	$contexte['url_reset'] = generer_url_public('spip_pass', "p=$token", false, false );
