@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/aide-aide?lang_cible=it
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// R
 	'raccourcis' => 'Scorciatoie tipografiche',
@@ -20,5 +16,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'raccourcis_note' => 'Note a piè di pagina',
 	'raccourcis_resume' => 'In sintesi',
 	'raccourcis_simple' => 'Formattazione semplice',
-	'raccourcis_tableau' => 'Tabelle'
-);
+	'raccourcis_tableau' => 'Tabelle',
+];
