@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/aide-aide?lang_cible=pt_br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// R
 	'raccourcis' => 'Atalhos tipográficos',
@@ -20,5 +16,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'raccourcis_note' => 'Notas de pé de página',
 	'raccourcis_resume' => 'Resumo',
 	'raccourcis_simple' => 'Formatação simples',
-	'raccourcis_tableau' => 'Tabelas'
-);
+	'raccourcis_tableau' => 'Tabelas',
+];
