@@ -3,14 +3,10 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-aide?lang_cible=ar
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'aide_description' => 'يتيح هذا الملحق إدخال تعليمات فورية على SPIP يُدلّ اليها برمز معين. يمكن تعميم هذه التعليمات على ملاحق أخرى.',
 	'aide_nom' => 'تعليمات SPIP',
-	'aide_slogan' => 'تعليمات SPIP الفورية'
-);
+	'aide_slogan' => 'تعليمات SPIP الفورية',
+];
