@@ -3,14 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-archiviste?lang_cible=pt_br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
-
+return [
 	// A
 	'archiviste_description' => 'Permite comprimir ou expandir arquivos Zip, Tar, ...',
 	'archiviste_nom' => 'Arquivista',
 	'archiviste_slogan' => 'Gerenciar arquivos compactados'
-);
+];
