@@ -7,7 +7,6 @@
  *  Arnaud Martin, Antoine Pitrou, Philippe Rivière, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribué sous licence GNU/GPL.     *
- *  Pour plus de détails voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
 /**
@@ -32,10 +31,17 @@ if (!defined('_ECRIRE_INC_VERSION')) {
  * @param bool $phpauth
  * @return array|bool
  */
-function auth_spip_dist($login, $pass, $serveur = '', $phpauth = false) {
+function auth_spip_dist(
+	$login,
+	#[\SensitiveParameter]
+	$pass,
+	$serveur = '',
+	$phpauth = false,
+	string $fichier_cles = ''
+) {
 
 	// retrouver le login
-	$login = auth_spip_retrouver_login($login);
+	$login = auth_spip_retrouver_login($login, $serveur);
 	// login inconnu, n'allons pas plus loin
 	if (!$login) {
 		return [];
@@ -68,8 +74,7 @@ function auth_spip_dist($login, $pass, $serveur = '', $phpauth = false) {
 		return [];
 	}
 
-	include_spip('inc/chiffrer');
-	$cles = SpipCles::instance();
+	$cles = SpipCles::instance($fichier_cles);
 	$secret = $cles->getSecretAuth();
 
 	$hash = null;
@@ -115,11 +120,11 @@ function auth_spip_dist($login, $pass, $serveur = '', $phpauth = false) {
 					else {
 						spip_log("Echec restauration des cles : verifier les droits d'ecriture ?", 'auth' . _LOG_ERREUR);
 						// et on echoue car on ne veut pas que la situation reste telle quelle
-						raler_fichier(_DIR_ETC . 'cles.php');
+						raler_fichier($fichier_cles ?: _DIR_ETC . 'cles.php');
 					}
 				}
 				else {
-					spip_log('Pas de cle secrete disponible (fichier config/cle.php absent ?) mais le backup du webmestre #' . $row['id_auteur'] . " n'est pas valide", 'auth' . _LOG_ERREUR);
+					spip_log('Pas de cle secrete disponible (fichier ' . ($fichier_cles ?: 'config/cle.php') . ' absent ?) mais le backup du webmestre #' . $row['id_auteur'] . " n'est pas valide", 'auth' . _LOG_ERREUR);
 					sql_updateq('spip_auteurs', ['backup_cles' => ''], 'id_auteur=' . intval($row['id_auteur']));
 				}
 			}
@@ -159,6 +164,14 @@ function auth_spip_dist($login, $pass, $serveur = '', $phpauth = false) {
 				'alea_futur' => sql_quote(creer_uniqid(), $serveur, 'text'), // @deprecated 4.1
 				'pass' => sql_quote($pass_hash_next, $serveur, 'text'),
 			];
+
+			// regenerer un htpass si on a active/desactive le plugin htpasswd
+			// et/ou que l'algo a change - pour etre certain de toujours utiliser le bon algo
+			$htpass = generer_htpass($pass);
+			if (strlen($htpass) !== strlen($row['htpass'])) {
+				$set['htpass'] = sql_quote($htpass, $serveur, 'text');
+			}
+
 			// a chaque login de webmestre : sauvegarde chiffree des clés du site (avec les pass du webmestre)
 			if ($auteur_peut_sauver_cles) {
 				$set['backup_cles'] = sql_quote($cles->backup($pass), $serveur, 'text');
@@ -175,6 +188,12 @@ function auth_spip_dist($login, $pass, $serveur = '', $phpauth = false) {
 				[],
 				$serveur
 			);
+
+			// si on a change le htpass car changement d'algo, regenerer les fichiers htpasswd
+			// sauf si connexion distante
+			if (isset($set['htpass']) && empty($serveur)) {
+				ecrire_acces();
+			}
 		}
 
 		// En profiter pour verifier la securite de tmp/
@@ -199,7 +218,6 @@ function auth_spip_dist($login, $pass, $serveur = '', $phpauth = false) {
  * @return bool
  */
 function auth_spip_initialiser_secret(bool $force = false): bool {
-	include_spip('inc/chiffrer');
 	$cles = SpipCles::instance();
 	$secret = $cles->getSecretAuth();
 
@@ -242,14 +260,14 @@ function auth_spip_formulaire_login($flux) {
 	// javascript qui gere la securite du login en evitant de faire circuler le pass en clair
 	$js = file_get_contents(find_in_path('prive/javascript/login.js'));
 	$flux['data'] .=
-		  '<script type="text/javascript">/*<![CDATA[*/'
+		  '<script>'
 		. "$js\n"
 		. "var login_info={'login':'" . $flux['args']['contexte']['var_login'] . "',"
 		. "'page_auteur': '" . generer_url_public('informer_auteur') . "',"
 		. "'informe_auteur_en_cours':false,"
 		. "'attente_informe':0};"
 		. "jQuery(function(){jQuery('#var_login').change(actualise_auteur);});"
-		. '/*]]>*/</script>';
+		. '</script>';
 
 	return $flux;
 }
@@ -429,7 +447,13 @@ function auth_spip_autoriser_modifier_pass(string $serveur = ''): bool {
  * @return string
  *  message d'erreur si login non valide, chaine vide sinon
  */
-function auth_spip_verifier_pass($login, $new_pass, $id_auteur = 0, $serveur = '') {
+function auth_spip_verifier_pass(
+	$login,
+	#[\SensitiveParameter]
+	$new_pass,
+	$id_auteur = 0,
+	$serveur = ''
+) {
 	// login et mot de passe
 	if (strlen($new_pass) < _PASS_LONGUEUR_MINI) {
 		return _T('info_passe_trop_court_car_pluriel', ['nb' => _PASS_LONGUEUR_MINI]);
@@ -448,7 +472,13 @@ function auth_spip_verifier_pass($login, $new_pass, $id_auteur = 0, $serveur = '
  * @param string $serveur
  * @return bool
  */
-function auth_spip_modifier_pass($login, $new_pass, $id_auteur, $serveur = '') {
+function auth_spip_modifier_pass(
+	$login,
+	#[\SensitiveParameter]
+	$new_pass,
+	$id_auteur,
+	$serveur = ''
+) {
 	if (is_null($new_pass) or auth_spip_verifier_pass($login, $new_pass, $id_auteur, $serveur) != '') {
 		return false;
 	}
@@ -460,7 +490,6 @@ function auth_spip_modifier_pass($login, $new_pass, $id_auteur, $serveur = '') {
 		return false;
 	}
 
-	include_spip('inc/chiffrer');
 	$cles = SpipCles::instance();
 	$secret = $cles->getSecretAuth();
 	if (!$secret) {
