@@ -88,7 +88,7 @@ function generer_generer_url_arg($type, $p, $_id) {
 				"quete_meta('dir_img', $s) . \n\t" .
 				"quete_fichier($_id,$s)";
 		}
-		$s = ", '', '', $s, quete_meta('type_urls', $s)";
+		$s = ", '', '', true, quete_meta('type_urls', $s), $s";
 	} else {
 		$s = ", '', '', true";
 	}
