@@ -3,14 +3,10 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/bigup-paquet-xml-bigup?lang_cible=ar
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// B
-	'bigup_description' => '',
+	'bigup_description' => 'تنزيل المستندات بالسحب والرمي',
 	'bigup_nom' => 'تحميل كبير',
-	'bigup_slogan' => 'تحميل الملفات مهما كان حجمها'
-);
+	'bigup_slogan' => 'تحميل الملفات مهما كان حجمها',
+];
