@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/compagnon?lang_cible=fr_tu
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// B
 	'bouton_tout_compris' => 'Masquer tous les messages du compagnon',
@@ -73,5 +69,5 @@ Souhaites-tu réinitialiser ces messages ?',
 
 	// T
 	'titre_compagnon' => 'Le Compagnon',
-	'titre_page_configurer_compagnon' => 'Configurer le Compagnon'
-);
+	'titre_page_configurer_compagnon' => 'Configurer le Compagnon',
+];
