@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/compagnon?lang_cible=uk
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// B
 	'bouton_tout_compris' => 'Сховати всі повідомлення плагіну',
@@ -63,5 +59,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 
 	// T
 	'titre_compagnon' => '„Помічник”',
-	'titre_page_configurer_compagnon' => 'Налаштування „Помічника”'
-);
+	'titre_page_configurer_compagnon' => 'Налаштування „Помічника”',
+];
