@@ -3,14 +3,10 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compagnon?lang_cible=de
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// C
 	'compagnon_description' => 'Der Begleiter hilft neuen Benutzern bei ihren ersten Schritten im SPIP Redaktionssystem.',
 	'compagnon_nom' => 'Begleiter',
-	'compagnon_slogan' => 'Assistent für die ersten Schritte mit SPIP'
-);
+	'compagnon_slogan' => 'Assistent für die ersten Schritte mit SPIP',
+];
