@@ -3,14 +3,10 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compagnon?lang_cible=eo
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// C
 	'compagnon_description' => 'La kompano proponas helpon por uzantoj dum liaj unuaj vizitoj al SPIP privata spaco.',
 	'compagnon_nom' => 'Kompano',
-	'compagnon_slogan' => 'Helpanto por SPIP-komencantoj'
-);
+	'compagnon_slogan' => 'Helpanto por SPIP-komencantoj',
+];
