@@ -3,14 +3,10 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compagnon?lang_cible=es
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// C
 	'compagnon_description' => 'El compañero ofrece ayuda a los usuarios durante su primera visita al espacio privado de SPIP.',
 	'compagnon_nom' => 'Compañero',
-	'compagnon_slogan' => 'Asistente para dar los primeros pasos con SPIP'
-);
+	'compagnon_slogan' => 'Asistente para dar los primeros pasos con SPIP',
+];
