@@ -3,15 +3,11 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compagnon?lang_cible=fr_tu
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// C
 	'compagnon_description' => 'Le compagnon offre une aide aux utilisateurs
 		lors de leur première visite dans l’espace privé de SPIP.',
 	'compagnon_nom' => 'Compagnon',
-	'compagnon_slogan' => 'Assistant de premiers pas avec SPIP'
-);
+	'compagnon_slogan' => 'Assistant de premiers pas avec SPIP',
+];
