@@ -3,14 +3,10 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compagnon?lang_cible=ja
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// C
 	'compagnon_description' => '初めてSPIPの管理エリアをご訪問する時、仲間さんは、援助を提供してくださいます。',
 	'compagnon_nom' => '仲間さん',
-	'compagnon_slogan' => 'SPIPを使用するように、最初のステップウィザードです。'
-);
+	'compagnon_slogan' => 'SPIPを使用するように、最初のステップウィザードです。',
+];
