@@ -3,14 +3,10 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compagnon?lang_cible=lb
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// C
 	'compagnon_description' => 'De Compagnon bitt de Benotzer Hëllef beim éischte Benotze vum privaten Deel vu SPIP.',
 	'compagnon_nom' => 'Compagnon',
-	'compagnon_slogan' => 'Assistent fir déi éischt Schrëtt mat SPIP'
-);
+	'compagnon_slogan' => 'Assistent fir déi éischt Schrëtt mat SPIP',
+];
