@@ -3,14 +3,10 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compagnon?lang_cible=pt
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// C
 	'compagnon_description' => 'O guia oferece assistência aos utilizadores durante a sua primeira visita à área privada de SPIP.', # MODIF
 	'compagnon_nom' => 'Guia',
-	'compagnon_slogan' => 'Assistente de iniciação a SPIP'
-);
+	'compagnon_slogan' => 'Assistente de iniciação a SPIP',
+];
