@@ -3,15 +3,11 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compagnon?lang_cible=sk
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// C
 	'compagnon_description' => 'Compagnon ponúka pomoc používateľom 
 		pri ich prvej návšteve v súkromnej zóne SPIPu.',
 	'compagnon_nom' => 'Compagnon',
-	'compagnon_slogan' => 'Sprievodca pri prvých krokoch so SPIPom'
-);
+	'compagnon_slogan' => 'Sprievodca pri prvých krokoch so SPIPom',
+];
