@@ -3,14 +3,10 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compagnon?lang_cible=uk
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// C
 	'compagnon_description' => 'Плагін виводить довідку про систему управління при першому вході користувача до адміністративної частини.',
 	'compagnon_nom' => 'Помічник (Companion)',
-	'compagnon_slogan' => 'Допомога на початку роботи зі SPIP'
-);
+	'compagnon_slogan' => 'Допомога на початку роботи зі SPIP',
+];
