@@ -98,16 +98,11 @@ function minifier_css($contenu, $options = '') {
 		$contenu = preg_replace("/\b0+\.(\d+(r?em|vh|vw))/ims", '.$1', $contenu);
 		// supprimer les declarations vides
 		$contenu = preg_replace(',(^|})([^{}]*){},Ums', '$1', $contenu);
-		// supprimer l'unité quand la valeur est zéro (sauf pour % car casse les @keyframes cf https://core.spip.net/issues/3128 et sauf pour les chaînes en base64 cf https://core.spip.net/issues/3991)
-		$contenu = preg_replace("/([^0-9.]\b0)(em|px|pt|rem|ex|pc|vh|vw|vmin|vmax|cm|mm|in|ch)\b/ms", '$1', $contenu);
 
 		// renommer les couleurs par leurs versions courtes quand c'est possible
+		// mais on introduit pas de nouvelles couleurs en #xx car si c'est dans un svg url encodé ça casse
 		$colors = [
 			'source' => [
-				'black',
-				'fuchsia',
-				'white',
-				'yellow',
 				'#800000',
 				'#ffa500',
 				'#808000',
@@ -120,10 +115,6 @@ function minifier_css($contenu, $options = '') {
 				'#f00'
 			],
 			'replace' => [
-				'#000',
-				'#F0F',
-				'#FFF',
-				'#FF0',
 				'maroon',
 				'orange',
 				'olive',
