@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/compresseur?lang_cible=ast
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// E
 	'explication_url_statique_ressources' => 'Una URL que permite sirvir los ficheros estáticos (imáxenes, JS…) ensin cookie. Polo xeneral, un sub-dominiu alternativu que tamién apunta al sitiu.',
@@ -25,5 +21,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	// T
 	'texte_compacter_avertissement' => 'Cuida de nun activar estes opciones mientres se desendolca’l sitiu: los elementos compautaos pierden la visibilidá.',
 	'texte_compacter_script_css' => 'SPIP pue compautar los scripts JavaScript y les fueyes d’estilu CSS, pa guardalos como archivos estáticos; esto acelera l’amosamientu del sitiu.',
-	'titre_compacter_script_css' => 'Compautación de los scripts y CSS'
-);
+	'titre_compacter_script_css' => 'Compautación de los scripts y CSS',
+];
