@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/compresseur?lang_cible=co
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// I
 	'info_compresseur_titre' => 'Uttimizazione è cumpressione',
@@ -18,5 +14,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'texte_compacter_avertissement' => 'Attenti à ùn attivà st’opzioni durante u sviluppu di u situ : L’elementi cumpressi ùn diventenu propriu più leghjitoghji.',
 	'texte_compacter_script_css' => 'SPIP pò cumpressà i scripts javascript è e foglie di stile CSS, da arregitrà li in i schedari stàtichi; 
 	cusì u situ diventa più veloce.',
-	'titre_compacter_script_css' => 'Cumpressione di i scripts è CSS'
-);
+	'titre_compacter_script_css' => 'Cumpressione di i scripts è CSS',
+];
