@@ -3,12 +3,8 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/compresseur?lang_cible=he
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// I
-	'info_compresseur_titre' => 'אופטימציה וכיווץ'
-);
+	'info_compresseur_titre' => 'אופטימציה וכיווץ',
+];
