@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/compresseur?lang_cible=ja
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// E
 	'explication_url_statique_ressources' => 'クーキーを使用せずに静的ファイル（画像、JS...）を提供できるURL。通常、サイトにも向ける代替サブドメインです。',
@@ -25,5 +21,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	// T
 	'texte_compacter_avertissement' => 'サイトの開発中にこれらのオプションを有効にしないように注意してください： 圧縮された要素はすべて読めなくなります。',
 	'texte_compacter_script_css' => 'SPIPは、静的ファイルに保存するために、JavaScriptスクリプトとCSSスタイルシートを圧縮することが出来ます。これにより、サイトの表示速度が上がります。',
-	'titre_compacter_script_css' => 'スクリプトとCSSの圧縮'
-);
+	'titre_compacter_script_css' => 'スクリプトとCSSの圧縮',
+];
