@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/compresseur?lang_cible=nl
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// E
 	'explication_url_statique_ressources' => 'Een URL die kan dienen voor statische bestanden (afbeeldingen, JS…) zonder cookie. In het algemeen een alternatief subdomein dat ook naar de site verwijst.',
@@ -25,5 +21,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	// T
 	'texte_compacter_avertissement' => 'Gebruik deze opties liever niet tijdens de ontwikkeling van de site: gecomprimeerde elementen verliezen hun leesbaarheid.',
 	'texte_compacter_script_css' => 'SPIP kan JavaScript en stylesheets (CSS) comprimeren, om ze vervolgens op te slaan in statische bestanden, wat de weergave van de site versnelt.',
-	'titre_compacter_script_css' => 'Compressie van scripts en CSS'
-);
+	'titre_compacter_script_css' => 'Compressie van scripts en CSS',
+];
