@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/compresseur?lang_cible=ro
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// I
 	'info_compresseur_titre' => 'Optimizări şi compresie',
@@ -17,5 +13,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	// T
 	'texte_compacter_avertissement' => 'Atenţie: nu activaţi aceste opţiuni în timpul dezvoltării site-ului dumneavoastră, pentru că elementele compactate îşi pierd lizibilitatea.',
 	'texte_compacter_script_css' => 'SPIP poate compacta script-urile javascript şi foile de stil CSS pentru a le înregistra în fişiere statice; aceasta operaţiune accelerează afişarea site-ului.',
-	'titre_compacter_script_css' => 'Compactarea script-urilor şi a CSS-urlor'
-);
+	'titre_compacter_script_css' => 'Compactarea script-urilor şi a CSS-urlor',
+];
