@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compresseur?lang_cible=es
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// C
 	'compresseur_description' => 'Compresión de css y javascript en los encabezados de las páginas HTML de <code>ecrire/</code> y/o del sitio público',
-	'compresseur_slogan' => 'Compresión de css y javascript '
-);
+	'compresseur_slogan' => 'Compresión de css y javascript ',
+];
