@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compresseur?lang_cible=hac
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// C
 	'compresseur_description' => 'دروسکەودەی فشاردریاو سی‌ئێس‌ئێس و جاڤا سکریپتی چە لاو سەری  پەڕەکاۋە چیرو<code>ecrire/</code> و/یا سەرو پەڕەی سەرەكی پەڕیانەكەیۆ',
-	'compresseur_slogan' => 'دروسکەردەی فشاردریاو سی‌ئێس‌ئێس و جاڤا سکریپتی'
-);
+	'compresseur_slogan' => 'دروسکەردەی فشاردریاو سی‌ئێس‌ئێس و جاڤا سکریپتی',
+];
