@@ -3,14 +3,10 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compresseur?lang_cible=it
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// C
 	'compresseur_description' => 'Compressione di CSS e javascript 
 nell’intestazione delle pagine html di <code>ecrire/</code> e/o del sito pubblico pubblico.',
-	'compresseur_slogan' => 'Compressione di CSS e javascript'
-);
+	'compresseur_slogan' => 'Compressione di CSS e javascript',
+];
