@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compresseur?lang_cible=ru
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// C
 	'compresseur_description' => 'Сжимает css и javascript файлов на публичной части сайта и в панели управления <code>ecrire/</code> ',
-	'compresseur_slogan' => 'Плагин для сжатия CSS и Javascript файлов'
-);
+	'compresseur_slogan' => 'Плагин для сжатия CSS и Javascript файлов',
+];
