@@ -9,6 +9,8 @@
  *  Ce programme est un logiciel libre distribué sous licence GNU/GPL.     *
 \***************************************************************************/
 
+use Spip\Afficher\Minipage\Admin as MinipageAdmin;
+
 if (!defined('_ECRIRE_INC_VERSION')) {
 	return;
 }
@@ -48,7 +50,11 @@ function base_restaurer_dist($titre = '', $reprise = false) {
 		$titre = _T('dump:restauration_en_cours') . ' (' . (is_countable($status['tables']) ? count($status['tables']) : 0) . ') ';
 		$balise_img = chercher_filtre('balise_img');
 		$titre .= $balise_img(chemin_image('loader.svg'), '', 'loader');
-		echo(install_debut_html($titre));
+		$minipage = new MinipageAdmin();
+		echo $minipage->installDebutPage([
+			'all_inline' => false,
+			'titre' => $titre,
+		]);
 		// script de rechargement auto sur timeout
 		echo http_script("window.setTimeout('location.href=\"" . $redirect . "\";'," . ($timeout * 1000) . ')');
 		echo "<div style='text-align: left'>\n";
@@ -85,7 +91,7 @@ function base_restaurer_dist($titre = '', $reprise = false) {
 			echo dump_relance($redirect);
 		}
 
-		echo(install_fin_html());
+		echo $minipage->installFinPage();
 		ob_end_flush();
 		flush();
 
