@@ -3,12 +3,8 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=ay
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// B
-	'bouton_restaurer_base' => 'Yatqallta askichaña'
-);
+	'bouton_restaurer_base' => 'Yatqallta askichaña',
+];
