@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=nb
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// B
 	'bouton_restaurer_base' => 'Gjenopprett databasen',
@@ -23,5 +19,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'texte_admin_tech_02' => 'Attention: cette sauvegarde ne pourra être restaurée QUE dans un site installé sous la même version de SPIP. Il ne faut donc surtout pas « vider la base » en espérant réinstaller la sauvegarde après une mise à jour... Consultez <a href="@spipnet@">la documentation de SPIP</a>.', # MODIF
 	'texte_restaurer_base' => 'Gjenopprett innholdet av databasens sikkerhetskopi',
 	'texte_sauvegarde' => 'Ta sikkerhetskopi av databaseinnholdet',
-	'texte_sauvegarde_base' => 'Ta sikkerhetskopi av databasen'
-);
+	'texte_sauvegarde_base' => 'Ta sikkerhetskopi av databasen',
+];
