@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dump?lang_cible=de
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// D
 	'dump_description' => 'Sicherung und Wiederherstellung der Datenbank im SQLite-Format',
-	'dump_slogan' => 'Sicherung und Wiederherstellung der  SPIP-Datenbank'
-);
+	'dump_slogan' => 'Sicherung und Wiederherstellung der  SPIP-Datenbank',
+];
