@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dump?lang_cible=en
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// D
 	'dump_description' => 'Backup and restoration of the database in SQLite format',
-	'dump_slogan' => 'Backup and restore database SPIP'
-);
+	'dump_slogan' => 'Backup and restore database SPIP',
+];
