@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dump?lang_cible=hac
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// D
 	'dump_description' => 'پاشەکۆتکەرڎەی و ئەۋەگېڵنای داتابەیسی بە فۆرماتو SQLite',
-	'dump_slogan' => 'پاشەکۆتکەرڎەی و ئەۋەگېڵنای داتابەیسو SPIP'
-);
+	'dump_slogan' => 'پاشەکۆتکەرڎەی و ئەۋەگېڵنای داتابەیسو SPIP',
+];
