@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dump?lang_cible=oc_ni_mis
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// D
 	'dump_description' => 'Sauvagarda de la basa en SQLite e restauramen',
-	'dump_slogan' => 'Sauvagarda e restauramen de la basa SPIP'
-);
+	'dump_slogan' => 'Sauvagarda e restauramen de la basa SPIP',
+];
