@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dump?lang_cible=pt
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// D
 	'dump_description' => 'Cópia de segurança e restauro da base de dados em SQLite ',
-	'dump_slogan' => 'Cópia de segurança e restauro da base de dados SPIP'
-);
+	'dump_slogan' => 'Cópia de segurança e restauro da base de dados SPIP',
+];
