@@ -350,32 +350,3 @@ function _image_decale_composante($coul, $gamma) {
 
 	return $coul;
 }
-
-/**
- * Decalage d'une composante de couleur en sepia
- * entier de 0 a 255
- *
- * @param int $coul
- * @param int $val
- * @return int
- */
-function _image_decale_composante_127($coul, $val) {
-	if ($coul < 127) {
-		$y = round((($coul - 127) / 127) * $val) + $val;
-	} else {
-		if ($coul >= 127) {
-			$y = round((($coul - 127) / 128) * (255 - $val)) + $val;
-		} else {
-			$y = $coul;
-		}
-	}
-
-	if ($y < 0) {
-		$y = 0;
-	}
-	if ($y > 255) {
-		$y = 255;
-	}
-
-	return $y;
-}
