@@ -1389,7 +1389,7 @@ function image_rotation($im, $angle, $crop = false) {
 			$effectuer_gd = true;
 
 			if ($GLOBALS['meta']['image_process'] == 'convert') {
-				if (_CONVERT_COMMAND != '') {
+				if (!defined('_CONVERT_COMMAND')) {
 					@define('_CONVERT_COMMAND', 'convert');
 					@define('_ROTATE_COMMAND', _CONVERT_COMMAND . ' -background none -rotate %t %src %dest');
 				} else {
