@@ -1,13 +1,10 @@
 <?php
 // This is a SPIP language file  --  Ceci est un fichier langue de SPIP
 // Fichier source, a modifier dans https://git.spip.net/spip/filtres_images.git
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
 
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// I
 	'images_description' => 'Filtres de transformation d’images et de couleurs',
-	'images_slogan' => 'Filtres de transformation d’images et de couleurs'
-);
+	'images_slogan' => 'Filtres de transformation d’images et de couleurs',
+];
