@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-images?lang_cible=fr_fem
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// I
 	'images_description' => 'Filtres de transformation d’images et de couleurs',
-	'images_slogan' => 'Filtres de transformation d’images et de couleurs'
-);
+	'images_slogan' => 'Filtres de transformation d’images et de couleurs',
+];
