@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-images?lang_cible=pt
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// I
 	'images_description' => 'Processamento de imagens e filtros de cores',
-	'images_slogan' => 'Processamento de imagens e filtros de cores'
-);
+	'images_slogan' => 'Processamento de imagens e filtros de cores',
+];
