@@ -6,11 +6,18 @@
 
 
 $test = '_couleur_hsl2rgb';
-$remonte = '../';
-while (!is_dir($remonte . 'ecrire')) {
-	$remonte = "../$remonte";
+$remonte = "";
+while (!is_file($remonte."test.inc") and !is_dir($remonte.'ecrire/'))
+	$remonte = $remonte."../";
+foreach ([$remonte."test.inc", $remonte."tests/test.inc", $remonte."tests/tests/legacy/test.inc"] as $f) {
+	if (is_file($f)){
+		require $f;
+		break;
+	}
+}
+if (!defined('_SPIP_TEST_INC')) {
+	die('Impossible de trouver test.inc depuis ' .getcwd());
 }
-require $remonte . 'tests/test.inc';
 find_in_path('filtres/images_lib.php', '', true);
 
 //
