@@ -318,8 +318,16 @@ function formulaires_dater_traiter_dist($objet, $id_objet, $retour = '', $option
 		if (isset($options['champ_date_redac']) and $options['champ_date_redac']) {
 			$champ_date_redac = $options['champ_date_redac'];
 		}
-		if (isset($desc['field'][$champ_date_redac]) and $v['_editer_date_anterieure']) {
-			if (!_request('date_redac_jour') or _request('sans_redac')) {
+		if (isset($desc['field'][$champ_date_redac]) && $v['_editer_date_anterieure']) {
+			if (
+				!_request('date_redac_jour')
+				|| _request('sans_redac')
+				|| (in_array(
+					_request('date_redac_jour'),
+					['0000', '00/00/0000', '0000-00-00'],
+					true
+				) && _request('date_redac_heure') === '00:00')
+			) {
 				$set[$champ_date_redac] = sql_format_date(0, 0, 0, 0, 0, 0);
 			} else {
 				if (!$d = dater_recuperer_date_saisie(_request('date_redac_jour'), 'date_redac')) {
