@@ -486,16 +486,17 @@ function auteur_reset_password($id_auteur, $erreurs = []) {
  */
 function auteur_regenerer_identifiants($id_auteur, $notifier = true, $contexte = []) {
 	if ($id_auteur) {
-		$set = [];
-		include_spip('inc/access');
-		$set['pass'] = creer_pass_aleatoire(max(_PASS_LONGUEUR_MINI, 16));
+		$row = sql_fetsel('*', 'spip_auteurs', 'id_auteur=' . (int) $id_auteur);
 
-		include_spip('action/editer_auteur');
-		if (auteur_modifier($id_auteur, $set) !== '') {
-			return '';
+		// Si pas de mot de passe (création d'un nouveau compte), générer un hash aléatoire  pour le mettre en base, histoire qu'en suivant le lien on n'ait: pas de souci
+		// Cf https://git.spip.net/spip/prive/-/issues/79
+		if (!$row['pass']) {
+			$hash = uniqid(
+				'regeneration-'
+			); // SPIP n'écrit jamais un mot de passe directement, donc en stockant une chaine aléatoire on ne permet pas de trouver le mot de passe
+			sql_updateq('spip_auteurs', ['pass' => $hash], 'id_auteur=' . (int) $id_auteur);
 		}
 
-		$row = sql_fetsel('*', 'spip_auteurs', 'id_auteur=' . intval($id_auteur));
 		include_spip('inc/filtres');
 		if (
 			$notifier
@@ -503,13 +504,18 @@ function auteur_regenerer_identifiants($id_auteur, $notifier = true, $contexte =
 			and email_valide($row['email'])
 			and trouver_fond($fond = 'modeles/mail_nouveaux_identifiants')
 		) {
-			// envoyer l'email avec login/pass
+			include_spip('action/inscrire_auteur');
+			$token = auteur_attribuer_jeton($id_auteur);
+
+			$url_reset = generer_url_public('spip_pass', "p=$token", false, false);
+
+			// envoyer l'email avec login/url_reset
 			$c = [
 				'id_auteur' => $id_auteur,
 				'nom' => $row['nom'],
 				'mode' => $row['statut'],
 				'email' => $row['email'],
-				'pass' => $set['pass'],
+				'url_reset' => $url_reset,
 			];
 			// on merge avec les champs fournit en appel, qui sont passes au modele de notification donc
 			$contexte = array_merge($contexte, $c);
