@@ -43,13 +43,13 @@ function choisir_rubriques_admin_restreint(
 		$res =
 			"\n<div id='ajax_rubrique'>\n"
 			. "<label>$label</label>\n"
-			. "<input name='id_auteur' value='$id_auteur' type='hidden' />\n"
+			. "<input name='id_auteur' value='$id_auteur' type='hidden'>\n"
 			. $a
 			. "</div>\n"
 
 			// onchange = pour le menu
 			// l'evenement doit etre provoque a la main par le selecteur ajax
-			. "<script type='text/javascript'>/*<![CDATA[*/
+			. "<script>
 jQuery(function($){
 	$('#id_parent').on('change', function(){
 		var id_parent = parseInt(this.value);
@@ -58,7 +58,7 @@ jQuery(function($){
 			titre=titre.replace(/^\\s+/,'');
 			// Ajouter la rubrique selectionnee au formulaire,
 			// sous la forme d'un input name='rubriques[]'
-			var el = '<input type=\'checkbox\' class=\'checkbox\' checked=\'checked\' name=\'restreintes[]\' value=\''+id_parent+'\' /> ' + '<label><a href=\'?exec=rubrique&amp;id_rubrique='+id_parent+'\' target=\'_blank\'>'+titre+'</a></label>';
+			var el = '<input type=\'checkbox\' class=\'checkbox\' checked=\'checked\' name=\'restreintes[]\' value=\''+id_parent+'\'> ' + '<label><a href=\'?exec=rubrique&amp;id_rubrique='+id_parent+'\' target=\'_blank\'>'+titre+'</a></label>';
 			el = el + '$img_remove';
 			if (!$('$sel_css input[value='+id_parent+']').length) {
 				$('$sel_css').append('<li class=\"rubrique\">'+el+'</li>');
@@ -67,7 +67,7 @@ jQuery(function($){
 	})
 	.attr('name','noname');
 });
-/*]]>*/</script>";
+</script>";
 	}
 
 	return $res;
