@@ -9,6 +9,8 @@
  *  Ce programme est un logiciel libre distribué sous licence GNU/GPL.     *
 \***************************************************************************/
 
+use function SpipLeague\Component\Kernel\param;
+
 if (!defined('_ECRIRE_INC_VERSION')) {
 	return;
 }
@@ -36,9 +38,9 @@ function retrouve_auteur($id_auteur, $jeton = '') {
 	return false;
 }
 
-// chargement des valeurs par defaut des champs du formulaire
 /**
  * Chargement de l'auteur qui peut changer son mot de passe.
+ *
  * Soit un cookie d'oubli fourni par #FORMULAIRE_OUBLI est passe dans l'url par &p=
  * Soit un id_auteur est passe en parametre #FORMULAIRE_MOT_DE_PASSE{#ID_AUTEUR}
  * Dans les deux cas on verifie que l'auteur est autorise
@@ -156,13 +158,33 @@ function formulaires_mot_de_passe_traiter_dist($id_auteur = null, $jeton = null)
 				)
 			) {
 				$identifiant = $row['email'];
-			}
-			// Sinon on dit d'utiliser le login
-			else {
+			} else {
+				// Sinon on dit d'utiliser le login
 				$identifiant = $row['login'];
 			}
-			$res['message_ok'] = '<b>' . _T('pass_nouveau_enregistre') . '</b>' .
-				'<br />' . _T('pass_rappel_login', array('login' => $identifiant));
+			if (autoriser('ecrire', '', null, $row)) {
+				$lien_retour_texte = spip_ucfirst(_T('login_acces_prive'));
+				$lien_retour_url = param('spip.routes.back_office');
+			} else {
+				$lien_retour_texte = _T('pass_retour_public');
+				$lien_retour_url = $GLOBALS['meta']['adresse_site'];
+			}
+
+			include_spip('inc/filtres');
+			$res['message_ok'] = sprintf(
+				<<<HTML
+				<p>
+					<b>%s</b><br />
+					%s
+				</p>
+				<a href="%s">%s</a>
+				HTML
+				,
+				_T('pass_nouveau_enregistre'),
+				_T('pass_rappel_login', ['login' => $identifiant]),
+				attribut_url($lien_retour_url),
+				$lien_retour_texte
+			);
 
 			include_spip('inc/auth');
 			$auth = auth_identifier_login($row['login'], $oubli);
