@@ -9,11 +9,11 @@ return [
 	'bouton_radio_articles_futurs' => 'jutir yatiyawinakaruki (pirwa yatiyawinak janiw mayjt’aykiti)',
 	'bouton_radio_articles_tous' => 'taqpach qillqatanakaru',
 	'bouton_radio_articles_tous_sauf_forum_desactive' => 'Taqpach qillqatanakaru, janiw jiwt’at aruskipañanakar ukhama.',
-	'bouton_radio_enregistrement_obligatoire' => 'Qillqaw mayita (qillqayasiñapuniw aruskipayir churasina janir aruskipañan arst’asa)',
+	'bouton_radio_enregistrement_obligatoire' => 'Qillqaw mayita (qillqayasiñapuniw aruskipayir churasina janir aruskipañan arst’asa)', # MODIF
 	'bouton_radio_modere_abonnement' => 'qillqatanakatakiki',
 	'bouton_radio_modere_posteriori' => 'qhipurunx k’achata', # MODIF
 	'bouton_radio_modere_priori' => 'nayraqatax k’achata', # MODIF
-	'bouton_radio_publication_immediate' => 'Yatiyawinakat jank’aki yatiyaña (apayasinxa yanapawinakaxa uñstapxiwa, apnaqawirit ukata qhipurunxa apaqataspawa)',
+	'bouton_radio_publication_immediate' => 'Yatiyawinakat jank’aki yatiyaña (apayasinxa yanapawinakaxa uñstapxiwa, apnaqawirit ukata qhipurunxa apaqataspawa)', # MODIF
 
 	// F
 	'form_pet_message_commentaire' => '¿Mä yatiyawi, mä amuyu?',
@@ -51,7 +51,7 @@ return [
 	'icone_valider_message' => 'Aka yatiyaw iyaw saña',
 	'info_appliquer_choix_moderation' => 'Aka amuya kasta luraña',
 	'info_desactiver_forum_public' => 'Aruskipañanak jiwt’ayaña. Qillqatanakatakikiw naktayatani, ukhamarusa janiw jisk’aptatanakataki t’aqanakatakiraki.',
-	'info_envoi_forum' => 'Aruskipañanakat uñch’ukiwi',
+	'info_envoi_forum' => 'Aruskipañanakat uñch’ukiwi', # MODIF
 	'info_fonctionnement_forum' => 'Aruskipañawit lurt’xawipa:',
 	'info_gauche_suivi_forum_2' => 'Web qamawixa <i>aruskipañawinakat uñch’ukiwi</i> mä irnaqañatak qamawimat apnaqawiwa ( janiw aruskipaw qamawxakiti ukhamarak janiw qillqayaw qamawxakiti). Taqpach yanapanaka aruskipañawinakat aka qillqatata ukhamarak apnaqayaraktamwa.', # MODIF
 
