@@ -9,13 +9,13 @@ return [
 	'bouton_radio_articles_futurs' => 'solu à l’artìculi futuri (nisuna mudìfica à a basa attuale).',
 	'bouton_radio_articles_tous' => 'à tutti l’artìculi quant’elli sò.',
 	'bouton_radio_articles_tous_sauf_forum_desactive' => 'à tutti l’artìculi salvu quelli per chì hè disattivatu u foru.',
-	'bouton_radio_enregistrement_obligatoire' => 'Arregistramenu ubbligatoriu (l’utilizatori devenu abbunà si rinsignendu u so indirizzu e-mail prima di pudè mandà cuntributi).',
+	'bouton_radio_enregistrement_obligatoire' => 'Arregistramenu ubbligatoriu (l’utilizatori devenu abbunà si rinsignendu u so indirizzu e-mail prima di pudè mandà cuntributi).', # MODIF
 	'bouton_radio_moderation_priori' => 'Muderazione in antìcipu (i cuntributi ùn sò pubblicati chè dopu accunsentu da l’amministratori).', # MODIF
 	'bouton_radio_modere_abonnement' => 'Solu cù abbunamentu',
 	'bouton_radio_modere_posteriori' => 'Muderazione dopu', # MODIF
 	'bouton_radio_modere_priori' => 'muderazione in antìcipu', # MODIF
 	'bouton_radio_publication_immediate' => 'Pubblicazione à l’istante di i messagi
-(e cuntribuzioni sò pubblicate subbitu dopu mandate, l’amministradori i ponu sguassà dopu).',
+(e cuntribuzioni sò pubblicate subbitu dopu mandate, l’amministradori i ponu sguassà dopu).', # MODIF
 
 	// D
 	'documents_interdits_forum' => 'Ducumenti interdetti in u foru',
@@ -62,13 +62,13 @@ return [
 	di muderazione predefinitu :</i>', # MODIF
 	'info_appliquer_choix_moderation' => 'Serà appiecata sta scelta di muderazione :',
 	'info_config_forums_prive' => 'In u spaziu riservatu di u situ, pudete puru attivà diversi tippi di fori :', # MODIF
-	'info_config_forums_prive_admin' => 'Un foru riservatu à l’amministratori di u situ :',
-	'info_config_forums_prive_global' => 'Un foru generale, apertu à tutti i scrittori :',
+	'info_config_forums_prive_admin' => 'Un foru riservatu à l’amministratori di u situ :', # MODIF
+	'info_config_forums_prive_global' => 'Un foru generale, apertu à tutti i scrittori :', # MODIF
 	'info_config_forums_prive_objets' => 'Un foru per ogni artìculu, dispacciu, situ riferitu, etc. :',
 	'info_desactiver_forum_public' => 'Disattivà l’adopru di i fori pùbblichi.
 	I fori pùbblichi puderanu esse auturizati di volta in volta
 	per i sìnguli artìculi; Invece seranu interdetti per e rùbbriche, i dispacci, etc.',
-	'info_envoi_forum' => 'Nutìfiche da i fori à l’autori di l’artìculi',
+	'info_envoi_forum' => 'Nutìfiche da i fori à l’autori di l’artìculi', # MODIF
 	'info_fonctionnement_forum' => 'Funziunamentu di u foru :',
 	'info_gauche_suivi_forum_2' => 'A pàgina di <i>guardia di i fori</i> hè un arnese di gestione di u situ (è micca un spaziu di ragiunata o di scrittura). 
 		Nentru ci venenu pubblicati tutti i cuntributi di i fori di u situ, ch’elli sianu quelli di u situ pùbblicu o quelli di u spaziu privatu, 
@@ -81,16 +81,16 @@ return [
 	'info_mode_fonctionnement_defaut_forum_public' => 'Modu di funziunamentu predefinitu di i fori pùbblichi',
 	'info_option_email' => 'Quando un visitore di u situ posta un novu messagiu in u foru
 	assuciatu à un artìculu, l’autori di st’artìculu ne ponu esse
-	avvisati da un email. Signalate puru per ogni tippu di foru s’ellu ci vole à usà st’opzione.',
+	avvisati da un email. Signalate puru per ogni tippu di foru s’ellu ci vole à usà st’opzione.', # MODIF
 	'info_pas_de_forum' => 'Nisunu foru',
 	'info_question_visiteur_ajout_document_forum' => 'Sè vo vulete auturizà i visitori à alleà ducumenti (imàgini, mùsiche ...) à i so messagi di u foru, rinsignate quì sottu a lista di ’estensioni di i ducumenti auturizati pè i fori (per esempiu : gif, jpg, png, mp3).', # MODIF
 	'info_question_visiteur_ajout_document_forum_format' => 'Sè vo vulete auturizà tutti i tippi di ducumenti cunsiderati da affidati da SPIP, mettite una 
 		stelluccia. Per ùn auturizà nunda, ùn mettite nunda.', # MODIF
-	'item_activer_forum_administrateur' => 'Attivà u foru di l’amministratori',
-	'item_config_forums_prive_global' => 'Attivà i fori di i scrittori',
+	'item_activer_forum_administrateur' => 'Attivà u foru di l’amministratori', # MODIF
+	'item_config_forums_prive_global' => 'Attivà i fori di i scrittori', # MODIF
 	'item_config_forums_prive_objets' => 'Attivà sti fori',
-	'item_desactiver_forum_administrateur' => 'Disattivà u foru di l’amministratori',
-	'item_non_config_forums_prive_global' => 'Disattivà i fori di i scrittori',
+	'item_desactiver_forum_administrateur' => 'Disattivà u foru di l’amministratori', # MODIF
+	'item_non_config_forums_prive_global' => 'Disattivà i fori di i scrittori', # MODIF
 	'item_non_config_forums_prive_objets' => 'Disattivà sti fori',
 
 	// L
@@ -113,7 +113,7 @@ return [
 	// T
 	'text_article_propose_publication_forum' => 'Date puru u vostru parè in u foru di st’artìculu (in fondu di pàgina).',
 	'texte_en_cours_validation_forum' => 'Date puru u vostru parè usendu i fori chì li sò assuciati.',
-	'titre_cadre_forum_administrateur' => 'Foru privatu di l’amministratori',
+	'titre_cadre_forum_administrateur' => 'Foru privatu di l’amministratori', # MODIF
 	'titre_cadre_forum_interne' => 'Foru internu',
 	'titre_config_forums_prive' => 'Fori di u spaziu privatu',
 	'titre_forum' => 'Foru',
