@@ -9,14 +9,14 @@ return [
 	'bouton_radio_articles_futurs' => 'pou bann zartik a fèr sèlman (san tous a ryin dann bazdodné).',
 	'bouton_radio_articles_tous' => 'po TOUT bann zartik minm.',
 	'bouton_radio_articles_tous_sauf_forum_desactive' => 'pou tout bann zartik-la, sof banna pwinn bordé èk inn forom kozman.',
-	'bouton_radio_enregistrement_obligatoire' => 'Aou lé néséser fé zwé lanrozistroman po anvwa out komisyon (bann zitilzatèr i dwa mèt ladrès imèl pou abonn azot).',
+	'bouton_radio_enregistrement_obligatoire' => 'Aou lé néséser fé zwé lanrozistroman po anvwa out komisyon (bann zitilzatèr i dwa mèt ladrès imèl pou abonn azot).', # MODIF
 	'bouton_radio_moderation_priori' => 'Modèr-dovan (bann komisyon lé publyé dann figirwèb piblik, sèlman kan komandèr la apiyé).
 
 ', # MODIF
 	'bouton_radio_modere_abonnement' => 'In labonman lé nesèsèr',
 	'bouton_radio_modere_posteriori' => 'lé modèré apré konfirmasyon ', # MODIF
 	'bouton_radio_modere_priori' => 'lé modèré-dovan', # MODIF
-	'bouton_radio_publication_immediate' => 'Modékri lé publyé sir losan (bann komisyon lé visib toutswit apré zot la anvway ali ; bann komander sitwèb i pé dégrèn ali aprè).',
+	'bouton_radio_publication_immediate' => 'Modékri lé publyé sir losan (bann komisyon lé visib toutswit apré zot la anvway ali ; bann komander sitwèb i pé dégrèn ali aprè).', # MODIF
 
 	// F
 	'form_pet_message_commentaire' => 'Inn modékri, inn ti lavi, inn komantèr ?',
@@ -57,7 +57,7 @@ return [
 	'info_activer_forum_public' => '<i>Swazi inn manyir lamodérasyon otomatik pou bann forom piblik :</i>', # MODIF
 	'info_appliquer_choix_moderation' => 'Aplik lo swa ou la fé pou lamodérasyon :',
 	'info_desactiver_forum_public' => 'Apiy tèrla, pou détour litilizasyon tout bann forom piblik. Ou sra touzou kav permèt bann forom-la èk bann zartik (dann désertin ka ou sava désid) ; mé nora pwinn forom èk bann rubrik, bann tit-nouvèl, é tousala.',
-	'info_envoi_forum' => 'Anvwa tout bann modékri sak i sort dann bann forom , pou tout bann lotèr lartik lyé ',
+	'info_envoi_forum' => 'Anvwa tout bann modékri sak i sort dann bann forom , pou tout bann lotèr lartik lyé ', # MODIF
 	'info_fonctionnement_forum' => 'Koman forom-la i pé roul ron :',
 	'info_gauche_suivi_forum_2' => 'Paz <i>swivi bann forom</i> lé inn zoutiy pou zèr an liyn out sit (pa inn léspas kozman o lékritir). Li afis tout bann kontribusyon sak lé prézanté dann tout bann forom out sit i ébèrz (kiswa forom-dodan, forom-déor, tousala...). Li permé zèr bann kontribusyon-la.', # MODIF
 	'info_liens_syndiques_3' => 'bann forom',
@@ -70,8 +70,8 @@ return [
 bann lotèr i pé konèt a li
 sanm inn limèl. Indik tèrla si ou vé anserv lopsyon-la ?', # MODIF
 	'info_pas_de_forum' => 'néna pwinn forom',
-	'item_activer_forum_administrateur' => 'Fé zwé lo forom bann komandèr',
-	'item_desactiver_forum_administrateur' => 'Défalk bann forom-komandèr',
+	'item_activer_forum_administrateur' => 'Fé zwé lo forom bann komandèr', # MODIF
+	'item_desactiver_forum_administrateur' => 'Défalk bann forom-komandèr', # MODIF
 
 	// L
 	'lien_reponse_article' => 'Réponn lartik-la',
@@ -88,7 +88,7 @@ sanm inn limèl. Indik tèrla si ou vé anserv lopsyon-la ?', # MODIF
 	'repondre_message' => 'Po réponn modékri-la',
 
 	// T
-	'titre_cadre_forum_administrateur' => 'Forom privé bann komandèr',
+	'titre_cadre_forum_administrateur' => 'Forom privé bann komandèr', # MODIF
 	'titre_cadre_forum_interne' => 'Forom dodan',
 	'titre_forum' => 'Forom ',
 	'titre_forum_suivi' => 'Swivi bann forom',
