@@ -9,9 +9,9 @@ return [
 	'bouton_radio_articles_futurs' => 'στα μελλοντικά άρθρα μόνο (καμία δράση στη βάση δεδομένων).',
 	'bouton_radio_articles_tous' => 'σε όλα τα άρθρα χωρίς εξαίρεση.',
 	'bouton_radio_articles_tous_sauf_forum_desactive' => 'σε όλα τα άρθρα,εκτός από αυτά για τα οποία είναι απενεργοποιημένο το φόρουμ.',
-	'bouton_radio_enregistrement_obligatoire' => 'Απαραίτητη εγγραφή (οι χρήστες πρέπει να προσυπογράψουν με την παροχή της διεύθυνσης ηλεκτρονικού ταχυδρομείου τους πρίν είναι σε θέση να ταχυδρομηθούν οι συνεισφορές).',
+	'bouton_radio_enregistrement_obligatoire' => 'Απαραίτητη εγγραφή (οι χρήστες πρέπει να προσυπογράψουν με την παροχή της διεύθυνσης ηλεκτρονικού ταχυδρομείου τους πρίν είναι σε θέση να ταχυδρομηθούν οι συνεισφορές).', # MODIF
 	'bouton_radio_modere_abonnement' => 'απαιτείται εγγραφή',
-	'bouton_radio_publication_immediate' => 'Αμεση δημοσίευση των μηνυμάτων (οι συνεισφορές θα παρουσιαστούν μόλις στέλνονται, οι διαχειριστές του ιστοχώρου μπορούν έπειτα να τις διαγράψουν).',
+	'bouton_radio_publication_immediate' => 'Αμεση δημοσίευση των μηνυμάτων (οι συνεισφορές θα παρουσιαστούν μόλις στέλνονται, οι διαχειριστές του ιστοχώρου μπορούν έπειτα να τις διαγράψουν).', # MODIF
 
 	// F
 	'form_pet_message_commentaire' => 'Μήνυμα, σχόλιο ;',
@@ -53,7 +53,7 @@ return [
 	'info_desactiver_forum_public' => 'Απενεργοποιήστε την χρήση των δημόσιων
  φόρουμ. Τα δημόσια φόρουμ θα μπορούσαν να επιτραπούν σε ανά περίπτωση
  για τα άρθρα; θα είναι απαγορευμένα για τα τμήματα, τις ειδήσεις, κ.λπ....',
-	'info_envoi_forum' => 'Στείλετε τα φόρουμ στους συντάκτες άρθρων',
+	'info_envoi_forum' => 'Στείλετε τα φόρουμ στους συντάκτες άρθρων', # MODIF
 	'info_fonctionnement_forum' => 'Λειτουργία φόρουμ:',
 
 	// O
