@@ -9,7 +9,7 @@ return [
 	'bouton_radio_articles_futurs' => '70 fu7ur3 4r71c135 0n1y (n0 4c710n 0n 7h3 d474b453).',
 	'bouton_radio_articles_tous' => '70 411 4r71c135 w17h0u7 4ny 3xc3p710n.',
 	'bouton_radio_articles_tous_sauf_forum_desactive' => '70 411 4r71c135, 3xc3p7 7h053 w17h d154b13d f0rum5.',
-	'bouton_radio_enregistrement_obligatoire' => 'R3qu1r3d r3g157r4710n (u53r5 mu57 5ub5cr1b3 by pr0v1d1ng 7h31r 3-m411 4ddr355 b3f0r3 b31ng 4b13 70 p057 c0n7r1bu710n5).',
+	'bouton_radio_enregistrement_obligatoire' => 'R3qu1r3d r3g157r4710n (u53r5 mu57 5ub5cr1b3 by pr0v1d1ng 7h31r 3-m411 4ddr355 b3f0r3 b31ng 4b13 70 p057 c0n7r1bu710n5).', # MODIF
 	'bouton_radio_moderation_priori' => 'B3f0r3h4nd m0d3r4710n (
 	c0n7r1bu710n5 w111 b3 5h0wn 0n1y 4f73r v411d4710n by
 	4dm1n157r470r5).', # MODIF
@@ -18,7 +18,7 @@ return [
 	'bouton_radio_modere_priori' => 'b3f0r3h4nd m0d3r4710n', # MODIF
 	'bouton_radio_publication_immediate' => '1mm3d1473 pub11c4710n 0f m3554g35
 	(c0n7r1bu710n5 w111 b3 5h0wn 7h3 m0m3n7 7h3y 4r3 53n7, 4dm1n157r470r5 c4n
-	d31373 7h3m 7h3n).',
+	d31373 7h3m 7h3n).', # MODIF
 
 	// F
 	'form_pet_message_commentaire' => '4ny m3554g3 0r c0mm3n7?',
@@ -61,7 +61,7 @@ return [
 	'info_desactiver_forum_public' => 'D154b13 7h3 u53 0f pub11c
 	f0rum5. Pub11c f0rum5 c0u1d b3 4110w3d 0n 4 c453 by c453
 	b4515 f0r 7h3 4r71c135; 7h3y w111 b3 f0rb1dd3n f0r 7h3 53c710n5, n3w5, 37c.',
-	'info_envoi_forum' => '53nd f0rum5 70 4r71c135 4u7h0r5',
+	'info_envoi_forum' => '53nd f0rum5 70 4r71c135 4u7h0r5', # MODIF
 	'info_fonctionnement_forum' => 'F0rum 0p3r4710n:',
 	'info_gauche_suivi_forum_2' => '7h3 <1>f0rum5 f0110w-up</1> p4g3 15 4 m4n4g3m3n7 7001 0f y0ur 5173 (n07 4 d15cu5510n 0r 3d171ng). 17 d15p14y5 411 7h3 c0n7r1bu710n5 0f 7h3 pub11c f0rum 0f 7h15 4r71c13 4nd 4110w5 y0u 70 m4n4g3 7h353 c0n7r1bu710n5.', # MODIF
 	'info_liens_syndiques_3' => 'f0rum5',
@@ -74,8 +74,8 @@ return [
 		4550c1473d w17h 4n 4r71c13, 7h3 4r71c13’5 4u7h0r5 c4n b3
 		1nf0rm3d 0f 7h15 m3554g3 by 3-m411. D0 y0u w15h 70 u53 7h15 0p710n?', # MODIF
 	'info_pas_de_forum' => 'n0 f0rum',
-	'item_activer_forum_administrateur' => '3n4b13 4dm1n157r470r5 f0rum',
-	'item_desactiver_forum_administrateur' => 'D154b13 4dm1n157r470r5 f0rum',
+	'item_activer_forum_administrateur' => '3n4b13 4dm1n157r470r5 f0rum', # MODIF
+	'item_desactiver_forum_administrateur' => 'D154b13 4dm1n157r470r5 f0rum', # MODIF
 
 	// L
 	'lien_reponse_article' => 'R3p1y 70 7h3 4r71c13',
@@ -92,7 +92,7 @@ return [
 	'repondre_message' => 'R3p1y 70 7h15 m3554g3',
 
 	// T
-	'titre_cadre_forum_administrateur' => '4dm1n157r470r5 pr1v473 f0rum',
+	'titre_cadre_forum_administrateur' => '4dm1n157r470r5 pr1v473 f0rum', # MODIF
 	'titre_cadre_forum_interne' => '1n73rn41 f0rum',
 	'titre_forum' => 'F0rum',
 	'titre_forum_suivi' => 'F0rum5 f0110w-up',
