@@ -12,14 +12,14 @@ return [
 	'bouton_radio_articles_futurs' => 'a los artículos futuros solamente (no modifica la base de datos).',
 	'bouton_radio_articles_tous' => 'a todos los artículos sin excepción.',
 	'bouton_radio_articles_tous_sauf_forum_desactive' => 'a todos los artículos, salvo aquellos cuyo foro está desactivado.',
-	'bouton_radio_enregistrement_obligatoire' => 'Inscripción obligatoria (es necesario inscribirse dando su correo electrónico antes de poder participar en el foro).',
+	'bouton_radio_enregistrement_obligatoire' => 'Inscripción obligatoria (es necesario inscribirse dando su correo electrónico antes de poder participar en el foro).', # MODIF
 	'bouton_radio_moderation_priori' => 'Moderado a priori (las
  	contribuciones sólo aparecen públicas luego de validación por un/a
-  	administrador/a).',
+  	administrador/a).', # MODIF
 	'bouton_radio_modere_abonnement' => 'sólo para inscritos',
 	'bouton_radio_modere_posteriori' => 'moderación a posteriori',
 	'bouton_radio_modere_priori' => 'moderación a priori',
-	'bouton_radio_publication_immediate' => 'Publicación inmediata de los mensajes (las contribuciones aparecen en cuanto son enviadas, siendo posible eliminarlas después).',
+	'bouton_radio_publication_immediate' => 'Publicación inmediata de los mensajes (las contribuciones aparecen en cuanto son enviadas, siendo posible eliminarlas después).', # MODIF
 
 	// D
 	'documents_interdits_forum' => 'Documentos prohibidos en el foro',
@@ -42,7 +42,7 @@ return [
 	'forum_cliquer_retour' => 'Haga clic <a href=\'@retour_forum@\'>aquí</a> para continuar.',
 	'forum_envoyer' => 'Enviar',
 	'forum_forum' => 'foro',
-	'forum_info_modere' => 'Este foro es moderado a priori: su contribución sólo aparecerá una vez validada por un/a administrador/a del sitio.',
+	'forum_info_modere' => 'Este foro es moderado a priori: su contribución sólo aparecerá una vez validada por un/a administrador/a del sitio.', # MODIF
 	'forum_lien_hyper' => 'Enlace hipertexto',
 	'forum_message' => 'Su mensaje',
 	'forum_message_definitif' => 'Mensaje definitivo: enviar al sitio',
@@ -83,11 +83,11 @@ suministrado. Si no está inscrito/a, debe',
 	'info_activer_forum_public' => 'Para activar los foros públicos, seleccione el modo de moderación por defecto:',
 	'info_appliquer_choix_moderation' => 'Aplicar este tipo de moderación',
 	'info_config_forums_prive' => 'En el espacio privado del sitio, puede activar varios tipos de foro:',
-	'info_config_forums_prive_admin' => 'Un foro reservado a los administradores del sitio:',
-	'info_config_forums_prive_global' => 'Un foro global, abierto a todos los redactores:',
+	'info_config_forums_prive_admin' => 'Un foro reservado a los administradores del sitio:', # MODIF
+	'info_config_forums_prive_global' => 'Un foro global, abierto a todos los redactores:', # MODIF
 	'info_config_forums_prive_objets' => 'Un foro para cada artículo, breve, sitio referenciado, etc.:',
 	'info_desactiver_forum_public' => 'Desactivar los foros públicos. Podrán ser activados puntualmente para los artículos, pero no para los breves, las secciones, etc.',
-	'info_envoi_forum' => 'Seguimiento de los foros',
+	'info_envoi_forum' => 'Seguimiento de los foros', # MODIF
 	'info_fonctionnement_forum' => 'Funcionamiento del foro:',
 	'info_forcer_previsualisation_court' => 'Forzar la vista previa',
 	'info_forcer_previsualisation_long' => 'Forzar la vista previa antes de mandar el mensaje',
@@ -102,18 +102,18 @@ suministrado. Si no está inscrito/a, debe',
 	'info_liens_titre' => 'Enlace(s) que contiene el título del mensaje',
 	'info_mode_fonctionnement_defaut_forum_public' => 'Modo de funcionamiento de los foros públicos',
 	'info_nb_messages_forum' => '@nb@ mensajes de foro',
-	'info_option_email' => 'Cuando se envía una nueva contribución a un foro asociado a un artículo, los autores del artículo pueden recibir una notificación por correo electrónico. Indique para cada tipo de foro si hay que utilizar esta opción.',
+	'info_option_email' => 'Cuando se envía una nueva contribución a un foro asociado a un artículo, los autores del artículo pueden recibir una notificación por correo electrónico. Indique para cada tipo de foro si hay que utilizar esta opción.', # MODIF
 	'info_pas_de_forum' => 'sin foro',
-	'info_question_visiteur_ajout_document_forum' => 'Si desea autorizar la publicación de documentos (imágenes, sonidos...) en los mensajes de foro, indique la lista de extensiones de documentos autorizados en los foros (por ejemplo: gif, jpg, png, mp3).',
+	'info_question_visiteur_ajout_document_forum' => 'Si desea autorizar la publicación de documentos (imágenes, sonidos...) en los mensajes de foro, indique la lista de extensiones de documentos autorizados en los foros (por ejemplo: gif, jpg, png, mp3).', # MODIF
 	'info_question_visiteur_ajout_document_forum_format' => 'Para autorizar todos los tipos de documentos considerados como fiables por SPIP, marca un asterisco. Para no autorizar ninguno, no indiques nada.',
 	'info_selectionner_message' => 'Seleccionar los mensajes:',
 	'interface_formulaire' => 'Interfaz formulario',
 	'interface_onglets' => 'Interfaz con pestañas',
-	'item_activer_forum_administrateur' => 'Activar el foro del equipo de administración.',
-	'item_config_forums_prive_global' => 'Activar el foro de los redactores',
+	'item_activer_forum_administrateur' => 'Activar el foro del equipo de administración.', # MODIF
+	'item_config_forums_prive_global' => 'Activar el foro de los redactores', # MODIF
 	'item_config_forums_prive_objets' => 'Activar estos foros',
-	'item_desactiver_forum_administrateur' => 'Desactivar el foro de administración',
-	'item_non_config_forums_prive_global' => 'Desactivar el foro de los redactores',
+	'item_desactiver_forum_administrateur' => 'Desactivar el foro de administración', # MODIF
+	'item_non_config_forums_prive_global' => 'Desactivar el foro de los redactores', # MODIF
 	'item_non_config_forums_prive_objets' => 'Desactivar estos foros',
 
 	// L
@@ -127,12 +127,12 @@ suministrado. Si no está inscrito/a, debe',
 
 	// M
 	'messages_aucun' => 'Ningún',
-	'messages_meme_auteur' => 'Todos los mensajes de este autor/a',
+	'messages_meme_auteur' => 'Todos los mensajes de este autor/a', # MODIF
 	'messages_meme_email' => 'Todos los mensajes de este email',
 	'messages_meme_ip' => 'Todos los mensajes de esta IP',
 	'messages_off' => 'Eliminados',
 	'messages_perso' => 'Personales',
-	'messages_privadm' => 'Administradores',
+	'messages_privadm' => 'Administradores', # MODIF
 	'messages_prive' => 'Privados',
 	'messages_privoff' => 'Eliminados',
 	'messages_privrac' => 'Generales',
@@ -161,7 +161,7 @@ suministrado. Si no está inscrito/a, debe',
 	'texte_en_cours_validation' => 'Los siguientes artículos, breves y foros están propuestos para publicación.',
 	'texte_en_cours_validation_forum' => 'No dude en dar su opinión mediante los foros adjuntos.',
 	'texte_messages_publics' => 'Mensajes públicos sobre:',
-	'titre_cadre_forum_administrateur' => 'Foro administradores',
+	'titre_cadre_forum_administrateur' => 'Foro administradores', # MODIF
 	'titre_cadre_forum_interne' => 'Foro interno',
 	'titre_config_forums_prive' => 'Foros del espacio privado',
 	'titre_forum' => 'Foros',
