@@ -9,7 +9,7 @@ return [
 	'bouton_radio_articles_futurs' => 'untuk artikel yang akan dipublikasikan di masa depan saja (tidak ada aksi di database).',
 	'bouton_radio_articles_tous' => 'untuk semua artikel tanpa pengecualian.',
 	'bouton_radio_articles_tous_sauf_forum_desactive' => 'untuk semua artikel, terkecuali artikel yang forumnya dinonaktifkan.',
-	'bouton_radio_enregistrement_obligatoire' => 'Registrasi diperlukan (pengguna harus mendaftarkan diri dengan memberikan alamat e-mailnya sebelum dapat berkontribusi).',
+	'bouton_radio_enregistrement_obligatoire' => 'Registrasi diperlukan (pengguna harus mendaftarkan diri dengan memberikan alamat e-mailnya sebelum dapat berkontribusi).', # MODIF
 	'bouton_radio_moderation_priori' => 'Moderasi awal (
  kontribusi hanya akan ditampilkan setelah validasi
  oleh administrator).', # MODIF
@@ -18,7 +18,7 @@ return [
 	'bouton_radio_modere_priori' => 'moderasi awal', # MODIF
 	'bouton_radio_publication_immediate' => 'Publikasi pesan segera
  (kontribusi akan ditampilkan sesegera mungkin setelah dikirimkan, kemudian
- administrator dapat menghapusnya).',
+ administrator dapat menghapusnya).', # MODIF
 
 	// F
 	'form_pet_message_commentaire' => 'Ada pesan atau komentar?',
@@ -62,7 +62,7 @@ return [
 	'info_desactiver_forum_public' => 'Non aktifkan penggunaan forum
 	umum. Forum umum dapat digunakan berdasarkan kasus per kasus untuk
 	artikel-artikel; dan penggunannya dilarang untuk bagian, berita, dll.',
-	'info_envoi_forum' => 'Kirim forum ke penulis artikel',
+	'info_envoi_forum' => 'Kirim forum ke penulis artikel', # MODIF
 	'info_fonctionnement_forum' => 'Operasi forum:',
 	'info_gauche_suivi_forum_2' => 'Halaman <i>tindak lanjut forum</i> adalah alat bantu pengelola situs anda (bukan area diskusi atau pengeditan). Halaman ini menampilkan semua kontribusi forum umum artikel ini dan mengizinkan anda untuk mengelola kontribusi-kontribusi ini.', # MODIF
 	'info_liens_syndiques_3' => 'forum',
@@ -75,8 +75,8 @@ return [
 		yang terasosiasi dengan sebuah artikel, penulis artikel akan diinformasikan
 		melalui e-mail. Anda ingin menggunakan opsi ini?', # MODIF
 	'info_pas_de_forum' => 'tidak ada forum',
-	'item_activer_forum_administrateur' => 'Aktifkan forum administrator',
-	'item_desactiver_forum_administrateur' => 'Non aktifkan forum administrator',
+	'item_activer_forum_administrateur' => 'Aktifkan forum administrator', # MODIF
+	'item_desactiver_forum_administrateur' => 'Non aktifkan forum administrator', # MODIF
 
 	// L
 	'lien_reponse_article' => 'Balasan pada artikel',
@@ -96,7 +96,7 @@ return [
 	'statut_original' => 'asli',
 
 	// T
-	'titre_cadre_forum_administrateur' => 'Forum pribadi para administrator',
+	'titre_cadre_forum_administrateur' => 'Forum pribadi para administrator', # MODIF
 	'titre_cadre_forum_interne' => 'Forum intern',
 	'titre_forum' => 'Forum',
 	'titre_forum_suivi' => 'Tindak lanjut forum',
