@@ -12,12 +12,12 @@ return [
 	'bouton_radio_articles_futurs' => 'nëmmen fir nei Artikelen (keng Aktioun op d’Datebank).',
 	'bouton_radio_articles_tous' => 'fir all nei Artikelen ouni Ausnahm.',
 	'bouton_radio_articles_tous_sauf_forum_desactive' => 'fir all Artikelen, ausser déi wou de Forum ausgeschalt ass.',
-	'bouton_radio_enregistrement_obligatoire' => 'Obligatorescht Aschreiwen (d’Benotzer mussen sech umellen andeem si hier Email-Adress uginn ier se hier Message kënne schécken).',
-	'bouton_radio_moderation_priori' => 'Moderatioun à priori (d’Message ginn eréischt verëffentlecht nodeems se vun engem Administrateur bestätegt goufen).',
+	'bouton_radio_enregistrement_obligatoire' => 'Obligatorescht Aschreiwen (d’Benotzer mussen sech umellen andeem si hier Email-Adress uginn ier se hier Message kënne schécken).', # MODIF
+	'bouton_radio_moderation_priori' => 'Moderatioun à priori (d’Message ginn eréischt verëffentlecht nodeems se vun engem Administrateur bestätegt goufen).', # MODIF
 	'bouton_radio_modere_abonnement' => 'op Abonnement',
 	'bouton_radio_modere_posteriori' => 'Moderatioun à posteriori',
 	'bouton_radio_modere_priori' => 'Moderatioun à priori',
-	'bouton_radio_publication_immediate' => 'Direkt Verëffentlechung vun de Messagen (d’Message ginn direkt nom Schécken siichtbar, d’Administrateure kënnen se duerno läschen).',
+	'bouton_radio_publication_immediate' => 'Direkt Verëffentlechung vun de Messagen (d’Message ginn direkt nom Schécken siichtbar, d’Administrateure kënnen se duerno läschen).', # MODIF
 
 	// D
 	'documents_interdits_forum' => 'Dokumenter sinn am Forum net erlaabt',
@@ -37,7 +37,7 @@ return [
 	'forum_avez_selectionne' => 'Dir hutt gewielt:',
 	'forum_cliquer_retour' => '<a href=\'@retour_forum@\'>Hei klicken</a> fir weider.',
 	'forum_forum' => 'Forum',
-	'forum_info_modere' => 'Dëse Forum ass "à priori" moderéiert: äre Beitrag geet eréischt verëffentlecht wann e vun engem Administrateur vum Site bestätegt ass.',
+	'forum_info_modere' => 'Dëse Forum ass "à priori" moderéiert: äre Beitrag geet eréischt verëffentlecht wann e vun engem Administrateur vum Site bestätegt ass.', # MODIF
 	'forum_lien_hyper' => 'Link',
 	'forum_message' => 'Äre Message',
 	'forum_message_definitif' => 'Definitive Message: op de Site schécken',
@@ -74,11 +74,11 @@ return [
 	'info_activer_forum_public' => 'Fir déi ëffentlech Forumen anzeschalten, wielt d’Moderatiouns-Method:',
 	'info_appliquer_choix_moderation' => 'Dës Moderatiouns-Method benotzen:',
 	'info_config_forums_prive' => 'Am privaten Deel vum Site kënnt dir e puer Forumen aschalten:',
-	'info_config_forums_prive_admin' => 'E reservéierte Forum fir d’Administrateure vum Site:',
-	'info_config_forums_prive_global' => 'E globale Forum fir all Redakteren:',
+	'info_config_forums_prive_admin' => 'E reservéierte Forum fir d’Administrateure vum Site:', # MODIF
+	'info_config_forums_prive_global' => 'E globale Forum fir all Redakteren:', # MODIF
 	'info_config_forums_prive_objets' => 'E Forum ënnert all Artikel, Kuerzmeldung, verlinkte Site, asw.:',
 	'info_desactiver_forum_public' => 'Déi ëffentlech Forumen ausschalten. Ëffentlech Forume kënne vu Fall zu Fall pro Artikel ageschalt ginn; awer net op de Rubriken, Kuerzmeldungen, asw.',
-	'info_envoi_forum' => 'D’Forum-Messagen un d’Auteuren vun den Artikele schécken',
+	'info_envoi_forum' => 'D’Forum-Messagen un d’Auteuren vun den Artikele schécken', # MODIF
 	'info_fonctionnement_forum' => 'Fonctionnement vum Forum:',
 	'info_forums_liees_mot' => 'Forum-Messagen déi mat dësem Wuert verbonne sinn',
 	'info_gauche_suivi_forum_2' => 'D’Säit <i>Forume verfollegen</i> ass fir d’Gestioun vum Forum a net fir ze diskutéieren oder ze schreiwen. Si weist all d’Beiträg vun de Forume vum Site, déi ëffentlech an déi privat, an dir kënnt d’Beiträg beaarbechten.',
@@ -91,18 +91,18 @@ return [
 	'info_liens_titre' => 'Linken aus dem Titel vum Message',
 	'info_mode_fonctionnement_defaut_forum_public' => 'Default-Méthod vun den ëffentleche Forumen',
 	'info_nb_messages_forum' => '@nb@ Messagen am Forum',
-	'info_option_email' => 'Wann e Visiteur vum Site e neie Message an de Forum vun engem Artikel schéckt, kennen d’Auteuren vum Artikel via Email Bescheed kréien. Wëllt dir dës Optioun benotzen?',
+	'info_option_email' => 'Wann e Visiteur vum Site e neie Message an de Forum vun engem Artikel schéckt, kennen d’Auteuren vum Artikel via Email Bescheed kréien. Wëllt dir dës Optioun benotzen?', # MODIF
 	'info_pas_de_forum' => 'kee Forum',
-	'info_question_visiteur_ajout_document_forum' => 'Wann dir de Visiteuren erlaabt Dokumenter (Biller, Toun...) bei Forum-Message bäizeflécken, da gitt hei d’Lëscht vun den Extensiounen un déi erlaabt sinn (z.B.: gif, jpg, png, mp3).',
+	'info_question_visiteur_ajout_document_forum' => 'Wann dir de Visiteuren erlaabt Dokumenter (Biller, Toun...) bei Forum-Message bäizeflécken, da gitt hei d’Lëscht vun den Extensiounen un déi erlaabt sinn (z.B.: gif, jpg, png, mp3).', # MODIF
 	'info_question_visiteur_ajout_document_forum_format' => 'Wann dir all Type wëllt erlaben déi SPIP als sécher ukuckt, dann gitt e Stär an. Fir näischt ze erlaben, gitt näischt an.',
 	'info_selectionner_message' => 'Message wielen:',
 	'interface_formulaire' => 'Formulär-Interface',
 	'interface_onglets' => 'Interface mat Tabs',
-	'item_activer_forum_administrateur' => 'De Forum vun den Adminstrateuren aschalten',
-	'item_config_forums_prive_global' => 'De Redaktor-Forum aschalten',
+	'item_activer_forum_administrateur' => 'De Forum vun den Adminstrateuren aschalten', # MODIF
+	'item_config_forums_prive_global' => 'De Redaktor-Forum aschalten', # MODIF
 	'item_config_forums_prive_objets' => 'Forumen aschalten',
-	'item_desactiver_forum_administrateur' => 'De Forum vun den Administrateuren ofschalten',
-	'item_non_config_forums_prive_global' => 'De Redaktor-Forum ofschalten',
+	'item_desactiver_forum_administrateur' => 'De Forum vun den Administrateuren ofschalten', # MODIF
+	'item_non_config_forums_prive_global' => 'De Redaktor-Forum ofschalten', # MODIF
 	'item_non_config_forums_prive_objets' => 'Forumen ofschalten',
 
 	// L
@@ -116,12 +116,12 @@ return [
 
 	// M
 	'messages_aucun' => 'Keen',
-	'messages_meme_auteur' => 'All d’Message vun dësem Auteur',
+	'messages_meme_auteur' => 'All d’Message vun dësem Auteur', # MODIF
 	'messages_meme_email' => 'All d’Message vun dësem Email',
 	'messages_meme_ip' => 'All d’Message vun dëser IP',
 	'messages_off' => 'Geläscht',
 	'messages_perso' => 'Perséinlech',
-	'messages_privadm' => 'Administrateuren',
+	'messages_privadm' => 'Administrateuren', # MODIF
 	'messages_prive' => 'Privat',
 	'messages_privoff' => 'Geläscht',
 	'messages_privrac' => 'Generell',
@@ -150,7 +150,7 @@ return [
 	'texte_en_cours_validation' => 'Dës Inhalter waarden op Bestätegung.',
 	'texte_en_cours_validation_forum' => 'Sot är Meenung am Forum deen dozou gehéiert.',
 	'texte_messages_publics' => 'Ëffentlech Messagen op:',
-	'titre_cadre_forum_administrateur' => 'Privat-Forum vun den Administrateuren',
+	'titre_cadre_forum_administrateur' => 'Privat-Forum vun den Administrateuren', # MODIF
 	'titre_cadre_forum_interne' => 'Interne Forum',
 	'titre_config_forums_prive' => 'Forume vum privaten Deel',
 	'titre_forum' => 'Forum',
