@@ -13,14 +13,14 @@ return [
 	'bouton_radio_articles_tous' => 'voor alle artikelen zonder uitzondering.',
 	'bouton_radio_articles_tous_sauf_forum_desactive' => 'voor alle artikelen, behalve deze waarvan het forum is gedesactiveerd.',
 	'bouton_radio_enregistrement_obligatoire' => 'Registratie verplicht (om bijdragen te kunnen
-  posten, dienen gebruikers zich eerst in te schrijven en hun e-mailadres aan te leveren).',
-	'bouton_radio_moderation_priori' => 'Vooraf modereren (de bijdragen worden pas gepubliceerd na goedkeuring door een van de beheerders).',
+  posten, dienen gebruikers zich eerst in te schrijven en hun e-mailadres aan te leveren).', # MODIF
+	'bouton_radio_moderation_priori' => 'Vooraf modereren (de bijdragen worden pas gepubliceerd na goedkeuring door een van de beheerders).', # MODIF
 	'bouton_radio_modere_abonnement' => 'op aanvraag',
 	'bouton_radio_modere_posteriori' => 'achteraf modereren',
 	'bouton_radio_modere_priori' => 'vooraf modereren',
 	'bouton_radio_publication_immediate' => 'Onmiddellijke publicatie van berichten
  (bijdragen worden zichtbaar zodra ze verstuurd worden; beheerders kunnen nadien nog steeds
- berichten schrappen).',
+ berichten schrappen).', # MODIF
 
 	// D
 	'documents_interdits_forum' => 'Verboden documenten in het forum',
@@ -43,7 +43,7 @@ return [
 	'forum_cliquer_retour' => 'Klik <a href=\'@retour_forum@\'>hier</a> om door te gaan.',
 	'forum_envoyer' => 'Verzenden',
 	'forum_forum' => 'forum',
-	'forum_info_modere' => 'Dit forum wordt vooraf gemodereerd: je bijdrage zal pas verschijnen nadat een beheerder van de website het heeft goedgekeurd.',
+	'forum_info_modere' => 'Dit forum wordt vooraf gemodereerd: je bijdrage zal pas verschijnen nadat een beheerder van de website het heeft goedgekeurd.', # MODIF
 	'forum_lien_hyper' => 'webverwijzing',
 	'forum_message' => 'Je bericht',
 	'forum_message_definitif' => 'Definitief bericht: versturen',
@@ -86,12 +86,12 @@ return [
  voor het modereren te kiezen:',
 	'info_appliquer_choix_moderation' => 'Pas deze moderatievorm toe:',
 	'info_config_forums_prive' => 'In het privé gedeelte van de site kun je verschillende soorten forums activeren:',
-	'info_config_forums_prive_admin' => 'Een forum dat voor de beheerders van de site is gereserveerd:',
-	'info_config_forums_prive_global' => 'Een globaal forum, open voor alle redacteuren:',
+	'info_config_forums_prive_admin' => 'Een forum dat voor de beheerders van de site is gereserveerd:', # MODIF
+	'info_config_forums_prive_global' => 'Een globaal forum, open voor alle redacteuren:', # MODIF
 	'info_config_forums_prive_objets' => 'Een forum onder elk artikel, elke nieuwsflits, gerefereerde site, enz.:',
 	'info_desactiver_forum_public' => 'Het gebruik van de publieke forums deactiveren.
 De publieke forums kunnen per artikel toegestaan worden. Ze worden niet toegestaan op rubrieken en nieuwsberichten, enz.',
-	'info_envoi_forum' => 'Versturen van de forumbijdragen aan de auteurs van de artikelen',
+	'info_envoi_forum' => 'Versturen van de forumbijdragen aan de auteurs van de artikelen', # MODIF
 	'info_fonctionnement_forum' => 'Werking van het forum:',
 	'info_forcer_previsualisation_court' => 'Forceer een vooruitblik',
 	'info_forcer_previsualisation_long' => 'Forceer een vooruitblik voordat een bericht verzonden wordt',
@@ -106,18 +106,18 @@ De publieke forums kunnen per artikel toegestaan worden. Ze worden niet toegesta
 	'info_liens_titre' => 'Link(s) inbegrepen in het titel van de boodschap',
 	'info_mode_fonctionnement_defaut_forum_public' => 'Standaard werkwijze van de publieke forums',
 	'info_nb_messages_forum' => '@nb@ boodschappen in de forums',
-	'info_option_email' => 'Wanneer een bezoeker van de site een nieuw bericht in het forum opstelt dat aan een artikel is gekoppeld, kunnen de auteurs van het artikel per email over de bijdrage worden geïnformeerd. Geef voor elk soort forum aan of deze keuze moet worden toegepast.',
+	'info_option_email' => 'Wanneer een bezoeker van de site een nieuw bericht in het forum opstelt dat aan een artikel is gekoppeld, kunnen de auteurs van het artikel per email over de bijdrage worden geïnformeerd. Geef voor elk soort forum aan of deze keuze moet worden toegepast.', # MODIF
 	'info_pas_de_forum' => 'geen forum',
-	'info_question_visiteur_ajout_document_forum' => 'Als je de bezoekers documenten (afbeeldingen, geluid…) wil laten toevoegen aan hun forumbijdrage, moet je hieronder de lijst van de toegelaten extensies aangeven (bv: gif, jpg, png, mp3).',
+	'info_question_visiteur_ajout_document_forum' => 'Als je de bezoekers documenten (afbeeldingen, geluid…) wil laten toevoegen aan hun forumbijdrage, moet je hieronder de lijst van de toegelaten extensies aangeven (bv: gif, jpg, png, mp3).', # MODIF
 	'info_question_visiteur_ajout_document_forum_format' => 'Als je alle soorten documenten wilt toestaan die door SPIP als betrouwbaar worden beschouwd, zet je een ster. Om niets toe te staan vul je niets in.',
 	'info_selectionner_message' => 'Selecteer de berichten:',
 	'interface_formulaire' => 'Formulier interface',
 	'interface_onglets' => 'Tab interface',
-	'item_activer_forum_administrateur' => 'Forum van beheerders activeren',
-	'item_config_forums_prive_global' => 'Het redacteurenforum activeren',
+	'item_activer_forum_administrateur' => 'Forum van beheerders activeren', # MODIF
+	'item_config_forums_prive_global' => 'Het redacteurenforum activeren', # MODIF
 	'item_config_forums_prive_objets' => 'Deze forums activeren',
-	'item_desactiver_forum_administrateur' => 'Forum van de beheerders deactiveren',
-	'item_non_config_forums_prive_global' => 'Het forum van de redacteuren deactiveren',
+	'item_desactiver_forum_administrateur' => 'Forum van de beheerders deactiveren', # MODIF
+	'item_non_config_forums_prive_global' => 'Het forum van de redacteuren deactiveren', # MODIF
 	'item_non_config_forums_prive_objets' => 'Deze forums deactiveren',
 
 	// L
@@ -131,12 +131,12 @@ De publieke forums kunnen per artikel toegestaan worden. Ze worden niet toegesta
 
 	// M
 	'messages_aucun' => 'Geen',
-	'messages_meme_auteur' => 'Alle boodschappen van deze auteur',
+	'messages_meme_auteur' => 'Alle boodschappen van deze auteur', # MODIF
 	'messages_meme_email' => 'Alle boodschappen van dit e-mailadres',
 	'messages_meme_ip' => 'Alle boodschappen van dit IP-adres',
 	'messages_off' => 'Verwijderd',
 	'messages_perso' => 'Persoonlijk ',
-	'messages_privadm' => 'Beheerders',
+	'messages_privadm' => 'Beheerders', # MODIF
 	'messages_prive' => 'Privé',
 	'messages_privoff' => 'Verwijderd',
 	'messages_privrac' => 'Algemene',
@@ -165,7 +165,7 @@ De publieke forums kunnen per artikel toegestaan worden. Ze worden niet toegesta
 	'texte_en_cours_validation' => 'Deze inhoud is in afwachting van validatie',
 	'texte_en_cours_validation_forum' => 'Aarzel niet om advies te geven via het gekoppelde forum.',
 	'texte_messages_publics' => 'Openbare berichten op:',
-	'titre_cadre_forum_administrateur' => 'Privé-forum voor beheerders',
+	'titre_cadre_forum_administrateur' => 'Privé-forum voor beheerders', # MODIF
 	'titre_cadre_forum_interne' => 'Intern forum',
 	'titre_config_forums_prive' => 'Forums van het privé gedeelte',
 	'titre_forum' => 'Forum',
