@@ -9,7 +9,7 @@ return [
 	'bouton_radio_articles_futurs' => 'aus articles futurs solament (brisa d’accion sus la basa de donadas).',
 	'bouton_radio_articles_tous' => 'aus articles tots sens excepcion',
 	'bouton_radio_articles_tous_sauf_forum_desactive' => 'a tots los articles, fòra quilhs que lor forum es desactivat.',
-	'bouton_radio_enregistrement_obligatoire' => 'Registrament obligatòri (los utilizaires se deven abonar en donar lor adreiça e-mail avans de poder mandar de las contribucions).',
+	'bouton_radio_enregistrement_obligatoire' => 'Registrament obligatòri (los utilizaires se deven abonar en donar lor adreiça e-mail avans de poder mandar de las contribucions).', # MODIF
 	'bouton_radio_moderation_priori' => 'Moderacion a priòri (las
  contribucions apareissen en public nonmàs se los administrators
  las an validadas).', # MODIF
@@ -18,7 +18,7 @@ return [
 	'bouton_radio_modere_priori' => 'moderat a priòri', # MODIF
 	'bouton_radio_publication_immediate' => 'Publicar los messatges còp sec
  (las contribucions apareissen tanleu mandadas, los administrators las pòden
- suprimir puei).',
+ suprimir puei).', # MODIF
 
 	// F
 	'form_pet_message_commentaire' => 'Un messatge, una remarca?',
@@ -59,7 +59,7 @@ return [
 	'info_activer_forum_public' => '<i>Per activar los forums publics, volhatz chausir lor mòde de moderacion predefinit:</i>', # MODIF
 	'info_appliquer_choix_moderation' => 'Aplicar quela chausida de moderacion:',
 	'info_desactiver_forum_public' => 'Desactivar l’utilizacion daus forums publics. Los forums publics poirán èsser autorizats au cas per cas subre los articles; serán proïbits subre las rubricas, brevas, etc.',
-	'info_envoi_forum' => 'Enviament daus forums aus autors daus articles',
+	'info_envoi_forum' => 'Enviament daus forums aus autors daus articles', # MODIF
 	'info_fonctionnement_forum' => 'Foncionament dau forum:',
 	'info_gauche_suivi_forum_2' => 'La pagina de <i>segut daus forums</i> es un esplech de gestion dau vòstre sit (mas es pas un espaci per discutir o per redigir). Aficha totas las contribucions dau forum public de quel article e vos permet de gerir quelas contribucions.', # MODIF
 	'info_liens_syndiques_3' => 'forums',
@@ -72,8 +72,8 @@ return [
  associat a un article, se’n pòt avisar los autors
  de l’article per e-mail. Desiratz d’utilizar quela opcion?', # MODIF
 	'info_pas_de_forum' => 'Brisa de forum',
-	'item_activer_forum_administrateur' => 'Activar lo forum daus administrators',
-	'item_desactiver_forum_administrateur' => 'Desactivar lo forum daus administrators',
+	'item_activer_forum_administrateur' => 'Activar lo forum daus administrators', # MODIF
+	'item_desactiver_forum_administrateur' => 'Desactivar lo forum daus administrators', # MODIF
 
 	// L
 	'lien_reponse_article' => 'Responsa a l’article',
@@ -90,7 +90,7 @@ return [
 	'repondre_message' => 'Respondre a queu messatge',
 
 	// T
-	'titre_cadre_forum_administrateur' => 'Forum privat daus administrators',
+	'titre_cadre_forum_administrateur' => 'Forum privat daus administrators', # MODIF
 	'titre_cadre_forum_interne' => 'Forum interne',
 	'titre_forum' => 'Forum',
 	'titre_forum_suivi' => 'Segut daus forums',
