@@ -12,12 +12,12 @@ return [
 	'bouton_radio_articles_futurs' => 'ai articles futurs unicament (minga d’accion sus la basa de donadas).',
 	'bouton_radio_articles_tous' => 'a toi lu articles sensa excepcion',
 	'bouton_radio_articles_tous_sauf_forum_desactive' => 'à toi lu articles, levats aquelu que lo fòro es desactivat.',
-	'bouton_radio_enregistrement_obligatoire' => 'Registrament obligatòri (lu utilisaires si devon abonar en donant li sieui adreças e-mail denant de poder postar li contribucions).',
-	'bouton_radio_moderation_priori' => 'Moderacion <i>à priòri</i> (li contribucions apareisson pas publicament après validacion dai administrators).',
+	'bouton_radio_enregistrement_obligatoire' => 'Registrament obligatòri (lu utilisaires si devon abonar en donant li sieui adreças e-mail denant de poder postar li contribucions).', # MODIF
+	'bouton_radio_moderation_priori' => 'Moderacion <i>à priòri</i> (li contribucions apareisson pas publicament après validacion dai administrators).', # MODIF
 	'bouton_radio_modere_abonnement' => 'sus abonament',
 	'bouton_radio_modere_posteriori' => 'moderacion à posteriòri',
 	'bouton_radio_modere_priori' => 'moderacion à priòri',
-	'bouton_radio_publication_immediate' => 'Publicacion immediata dei messatges (li contribucions apareisson sus lo còup que son mandadi, lu administrators li poadon suprimir pi).',
+	'bouton_radio_publication_immediate' => 'Publicacion immediata dei messatges (li contribucions apareisson sus lo còup que son mandadi, lu administrators li poadon suprimir pi).', # MODIF
 
 	// D
 	'documents_interdits_forum' => 'Documents proïbits dins lo fòro',
@@ -40,7 +40,7 @@ return [
 	'forum_cliquer_retour' => 'Clicatz <a href=\'@retour_forum@\'>aquí</a> per continuar.',
 	'forum_envoyer' => 'Mandar',
 	'forum_forum' => 'fòro',
-	'forum_info_modere' => 'Aqueu fòro es moderat à priòri: la voastra contribucion apareisserà après èstre estada validada da un administrator dau site.',
+	'forum_info_modere' => 'Aqueu fòro es moderat à priòri: la voastra contribucion apareisserà après èstre estada validada da un administrator dau site.', # MODIF
 	'forum_lien_hyper' => 'Ligam ipertèxt',
 	'forum_message' => 'Lo voastre messatge',
 	'forum_message_definitif' => 'Messatge definitieu: mandar au sit',
@@ -81,11 +81,11 @@ return [
 	'info_activer_forum_public' => '<i>Per activar lu fòros publics, vorguètz chausir lu sieus mòdos
  de moderacion predefinits:</i>',
 	'info_appliquer_choix_moderation' => 'Aplicar aquela chausida de moderacion :',
-	'info_config_forums_prive_admin' => 'Un fòro reservat ai administrators dau site:',
-	'info_config_forums_prive_global' => 'Un fòro total, duvbert en toi lu redactors:',
+	'info_config_forums_prive_admin' => 'Un fòro reservat ai administrators dau site:', # MODIF
+	'info_config_forums_prive_global' => 'Un fòro total, duvbert en toi lu redactors:', # MODIF
 	'info_config_forums_prive_objets' => 'Un fòro sota cada article, brèva, site referençat, eca.:',
 	'info_desactiver_forum_public' => 'Desactivar l’utilisacion dei fòros publics. Lu fòros publics podràn èstre autorisats au cas per cas sus lu articles; seràn proïbits sus li rubricas, brèvas, eca.',
-	'info_envoi_forum' => 'Mandadís dei fòros ai autors dei articles',
+	'info_envoi_forum' => 'Mandadís dei fòros ai autors dei articles', # MODIF
 	'info_fonctionnement_forum' => 'Foncionament dau fòro :',
 	'info_forcer_previsualisation_court' => 'Forçar la previsualizacion',
 	'info_forums_liees_mot' => 'Lu messatges de fòro ligats en aquèu mòt',
@@ -99,15 +99,15 @@ return [
 	'info_liens_titre' => 'Estac(s) contengut(s) dins lo titre dau messatge',
 	'info_mode_fonctionnement_defaut_forum_public' => 'Mòde de foncionament predefinit dei fòros publics',
 	'info_nb_messages_forum' => '@nb@ messatges de fòro',
-	'info_option_email' => 'Quora un visitaire dau sit poasta un messatge novèu dins lo fòro associat à un article, lu autors de l’article poadon èstre avertits d’aqueu messatge per corrier electronic. Indicatz per cada tipe de fòro se cau utilisar aquela opcion.',
+	'info_option_email' => 'Quora un visitaire dau sit poasta un messatge novèu dins lo fòro associat à un article, lu autors de l’article poadon èstre avertits d’aqueu messatge per corrier electronic. Indicatz per cada tipe de fòro se cau utilisar aquela opcion.', # MODIF
 	'info_pas_de_forum' => 'Minga de fòro',
 	'info_selectionner_message' => 'Selecionar lu messatges :',
 	'interface_formulaire' => 'Interfaça formulàri',
-	'item_activer_forum_administrateur' => 'Activar lo fòro dei administrators',
-	'item_config_forums_prive_global' => 'Activar lo fòro dei redactors',
+	'item_activer_forum_administrateur' => 'Activar lo fòro dei administrators', # MODIF
+	'item_config_forums_prive_global' => 'Activar lo fòro dei redactors', # MODIF
 	'item_config_forums_prive_objets' => 'Activar aquelu fòros',
-	'item_desactiver_forum_administrateur' => 'Desactivar lo fòro dei administrators',
-	'item_non_config_forums_prive_global' => 'Desactivar lo fòro dei redactors',
+	'item_desactiver_forum_administrateur' => 'Desactivar lo fòro dei administrators', # MODIF
+	'item_non_config_forums_prive_global' => 'Desactivar lo fòro dei redactors', # MODIF
 	'item_non_config_forums_prive_objets' => 'Desactivar aquelu fòros',
 
 	// L
@@ -121,12 +121,12 @@ return [
 
 	// M
 	'messages_aucun' => 'Minga',
-	'messages_meme_auteur' => 'Toi lu messatges d’aquel autor',
+	'messages_meme_auteur' => 'Toi lu messatges d’aquel autor', # MODIF
 	'messages_meme_email' => 'Toi lu messatges d’aquel mèl',
 	'messages_meme_ip' => 'Toi lu messatges d’aquela IP',
 	'messages_off' => 'Suprimits',
 	'messages_perso' => 'Personaus',
-	'messages_privadm' => 'Administrators',
+	'messages_privadm' => 'Administrators', # MODIF
 	'messages_prive' => 'Privats',
 	'messages_privoff' => 'Suprimits',
 	'messages_privrac' => 'Generaus',
@@ -150,7 +150,7 @@ return [
 
 	// T
 	'texte_messages_publics' => 'Messatges publics sus:',
-	'titre_cadre_forum_administrateur' => 'Fòro privat dei administrators',
+	'titre_cadre_forum_administrateur' => 'Fòro privat dei administrators', # MODIF
 	'titre_cadre_forum_interne' => 'Fòro interne',
 	'titre_config_forums_prive' => 'Fòros de l’espaci privat',
 	'titre_forum' => 'Fòro',
