@@ -9,7 +9,7 @@ return [
 	'bouton_radio_articles_futurs' => 'ren qu’ais articles futurs (ges d’accion sus la basa de donadas).',
 	'bouton_radio_articles_tous' => 'ais articles totei sens excepcion',
 	'bouton_radio_articles_tous_sauf_forum_desactive' => 'a totei leis articles, levat lei que son forum es desactivat.',
-	'bouton_radio_enregistrement_obligatoire' => 'Registrament obligatòri (leis utilizaires se devon abonar en donant son adreiça e-mail avans de poder mandar de contribucions).',
+	'bouton_radio_enregistrement_obligatoire' => 'Registrament obligatòri (leis utilizaires se devon abonar en donant son adreiça e-mail avans de poder mandar de contribucions).', # MODIF
 	'bouton_radio_moderation_priori' => 'Moderacion a priòri (lei
  contribucions apareisson en public ren que se leis administrators
  leis an validadas).', # MODIF
@@ -18,7 +18,7 @@ return [
 	'bouton_radio_modere_priori' => 'moderat a priòri', # MODIF
 	'bouton_radio_publication_immediate' => 'Publicar lei messatges sus lo còp
  (lei contribucions apareisson tre mandadas, leis administrators lei pòdon
- suprimir puei).',
+ suprimir puei).', # MODIF
 
 	// F
 	'form_pet_message_commentaire' => 'Un messatge, una remarca?',
@@ -59,7 +59,7 @@ return [
 	'info_activer_forum_public' => '<i>Per activar lei forums publics, vougatz chausir son mòde de moderacion predefinit:</i>', # MODIF
 	'info_appliquer_choix_moderation' => 'Aplicar aquela chausida de moderacion:',
 	'info_desactiver_forum_public' => 'Desactivar l’utilizacion dei forums publics. Lei forums publics poiràn èsser autorizats au cas per cas subre leis articles; seràn proïbits subre lei rubricas, brèvas, etc.',
-	'info_envoi_forum' => 'Mandadís dei forums ais autors deis articles',
+	'info_envoi_forum' => 'Mandadís dei forums ais autors deis articles', # MODIF
 	'info_fonctionnement_forum' => 'Foncionament dau forum:',
 	'info_gauche_suivi_forum_2' => 'La pagina de <i>seguit dei forums</i> es una aisina de gestion dau vòstre sit (mai es pas un espaci per discutir o per redigir). Aficha totei lei contribucions dau forum public d’aquel article e vos permet de gerir aquelei contribucions.', # MODIF
 	'info_liens_syndiques_3' => 'forums',
@@ -72,8 +72,8 @@ return [
  associat a un article, se’n pòt avisar leis autors
  de l’article per e-mail. Desiratz d’utilizar aquela opcion?', # MODIF
 	'info_pas_de_forum' => 'Ges de forum',
-	'item_activer_forum_administrateur' => 'Activar lo forum deis administrators',
-	'item_desactiver_forum_administrateur' => 'Desactivar lo forum deis administrators',
+	'item_activer_forum_administrateur' => 'Activar lo forum deis administrators', # MODIF
+	'item_desactiver_forum_administrateur' => 'Desactivar lo forum deis administrators', # MODIF
 
 	// L
 	'lien_reponse_article' => 'Respònsa a l’article',
@@ -90,7 +90,7 @@ return [
 	'repondre_message' => 'Respòndre a aqueu messatge',
 
 	// T
-	'titre_cadre_forum_administrateur' => 'Forum privat deis administrators',
+	'titre_cadre_forum_administrateur' => 'Forum privat deis administrators', # MODIF
 	'titre_cadre_forum_interne' => 'Forum intèrne',
 	'titre_forum' => 'Forum',
 	'titre_forum_suivi' => 'Seguit dei forums',
