@@ -12,13 +12,13 @@ return [
 	'bouton_radio_articles_futurs' => 'apenas às próximas matérias (sem ação sobre a base de dados).',
 	'bouton_radio_articles_tous' => 'a todas as matérias, sem exceção.',
 	'bouton_radio_articles_tous_sauf_forum_desactive' => 'a todas as matérias, exceto aquelas em que o fórum está desativado.',
-	'bouton_radio_enregistrement_obligatoire' => 'Cadastro obrigatório (os usuários devem se cadastrar, fornecendo seu e-mail, antes de poderem enviar suas contribuições).', # MODIF
-	'bouton_radio_moderation_priori' => 'Moderação prévia (as contribuições só serão exibidas publicamente após a aprovação dos administradores).', # MODIF
+	'bouton_radio_enregistrement_obligatoire' => 'Cadastro obrigatório (os visitantes devem se inscrever, fornecendo o seu endereço de e-mail, antes de poderem postar suas contribuições).',
+	'bouton_radio_moderation_priori' => 'Moderação prévia (as contribuições só serão exibidas publicamente após a aprovação dos admins).',
 	'bouton_radio_modere_abonnement' => 'por assinatura',
 	'bouton_radio_modere_posteriori' => 'moderação a posteriori',
 	'bouton_radio_modere_priori' => 'moderação a priori',
 	'bouton_radio_publication_immediate' => 'Publicação imediata das mensagens
- (as contribuições serão exibidas assim que forem enviadas; os administradores poderão excluí-las em seguida).', # MODIF
+ (as contribuições serão exibidas assim que forem enviadas; os administradores poderão excluí-las posteriormente).',
 
 	// D
 	'documents_interdits_forum' => 'Documentos proibídos no fórum',
@@ -41,7 +41,7 @@ return [
 	'forum_cliquer_retour' => 'Clique <a href=\'@retour_forum@\'>aqui</a> para continuar.',
 	'forum_envoyer' => 'Enviar',
 	'forum_forum' => 'fórum',
-	'forum_info_modere' => 'Este fórum é moderado a priori: a sua contribuição só será exibida após ser validada por um administrador do site.', # MODIF
+	'forum_info_modere' => 'Este fórum é moderado previamente: a sua contribuição só será exibida após ser validada pelos responsáveis.',
 	'forum_lien_hyper' => 'Link hipertexto',
 	'forum_message' => 'Sua mensagem',
 	'forum_message_definitif' => 'Mensagem definitiva: enviar para o site',
@@ -80,11 +80,11 @@ return [
 	'info_activer_forum_public' => 'Para ativar os fóruns públicos, por favor, escolha o modo de moderação padrão:',
 	'info_appliquer_choix_moderation' => 'Atribuir esta escolha de moderação:',
 	'info_config_forums_prive' => 'Na área restrita do site, você pode ativar diversos tipos de fóruns:',
-	'info_config_forums_prive_admin' => 'Um fórum reservado aos administradores do site:', # MODIF
-	'info_config_forums_prive_global' => 'Um fórum global, aberto a todos os redatores:', # MODIF
+	'info_config_forums_prive_admin' => 'Um fórum reservado aos admins do site:',
+	'info_config_forums_prive_global' => 'Um fórum global, aberto a todos os redatores:',
 	'info_config_forums_prive_objets' => 'Um fórum para cada matéria, nota, site referenciado etc.:',
 	'info_desactiver_forum_public' => 'Desativar o uso dos fóruns públicos. Os fóruns públicos poderão ser autorizados caso a caso apenas nas matérias; não serão permitidos nas seções, notas etc.',
-	'info_envoi_forum' => 'Envio dos fóruns aos autores das matérias', # MODIF
+	'info_envoi_forum' => 'Envio dos fóruns aos autores das matérias',
 	'info_fonctionnement_forum' => 'Funcionamento do fórum:',
 	'info_forcer_previsualisation_court' => 'Forçar a previsualização',
 	'info_forcer_previsualisation_long' => 'Forçar a previsualização antes de enviar a mensagem',
@@ -99,18 +99,18 @@ return [
 	'info_liens_titre' => 'Link(s) contido(s) no título da mensagem',
 	'info_mode_fonctionnement_defaut_forum_public' => 'Modo de funcionamento padrão dos fóruns públicos',
 	'info_nb_messages_forum' => '@nb@ mensagens de fórum',
-	'info_option_email' => 'Sempre que um visitante postar uma nova mensagem no fórum associado a uma matéria, os autores da matéria podem ser avisados dessa mensagem por e-mail. Informe para cada tipo de fórum se esta oção deve ser usada.', # MODIF
+	'info_option_email' => 'Sempre que uma nova mensagem for postada no fórum associado a uma matéria, os autores da matéria podem ser notificados dessa postagem por e-mail. Informe, para cada tipo de fórum, se esta oção deve ser usada.',
 	'info_pas_de_forum' => 'sem fórum',
-	'info_question_visiteur_ajout_document_forum' => 'Se você deseja autorizar os visitantes a anexarem documentos (imagens, áudios...) às suas mensagens em fóruns, indique abaixo a lista das extensões de arquivos permitidos para os fóruns (ex.: gif, jpg, png, mp3).', # MODIF
+	'info_question_visiteur_ajout_document_forum' => 'Se você deseja autorizar a anexação de documentos (imagens, áudios...) nas mensagens de fórun, indique abaixo a lista das extensões de arquivos permitidos (ex.: gif, jpg, png, mp3).',
 	'info_question_visiteur_ajout_document_forum_format' => 'Se você deseja permitir todos os tipos de documentos considerados como seguros pelo SPIP, digite * (asterisco). Para não permitir nenhum, deixe em branco.',
 	'info_selectionner_message' => 'Selecione as mensagens:',
 	'interface_formulaire' => 'Interface de formulário',
 	'interface_onglets' => 'Interface com abas',
-	'item_activer_forum_administrateur' => 'Ativar o fórum dos administradores', # MODIF
-	'item_config_forums_prive_global' => 'Ativar os fóruns dos redatores', # MODIF
+	'item_activer_forum_administrateur' => 'Ativar o fórum dos admins',
+	'item_config_forums_prive_global' => 'Ativar o fórum da redação',
 	'item_config_forums_prive_objets' => 'Ativar estes fóruns',
-	'item_desactiver_forum_administrateur' => 'Desativar o fórum dos administradores', # MODIF
-	'item_non_config_forums_prive_global' => 'Desativar o fórum dos redatores', # MODIF
+	'item_desactiver_forum_administrateur' => 'Desativar o fórum dos admins',
+	'item_non_config_forums_prive_global' => 'Desativar o fórum da redação',
 	'item_non_config_forums_prive_objets' => 'Desativar estes fóruns',
 
 	// L
@@ -124,12 +124,12 @@ return [
 
 	// M
 	'messages_aucun' => 'Nenhuma',
-	'messages_meme_auteur' => 'Todas as mensagens deste autor', # MODIF
+	'messages_meme_auteur' => 'Todas as mensagens desta pessoa',
 	'messages_meme_email' => 'Todas as mensagens deste e-mail',
 	'messages_meme_ip' => 'Todas as mensagens desse IP',
 	'messages_off' => 'Apagadas',
 	'messages_perso' => 'Pessoais',
-	'messages_privadm' => 'Administradores', # MODIF
+	'messages_privadm' => 'Admins',
 	'messages_prive' => 'Particulares',
 	'messages_privoff' => 'Apagadas',
 	'messages_privrac' => 'Gerais',
@@ -158,7 +158,7 @@ return [
 	'texte_en_cours_validation' => 'Os conteúdos a seguir estão aguardando aprovação.',
 	'texte_en_cours_validation_forum' => 'Não hesite a dar a sua opinião sobre as mesmas nos fóruns a elas associados.',
 	'texte_messages_publics' => 'Mensagens publicas de:',
-	'titre_cadre_forum_administrateur' => 'Fórum privado dos administradores', # MODIF
+	'titre_cadre_forum_administrateur' => 'Fórum privado dos admins',
 	'titre_cadre_forum_interne' => 'Fórum interno',
 	'titre_config_forums_prive' => 'Fóruns da área privada',
 	'titre_forum' => 'Fórum',
