@@ -12,15 +12,15 @@ return [
 	'bouton_radio_articles_futurs' => 'len pre budúce články (žiadna zmena databázy).',
 	'bouton_radio_articles_tous' => 'pre všetky články bez výnimky.',
 	'bouton_radio_articles_tous_sauf_forum_desactive' => 'pre všetky články, okrem tých s deaktivovanými diskusnými fórami.',
-	'bouton_radio_enregistrement_obligatoire' => 'Vyžaduje sa registrácia (používatelia sa musia zaregistrovať uvedením svojej e-mailovej adresy predtým, ako budú môcť posielať príspevky).',
+	'bouton_radio_enregistrement_obligatoire' => 'Vyžaduje sa registrácia (používatelia sa musia zaregistrovať uvedením svojej e-mailovej adresy predtým, ako budú môcť posielať príspevky).', # MODIF
 	'bouton_radio_moderation_priori' => 'Kontrola pred zverejnením (príspevky sa zobrazia až potom, čo ich
- schvália administrátori).',
+ schvália administrátori).', # MODIF
 	'bouton_radio_modere_abonnement' => 'Vyžaduje sa registrácia',
 	'bouton_radio_modere_posteriori' => 'kontrola po zverejnení',
 	'bouton_radio_modere_priori' => 'kontrola pred zverejnením',
 	'bouton_radio_publication_immediate' => 'Okamžité publikovanie príspevkov
  (príspevky sa zobrazia len čo budú odoslané; ak bude treba, administrátori
- ich môžu potom odstrániť).',
+ ich môžu potom odstrániť).', # MODIF
 
 	// D
 	'documents_interdits_forum' => 'Dokumenty nie sú v tomto diskusnom fóre povolené',
@@ -43,7 +43,7 @@ return [
 	'forum_cliquer_retour' => 'Kliknite <a href=\'@retour_forum@\'>sem,</a> aby ste mohli pokračovať.',
 	'forum_envoyer' => 'Poslať',
 	'forum_forum' => 'diskusné fórum',
-	'forum_info_modere' => 'Toto diskusné fórum sa kontroluje pred zverejnením: váš príspevok sa zobrazí až potom, čo ho potvrdí administrátor stránky.',
+	'forum_info_modere' => 'Toto diskusné fórum sa kontroluje pred zverejnením: váš príspevok sa zobrazí až potom, čo ho potvrdí administrátor stránky.', # MODIF
 	'forum_lien_hyper' => 'Hypertextový odkaz',
 	'forum_message' => 'Váš príspevok',
 	'forum_message_definitif' => 'Koniec úprav: poslať príspevok',
@@ -84,13 +84,13 @@ return [
 	'info_activer_forum_public' => '<i>Ak chcete povoliť verejné diskusné fóra, prosím, uveďte predvolený spôsob ich riadenia:</i>',
 	'info_appliquer_choix_moderation' => 'Použiť tento výber riadenia:',
 	'info_config_forums_prive' => 'V súkromnej zóne môžete aktivovať rôzne typy diskusných fór:',
-	'info_config_forums_prive_admin' => 'Diskusné fórum vyhradené pre administrátorov:',
-	'info_config_forums_prive_global' => 'Globálne diskusné fórum otvorené všetkým autorom:',
+	'info_config_forums_prive_admin' => 'Diskusné fórum vyhradené pre administrátorov:', # MODIF
+	'info_config_forums_prive_global' => 'Globálne diskusné fórum otvorené všetkým autorom:', # MODIF
 	'info_config_forums_prive_objets' => 'Diskusné fórum pripojené ku každému článku, každej novinke, odkazovanej stránke, atď.:',
 	'info_desactiver_forum_public' => 'Deaktivovať používanie verejných
  diskusných fór. Verejné diskusné fóra sa dajú povoliť na individuálnej báze
  pri článkoch; budú zakázané pre rubriky, novinky a pod.',
-	'info_envoi_forum' => 'Posielať príspevky z diskusného fóra príslušným autorom',
+	'info_envoi_forum' => 'Posielať príspevky z diskusného fóra príslušným autorom', # MODIF
 	'info_fonctionnement_forum' => 'Nastavenie diskusného fóra:',
 	'info_forcer_previsualisation_court' => 'Nanútiť zobrazenie ukážky',
 	'info_forcer_previsualisation_long' => 'Pred odoslaním správy zobraziť ukážku',
@@ -105,18 +105,18 @@ return [
 	'info_liens_titre' => 'Obsah odkazu (-ov) v názve príspevku',
 	'info_mode_fonctionnement_defaut_forum_public' => 'Predvolený režim verejných diskusných fór',
 	'info_nb_messages_forum' => '@nb@ príspevkov v diskusnom fóre',
-	'info_option_email' => 'Keď návštevník pošle príspevok do diskusného fóra článku, autor článku môže byť o tom informovaný e-mailom. Pre každý typ diskusného fóra uveďte, či sa má táto možnosť aktivovať.',
+	'info_option_email' => 'Keď návštevník pošle príspevok do diskusného fóra článku, autor článku môže byť o tom informovaný e-mailom. Pre každý typ diskusného fóra uveďte, či sa má táto možnosť aktivovať.', # MODIF
 	'info_pas_de_forum' => 'žiadne diskusné fórum',
-	'info_question_visiteur_ajout_document_forum' => 'Ak chcete povoliť návštevníkom pripájať súbory (obrázky, zvuky a i.) k diskusným príspevkom, určte, ktoré prípony súborov budú akceptované (napr. gif, jpg, png, mp3).',
+	'info_question_visiteur_ajout_document_forum' => 'Ak chcete povoliť návštevníkom pripájať súbory (obrázky, zvuky a i.) k diskusným príspevkom, určte, ktoré prípony súborov budú akceptované (napr. gif, jpg, png, mp3).', # MODIF
 	'info_question_visiteur_ajout_document_forum_format' => 'Ak chcete povoliť všetky typy súborov, ktoré SPIP považuje za bezpečné, použite hviezdičku. Ak nechcete povoliť žiadne, nerobte nič.',
 	'info_selectionner_message' => 'Vybrať príspevky:',
 	'interface_formulaire' => 'Rozhranie formulára',
 	'interface_onglets' => 'Rozhranie s tabulátormi',
-	'item_activer_forum_administrateur' => 'Povoliť diskusné fórum administrátorov',
-	'item_config_forums_prive_global' => 'Aktivovať diskusné fórum autorov',
+	'item_activer_forum_administrateur' => 'Povoliť diskusné fórum administrátorov', # MODIF
+	'item_config_forums_prive_global' => 'Aktivovať diskusné fórum autorov', # MODIF
 	'item_config_forums_prive_objets' => 'Aktivovať tieto diskusné fóra',
-	'item_desactiver_forum_administrateur' => 'Deaktivovať diskusné fórum administrátorov',
-	'item_non_config_forums_prive_global' => 'Deaktivovať diskusné fórum autorov',
+	'item_desactiver_forum_administrateur' => 'Deaktivovať diskusné fórum administrátorov', # MODIF
+	'item_non_config_forums_prive_global' => 'Deaktivovať diskusné fórum autorov', # MODIF
 	'item_non_config_forums_prive_objets' => 'Deaktivovať tieto diskusné fóra',
 
 	// L
@@ -130,12 +130,12 @@ return [
 
 	// M
 	'messages_aucun' => 'Žiadne',
-	'messages_meme_auteur' => 'Všetky príspevky od tohto autora',
+	'messages_meme_auteur' => 'Všetky príspevky od tohto autora', # MODIF
 	'messages_meme_email' => 'Všetky príspevky z tohto e-mailu',
 	'messages_meme_ip' => 'Všetky príspevky z tejto IP',
 	'messages_off' => 'Vymazané',
 	'messages_perso' => 'Súkromné',
-	'messages_privadm' => 'Administrátori',
+	'messages_privadm' => 'Administrátori', # MODIF
 	'messages_prive' => 'Súkromné',
 	'messages_privoff' => 'Vymazané',
 	'messages_privrac' => 'Všeobecné',
@@ -164,7 +164,7 @@ return [
 	'texte_en_cours_validation' => 'Články, novinky, diskusné fóra uvedené nižšie boli odoslané na publikovanie.',
 	'texte_en_cours_validation_forum' => 'V pripojených diskusných fórach môžete smelo napísať komentár.',
 	'texte_messages_publics' => 'Verejné príspevky na:',
-	'titre_cadre_forum_administrateur' => 'Súkromné diskusné fórum administrátorov',
+	'titre_cadre_forum_administrateur' => 'Súkromné diskusné fórum administrátorov', # MODIF
 	'titre_cadre_forum_interne' => 'Interné diskusné fórum',
 	'titre_config_forums_prive' => 'Diskusné fóra v súkromnej zóne',
 	'titre_forum' => 'Diskusné fórum',
