@@ -9,12 +9,12 @@ return [
 	'bouton_radio_articles_futurs' => 'endast för framtida artiklar (ingen inverkan på databasen).',
 	'bouton_radio_articles_tous' => 'på alla artiklar utan undantag.',
 	'bouton_radio_articles_tous_sauf_forum_desactive' => 'på alla artiklar utom de utan forum.',
-	'bouton_radio_enregistrement_obligatoire' => 'Krav på registrering (användare måste registrera sig genom att tillhandahålla sin e-postadress innan de kan bidra).  being able to post contributions).',
+	'bouton_radio_enregistrement_obligatoire' => 'Krav på registrering (användare måste registrera sig genom att tillhandahålla sin e-postadress innan de kan bidra).  being able to post contributions).', # MODIF
 	'bouton_radio_moderation_priori' => 'Moderering i förhand (bidrag visas endast efter att de godkänts av en administatör).', # MODIF
 	'bouton_radio_modere_abonnement' => 'registrering krävs',
 	'bouton_radio_modere_posteriori' => 'moderering i efterhand', # MODIF
 	'bouton_radio_modere_priori' => 'moderering i förhand', # MODIF
-	'bouton_radio_publication_immediate' => 'Omedelbar publicering av meddelanden (bidrag visas direkt efter att de skickas, administratörer kan radera dom senare):',
+	'bouton_radio_publication_immediate' => 'Omedelbar publicering av meddelanden (bidrag visas direkt efter att de skickas, administratörer kan radera dom senare):', # MODIF
 
 	// D
 	'documents_interdits_forum' => 'Dokument är inte tillåtna i forumet',
@@ -61,7 +61,7 @@ return [
 	'info_desactiver_forum_public' => 'Avaktivera de publika forumen.
  Publika forum kan tillåtas  för
  enskilda artiklar; de kommer inte att vara aktiva för avdelningae, nyheter, osv.',
-	'info_envoi_forum' => 'Skicka foruminlägg till artikelredaktörerna',
+	'info_envoi_forum' => 'Skicka foruminlägg till artikelredaktörerna', # MODIF
 	'info_liens_syndiques_3' => 'forum',
 	'info_liens_syndiques_4' => 'är',
 	'info_liens_syndiques_5' => 'forum',
@@ -69,11 +69,11 @@ return [
 	'info_liens_syndiques_7' => 'i väntan på validering.',
 	'info_mode_fonctionnement_defaut_forum_public' => 'Valt funktionssätt för de publika forumen',
 	'info_pas_de_forum' => 'inget forum',
-	'item_activer_forum_administrateur' => 'Aktivera administratörernas forum',
-	'item_config_forums_prive_global' => 'Aktivera redaktörernas forum',
+	'item_activer_forum_administrateur' => 'Aktivera administratörernas forum', # MODIF
+	'item_config_forums_prive_global' => 'Aktivera redaktörernas forum', # MODIF
 	'item_config_forums_prive_objets' => 'Aktivera dessa forum',
-	'item_desactiver_forum_administrateur' => 'Avaktivera administratörernas forum',
-	'item_non_config_forums_prive_global' => 'Avaktivera redaktörernas forum',
+	'item_desactiver_forum_administrateur' => 'Avaktivera administratörernas forum', # MODIF
+	'item_non_config_forums_prive_global' => 'Avaktivera redaktörernas forum', # MODIF
 	'item_non_config_forums_prive_objets' => 'Avaktivera dessa forum',
 
 	// L
@@ -93,7 +93,7 @@ return [
 	'statut_original' => 'original',
 
 	// T
-	'titre_cadre_forum_administrateur' => 'Administratörernas privata forum ',
+	'titre_cadre_forum_administrateur' => 'Administratörernas privata forum ', # MODIF
 	'titre_cadre_forum_interne' => 'Internt forum',
 	'titre_forum' => 'Forum',
 ];
