@@ -9,12 +9,12 @@ return [
 	'bouton_radio_articles_futurs' => 'chỉ tác động đến bài vở mới (không làm thay đổi database) ',
 	'bouton_radio_articles_tous' => 'cho tất cả bài vở.',
 	'bouton_radio_articles_tous_sauf_forum_desactive' => 'cho tất cả bài vở trừ những bài không có diễn đàn.',
-	'bouton_radio_enregistrement_obligatoire' => 'Phải ghi danh (độc giả phải ghi tên và cho địa chỉ email trước khi gửi thư tín vào diễn đàn).',
+	'bouton_radio_enregistrement_obligatoire' => 'Phải ghi danh (độc giả phải ghi tên và cho địa chỉ email trước khi gửi thư tín vào diễn đàn).', # MODIF
 	'bouton_radio_moderation_priori' => 'Phải được chấp thuận trước (thư tín chỉ được đăng sau khi được quản trị viên chấp thuận).', # MODIF
 	'bouton_radio_modere_abonnement' => 'ghi danh mới được đăng',
 	'bouton_radio_modere_posteriori' => 'đăng trước, xét sau', # MODIF
 	'bouton_radio_modere_priori' => 'xét trước, đăng sau', # MODIF
-	'bouton_radio_publication_immediate' => 'Phát hành thư tín ngay lập tức (thư gửi đi sẽ hiện lên ngay, quản trị viên có thể xóa chúng sau đó).',
+	'bouton_radio_publication_immediate' => 'Phát hành thư tín ngay lập tức (thư gửi đi sẽ hiện lên ngay, quản trị viên có thể xóa chúng sau đó).', # MODIF
 
 	// F
 	'form_pet_message_commentaire' => 'Có nhắn tin hay bình luận gì không?',
@@ -53,7 +53,7 @@ return [
 	'info_activer_forum_public' => '<i>Để diễn đàn công cộng hoạt động, xin chọn một trong những phương thức điều hợp sau đây</i>', # MODIF
 	'info_appliquer_choix_moderation' => 'Dùng phương thức điều hợp này:',
 	'info_desactiver_forum_public' => 'Khóa việc sử dụng diễn đàn công cộng. Diễn đàn công cộng có thể được cho phép theo từng trường hợp một cho các bài vở; tuy nhiên sẽ cấm không được dùng cho các đề mục, tin ngắn, v.v...',
-	'info_envoi_forum' => 'Gửi thư tín diễn đàn đến tác giả bài viết',
+	'info_envoi_forum' => 'Gửi thư tín diễn đàn đến tác giả bài viết', # MODIF
 	'info_fonctionnement_forum' => 'Thao tác của diễn đàn: ',
 	'info_gauche_suivi_forum_2' => 'Trang <i>Quản trị Diễn Đàn</i> là một phương tiện quản trị của trang web (không dùng để trao đổi hay sửa đổi). Trang này liệt kê tất cả mọi thư tín trong diễn đàn công cộng của bài này và cho phép bạn quản trị những thư tín này.', # MODIF
 	'info_liens_syndiques_3' => ' diễn đàn',
@@ -64,8 +64,8 @@ return [
 	'info_mode_fonctionnement_defaut_forum_public' => 'Cách thức điều hành định sẵn của diễn đàn công',
 	'info_option_email' => 'Khi một vị khách gửi thư tín vào diễn đàn có liên hệ tới một bài viết, tác giả bài viết đó có thể được thông báo qua email. Bạn có muốn dùng đặc điểm này không? ', # MODIF
 	'info_pas_de_forum' => 'không có diễn đàn',
-	'item_activer_forum_administrateur' => 'Mở diễn đàn quản trị',
-	'item_desactiver_forum_administrateur' => 'Khóa diễn đàn quản trị viên',
+	'item_activer_forum_administrateur' => 'Mở diễn đàn quản trị', # MODIF
+	'item_desactiver_forum_administrateur' => 'Khóa diễn đàn quản trị viên', # MODIF
 
 	// L
 	'lien_reponse_article' => 'Hồi âm bài này',
@@ -82,7 +82,7 @@ return [
 	'repondre_message' => 'Trả lời mẫu tin này',
 
 	// T
-	'titre_cadre_forum_administrateur' => 'Diễn đàn dành riêng cho quản trị viên',
+	'titre_cadre_forum_administrateur' => 'Diễn đàn dành riêng cho quản trị viên', # MODIF
 	'titre_cadre_forum_interne' => 'Diễn đàn nội bộ',
 	'titre_forum' => 'Diễn đàn',
 	'titre_forum_suivi' => 'Quản trị Diễn đàn',
