@@ -11,7 +11,7 @@ return [
 	'bouton_radio_articles_tous_sauf_forum_desactive' => '为所有文章,除了那些论坛尚未激活的.',
 	'bouton_radio_enregistrement_obligatoire' => '必须注册 
 (在能发表出版物前
-用户必须提供电子邮件订阅).',
+用户必须提供电子邮件订阅).', # MODIF
 	'bouton_radio_moderation_priori' => '预存 (
  出版物只能管理员确认
  才能显示出来).', # MODIF
@@ -20,7 +20,7 @@ return [
 	'bouton_radio_modere_priori' => '预存前', # MODIF
 	'bouton_radio_publication_immediate' => '直接消息出版物
  (投稿发送后可显示, 管理员可以
- 删除它们).',
+ 删除它们).', # MODIF
 
 	// F
 	'form_pet_message_commentaire' => '其它消息和评论?',
@@ -61,7 +61,7 @@ return [
 	'info_desactiver_forum_public' => '停用公共论坛.
  公共论坛只能通过一篇一篇文章的访问;
 它们的专栏和简要等将被禁止.',
-	'info_envoi_forum' => '发送论坛给文章作者 ',
+	'info_envoi_forum' => '发送论坛给文章作者 ', # MODIF
 	'info_fonctionnement_forum' => '论坛操作:',
 	'info_gauche_suivi_forum_2' => ' <i>论坛跟踪</i> 页是你站点的一个管理工具(不是讨论或编辑). 它显示这篇文章的所有论坛出版物并允许你管理这些出版物.', # MODIF
 	'info_liens_syndiques_3' => '论坛',
@@ -74,8 +74,8 @@ return [
   , 文章的作者能被电子邮件通知
   . 你愿意用这个选项吗?', # MODIF
 	'info_pas_de_forum' => '没有论坛',
-	'item_activer_forum_administrateur' => '激活管理者论坛',
-	'item_desactiver_forum_administrateur' => '使管理论坛不可用',
+	'item_activer_forum_administrateur' => '激活管理者论坛', # MODIF
+	'item_desactiver_forum_administrateur' => '使管理论坛不可用', # MODIF
 
 	// L
 	'lien_reponse_article' => '回应文章',
@@ -92,7 +92,7 @@ return [
 	'repondre_message' => '回复消息',
 
 	// T
-	'titre_cadre_forum_administrateur' => '管理者私有论坛',
+	'titre_cadre_forum_administrateur' => '管理者私有论坛', # MODIF
 	'titre_cadre_forum_interne' => '内部论坛',
 	'titre_forum' => '内部论坛',
 	'titre_forum_suivi' => '论坛跟踪',
