@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-forum?lang_cible=ar
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// F
 	'forum_description' => 'منتدى SPIP (الخاص والعمومي)',
-	'forum_slogan' => 'إدارة المنتديات الخاصة والعمومي في SPIP'
-);
+	'forum_slogan' => 'إدارة المنتديات الخاصة والعمومي في SPIP',
+];
