@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-forum?lang_cible=ast
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// F
 	'forum_description' => 'Foru de SPIP (priváu y públicu)',
-	'forum_slogan' => 'Alministración de foros privaos y públicos en SPIP'
-);
+	'forum_slogan' => 'Alministración de foros privaos y públicos en SPIP',
+];
