@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-forum?lang_cible=br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// F
 	'forum_description' => 'SPIP forum (prevez ha publik)',
-	'forum_slogan' => 'Merañ ar foromoù preves ha foran e-barzh SPIP'
-);
+	'forum_slogan' => 'Merañ ar foromoù preves ha foran e-barzh SPIP',
+];
