@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-forum?lang_cible=en
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// F
 	'forum_description' => 'SPIP’s forum (private and public)',
-	'forum_slogan' => 'Management of private and public forums in SPIP'
-);
+	'forum_slogan' => 'Management of private and public forums in SPIP',
+];
