@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-forum?lang_cible=fa
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// F
 	'forum_description' => 'سخنگاه اسپيپ (خصوصي همگاني)؟',
-	'forum_slogan' => 'مديريت سخنگاه‌هاي خصوصي و همگاني در اسپيپ'
-);
+	'forum_slogan' => 'مديريت سخنگاه‌هاي خصوصي و همگاني در اسپيپ',
+];
