@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-forum?lang_cible=fr_fem
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// F
 	'forum_description' => 'Forum de SPIP (privé et public)',
-	'forum_slogan' => 'Gestion des forums privés et publics dans SPIP'
-);
+	'forum_slogan' => 'Gestion des forums privés et publics dans SPIP',
+];
