@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-forum?lang_cible=it
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// F
 	'forum_description' => 'Forum di SPIP (privati e pubblici)',
-	'forum_slogan' => 'Gestione dei forum privati e pubblici di SPIP'
-);
+	'forum_slogan' => 'Gestione dei forum privati e pubblici di SPIP',
+];
