@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-forum?lang_cible=ja
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// F
 	'forum_description' => 'SPIPの掲示板（プライベートと公開）',
-	'forum_slogan' => 'SPIPの掲示板（プライベートと公開）の管理'
-);
+	'forum_slogan' => 'SPIPの掲示板（プライベートと公開）の管理',
+];
