@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-forum?lang_cible=lb
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// F
 	'forum_description' => 'SPIP-Forum (privat an ëffentlech)',
-	'forum_slogan' => 'Beaarbechte vun de privaten an ëffentleche Forumen am SPIP'
-);
+	'forum_slogan' => 'Beaarbechte vun de privaten an ëffentleche Forumen am SPIP',
+];
