@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-forum?lang_cible=nl
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// F
 	'forum_description' => 'Forum van SPIP (privé en openbaar)',
-	'forum_slogan' => 'Beheer van de privé en openbare SPIP forums'
-);
+	'forum_slogan' => 'Beheer van de privé en openbare SPIP forums',
+];
