@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-forum?lang_cible=oc_ni_mis
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// F
 	'forum_description' => 'Fòrou de SPIP (privat e pùblicou)',
-	'forum_slogan' => 'Gestioun dei fòrou privat e pùblicou en SPIP'
-);
+	'forum_slogan' => 'Gestioun dei fòrou privat e pùblicou en SPIP',
+];
