@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-forum?lang_cible=uk
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// F
 	'forum_description' => 'Форуми у SPIP (загальні і редакційні)',
-	'forum_slogan' => 'Управління загальними і редакційними форумами у SPIP'
-);
+	'forum_slogan' => 'Управління загальними і редакційними форумами у SPIP',
+];
