@@ -9,6 +9,8 @@
  *  Ce programme est un logiciel libre distribué sous licence GNU/GPL.     *
 \***************************************************************************/
 
+use function SpipLeague\Component\Kernel\app;
+
 /**
  * Gestion de l'API autoriser et fonctions d'autorisations de SPIP
  *
@@ -119,7 +121,7 @@ if (!function_exists('autoriser')) {
 // mais apres la fonction autoriser()
 if ($f = find_in_path('mes_fonctions.php')) {
 	global $dossier_squelettes;
-	include_once(_ROOT_CWD . $f);
+	include_once(app()->getCwd() . DIRECTORY_SEPARATOR . $f);
 }
 
 
@@ -162,7 +164,7 @@ function autoriser_dist(string $faire, ?string $type = '', $id = null, $qui = nu
 	} elseif (is_numeric($qui)) {
 		$qui = sql_fetsel('*', 'spip_auteurs', 'id_auteur=' . $qui);
 		if (!$qui) {
-			return false;
+			$qui = ['statut' => '', 'id_auteur' => 0, 'webmestre' => 'non'];
 		}
 	}
 
@@ -1481,6 +1483,24 @@ function autoriser_preferences_configurer_dist(string $faire, string $type, $id,
 	return true;
 }
 
+/**
+ * Autorisation de voir le formulaire configurer_preferences_menus
+ *
+ * Calquée sur l'autorisation de voir le formulaire configurer_preferences
+ *
+ * @see autoriser()
+ *
+ * @param string $faire Action demandée
+ * @param string $type Type d'objet ou élément
+ * @param int|string|null $id Identifiant
+ * @param array $qui Description de l'auteur demandant l'autorisation
+ * @param array $opt Options de cette autorisation
+ * @return true
+ */
+function autoriser_preferencesmenus_configurer_dist(string $faire, string $type, $id, array $qui, array $opt): bool {
+	return autoriser('configurer', '_preferences', $id, $qui, $opt);
+}
+
 /**
  * Autorisation de voir l'onglet configurerpreferences
  *
@@ -1555,6 +1575,22 @@ function autoriser_auteurs_voir_dist(string $faire, string $type, $id, array $qu
 	return true;
 }
 
+/**
+ * Autorisation de voir les emails des autres auteurs
+ *
+ * @see autoriser()
+ *
+ * @param string $faire Action demandée
+ * @param string $type Type d'objet ou élément
+ * @param int|string|null $id Identifiant
+ * @param array $qui Description de l'auteur demandant l'autorisation
+ * @param array $opt Options de cette autorisation
+ * @return bool true s'il a le droit, false sinon
+ */
+function autoriser_auteurs_voiremails_dist(string $faire, string $type, $id, array $qui, array $opt): bool {
+	return $qui['statut'] === '0minirezo' && !$qui['restreint'];
+}
+
 /**
  * Autorisation de voir le menu auteurs
  *
