@@ -812,49 +812,54 @@ function recuperer_body($handle, $taille_max = _INC_DISTANT_MAX_SIZE, $fichier =
 }
 
 /**
- * Lit les entetes de reponse HTTP sur la socket $handle
- * et retourne
+ * @internal Lit les entetes de reponse HTTP sur la socket $handle et retourne:
+ *
  * false en cas d'echec,
- * un tableau associatif en cas de succes, contenant :
+ * un tableau associatif en cas de succès, contenant :
  * - le status
- * - le tableau complet des headers
- * - la date de derniere modif si connue
- * - l'url de redirection si specifiee
+ * - le tableau complet des headers sous forme de chaine de caractères
+ * - la date de dernière modif si connue
+ * - l'url de redirection si specifiée
+ * - la version http de la réponse (1.0, 1.1, 2, 3)
+ * - le contenu de l'entête content-length
+ * - le contenu de l'entête upgrade
  *
  * @param resource $handle
- * @param int|bool $if_modified_since
- * @return bool|array
- *   int status
- *   string headers
- *   int last_modified
- *   string location
+ * @param int|false $if_modified_since
+ *
+ * @return false|array{status:int,headers:string,last_modified:int,location:string,http_version:float,content_length:int,upgrade:string}
  */
 function recuperer_entetes_complets($handle, $if_modified_since = false) {
-	$result = ['status' => 0, 'headers' => [], 'last_modified' => 0, 'location' => ''];
+	$result = ['status' => 0, 'headers' => [], 'last_modified' => 0, 'location' => '', 'http_version' => 1.0, 'content_length' => 0, 'upgrade' => ''];
 
 	$s = @trim(fgets($handle, 16384));
-	if (!preg_match(',^HTTP/[0-9]+\.[0-9]+ ([0-9]+),', $s, $r)) {
+	if (!preg_match(',^HTTP/(?<protocol>[0-9]+(\.[0-9]+)?)\s*(?<code>[0-9]+),', $s, $matches)) {
 		return false;
 	}
-	$result['status'] = intval($r[1]);
+
+	$result['status'] = intval($matches['code'] ?? 0);
+	$result['http_version'] = floatval(sprintf('%1.1f', $matches['protocol'] ?? ''));
+
 	while ($s = trim(fgets($handle, 16384))) {
 		$result['headers'][] = $s . "\n";
 		preg_match(',^([^:]*): *(.*)$,i', $s, $r);
 		[, $d, $v] = $r;
 		$d = strtolower(trim($d));
-		if ( $d === 'location' && $result['status'] >= 300 && $result['status'] < 400) {
+		if ($d === 'location' && $result['status'] >= 300 && $result['status'] < 400) {
 			$result['location'] = $v;
 		} elseif ($d === 'last-modified') {
-			$result['last_modified'] = strtotime($v);
-		} elseif ($d === 'content-length' and strlen(trim($v))) {
+			$result['last_modified'] = strtotime($v) ?: 0;
+		} elseif ($d === 'content-length' && strlen(trim($v))) {
 			$result['content_length'] = intval($v);
+		} elseif ($d === 'upgrade' && strlen(trim($v))) {
+			$result['upgrade'] = trim($v);
 		}
 	}
 	if (
 		$if_modified_since
-		and $result['last_modified']
-		and $if_modified_since > $result['last_modified']
-		and $result['status'] == 200
+		&& $result['last_modified']
+		&& $if_modified_since > $result['last_modified']
+		&& $result['status'] == 200
 	) {
 		$result['status'] = 304;
 	}
