@@ -7,7 +7,6 @@
  *  Arnaud Martin, Antoine Pitrou, Philippe Rivière, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribué sous licence GNU/GPL.     *
- *  Pour plus de détails voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
 /**
@@ -220,8 +219,8 @@ function message_alerte_ouvrir(?string $titre = null, ?string $class = null, ?st
 	$class_racine = 'msg-alert';
 	$clearfix     = ($prive ? 'clearfix' : '');
 	$class_alerte = "$class_racine $class";
-	$class_texte  = "${class_racine}__text $clearfix";
-	$class_titre  = "${class_racine}__heading";
+	$class_texte  = "{$class_racine}__text $clearfix";
+	$class_titre  = "{$class_racine}__heading";
 
 	// Titre : markup
 	$titre = trim($titre);
