@@ -31,15 +31,15 @@ function inc_informer_dist($id, $col, $exclus, $rac, $type, $do = 'aff') {
 	$res = '';
 	if (
 		$type === 'rubrique'
-		and intval($GLOBALS['visiteur_session']['prefs']['display'] ?? 0) !== 1
-		and isset($GLOBALS['meta']['image_process'])
+		&& isset($GLOBALS['meta']['image_process'])
+		&& $GLOBALS['meta']['image_process'] !== 'non'
 	) {
 		if ($GLOBALS['meta']['image_process'] !== 'non') {
 			$chercher_logo = charger_fonction('chercher_logo', 'inc');
 			if ($res = $chercher_logo($id, 'id_rubrique', 'on')) {
 				[$fid, $dir, $nom, $format] = $res;
 				include_spip('inc/filtres_images_mini');
-				$res = image_reduire("<img src='$fid' alt='' />", 100, 48);
+				$res = image_reduire("<img src='$fid' alt=''>", 100, 48);
 				if ($res) {
 					$res = "<div class='informer__media' style='float: " . $GLOBALS['spip_lang_right'] . '; margin-' . $GLOBALS['spip_lang_right'] . ": -5px; margin-top: -5px;'>$res</div>";
 				}
@@ -66,10 +66,10 @@ function inc_informer_dist($id, $col, $exclus, $rac, $type, $do = 'aff') {
 	$js_func = $do . '_selection_titre';
 
 	return "<div style='display: none;'>"
-	. "<input type='text' id='" . $rac . "_sel' value='$id' />"
+	. "<input type='text' id='" . $rac . "_sel' value='$id'>"
 	. "<input type='text' id='" . $rac . "_sel2' value=\""
 	. entites_html($titre)
-	. '" />'
+	. '">'
 	. '</div>'
 	. "<div class='informer' style='padding: 5px; border-top: 0px;'>"
 	. '<div class="informer__item">'
@@ -80,7 +80,7 @@ function inc_informer_dist($id, $col, $exclus, $rac, $type, $do = 'aff') {
 	. "<div class='informer__action' style='clear:both; text-align: " . $GLOBALS['spip_lang_right'] . ";'>"
 	. "<input type='submit' class='fondo btn submit' value='"
 	. _T('bouton_choisir')
-	. "'\nonclick=\"$js_func('$titre',$id,'selection_rubrique','id_parent'); return false;\" />"
+	. "'\nonclick=\"$js_func('$titre',$id,'selection_rubrique','id_parent'); return false;\">"
 	. '</div>'
 	. '</div>';
 }
