@@ -9,6 +9,10 @@
  *  Ce programme est un logiciel libre distribué sous licence GNU/GPL.     *
 \***************************************************************************/
 
+use Spip\Afficher\Minipage\Admin as MinipageAdmin;
+
+use function SpipLeague\Component\Kernel\app;
+
 /**
  * Gestion de l'authentification par sessions
  * à utiliser pour valider l'accès (bloquant)
@@ -205,8 +209,8 @@ function ajouter_session($auteur) {
 		$fichier_session = fichier_session('alea_ephemere');
 		if (!ecrire_fichier_session($fichier_session, $auteur)) {
 			spip_log('Echec ecriture fichier session ' . $fichier_session, 'session' . _LOG_HS);
-			include_spip('inc/minipres');
-			echo minipres();
+			$minipage = new MinipageAdmin();
+			echo $minipage->page();
 			exit;
 		}
 		// verifier et limiter le nombre maxi de sessions
@@ -446,7 +450,7 @@ function session_set($nom, $val = null) {
  */
 function terminer_actualiser_sessions() {
 	// se remettre dans le dossier de travail au cas ou Apache a change
-	chdir(_ROOT_CWD);
+	chdir(app()->getCwd());
 	// recuperer les variables a effacer
 	$remove = session_set(false);
 	// mettre a jour toutes les sessions
@@ -677,8 +681,8 @@ function fichier_session($alea, $tantpis = false) {
 	if (empty($GLOBALS['meta'][$alea])) {
 		if (!$tantpis) {
 			spip_log("fichier session ($tantpis): $alea indisponible", 'session');
-			include_spip('inc/minipres');
-			echo minipres();
+			$minipage = new MinipageAdmin();
+			echo $minipage->page();
 		}
 
 		return ''; // echec mais $tanpis
