@@ -9,6 +9,8 @@
  *  Ce programme est un logiciel libre distribué sous licence GNU/GPL.     *
 \***************************************************************************/
 
+use Spip\Afficher\Minipage\Admin as MinipageAdmin;
+
 if (!defined('_ECRIRE_INC_VERSION')) {
 	return;
 }
@@ -19,7 +21,6 @@ if (defined('_TEST_DIRS')) {
 define('_TEST_DIRS', '1');
 
 include_spip('inc/headers');
-include_spip('inc/minipres');
 utiliser_langue_visiteur();
 
 //
@@ -142,7 +143,8 @@ function install_etape_chmod_dist() {
 			. "<input type='hidden' name='etape' value='chmod'>"
 			. "<div style='text-align: right'><input type='submit' value='" . attribut_html($t) . "'></div>";
 
-		echo minipres($titre, $res . generer_form_ecrire('install', $t));
+		$minipage = new MinipageAdmin();
+		echo $minipage->page($res . generer_form_ecrire('install', $t), ['titre' => $titre]);
 	} else {
 		$deja = (_FILE_CONNECT and analyse_fichier_connection(_FILE_CONNECT));
 		if (!$deja) {
