@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=en
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'activer_plugin' => 'Enable plugin',
@@ -26,12 +22,12 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'avis_connexion_echec_2' => 'Go back to the previous page, and check the information you provided.',
 	'avis_connexion_echec_3' => '<b>N.B.</b> On many servers, you must <b>request</b> activation of your access to the SQL database before you can use it. If you cannot connect to your database, check that activation has been done.',
 	'avis_connexion_erreur_creer_base' => 'The database could not be created.',
-	'avis_connexion_erreur_fichier_cle_manquant_1' => 'Installation must be performed by a webmaster with a backup of the keys and their password',
-	'avis_connexion_erreur_fichier_cle_manquant_2' => 'Installation must be performed by a webmaster with a backup of the keys',
+	'avis_connexion_erreur_fichier_cle_manquant_1' => 'Installation must be performed by a web-master or a web-mistress with a backup of the keys and their password',
+	'avis_connexion_erreur_fichier_cle_manquant_2' => 'Installation must be performed by a web-master or a web-mistress with a backup of the keys',
 	'avis_connexion_erreur_nom_base' => 'The database’s name should only contain letters, digits and hyphens.',
 	'avis_connexion_ldap_echec_1' => 'Connection to the LDAP server failed.',
 	'avis_connexion_ldap_echec_2' => 'Go back to the previous page, and check the information you provided.',
-	'avis_connexion_ldap_echec_3' => 'Alternatively, do not use LDAP support to import users.',
+	'avis_connexion_ldap_echec_3' => 'Alternatively, do not use LDAP support to import accounts.',
 	'avis_deplacement_rubrique' => 'Warning! This section contains @contient_breves@ news item@scb@: if you move it, please check this box to confirm.',
 	'avis_erreur_connexion_mysql' => 'SQL connection error',
 	'avis_erreur_creation_compte' => 'Failure during account initialisation',
@@ -56,13 +52,14 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'bouton_effacer_tout' => 'Delete ALL',
 	'bouton_envoyer_message' => 'Message complete: send',
 	'bouton_fermer' => 'Close',
+	'bouton_mettre_a_jour' => 'Update',
 	'bouton_mettre_a_jour_base' => 'Update the database',
 	'bouton_modifier' => 'Modify',
 	'bouton_radio_afficher' => 'Show',
-	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Appear in the list of editors online',
+	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Appear in the list of persons on-line',
 	'bouton_radio_envoi_annonces_adresse' => 'Send announcements to:',
 	'bouton_radio_envoi_liste_nouveautes' => 'Send news update list',
-	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Do not appear in the list of editors online',
+	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Do not appear in the list of persons on-line',
 	'bouton_radio_non_envoi_annonces_editoriales' => 'Do not send any editorial announcements',
 	'bouton_redirection' => 'REDIRECT',
 	'bouton_reinitialiser_aux_valeurs_par_defaut' => 'Reset to default values',
@@ -76,7 +73,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'bouton_vider_cache' => 'Empty the cache',
 
 	// C
-	'cache_modifiable_webmestre' => 'This parameter can be modified by the webmaster.',
+	'cache_modifiable_webmestre' => 'This parameter can be modified by the web-master or the web-mistress.',
 	'calendrier_synchro' => 'If you use a calendar application compatible with <b>iCal</b>, you can synchronise it with information from this site.',
 	'config_activer_champs' => 'Activate the following fields',
 	'config_choix_base_sup' => 'Choose a database on this server',
@@ -121,7 +118,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'entree_contenu_rubrique' => '(Brief description of the content of this section.)',
 	'entree_identifiants_connexion' => 'Your connection identifiers...',
 	'entree_identifiants_connexion_2' => 'Connection identifiers',
-	'entree_informations_connexion_ldap' => 'Please fill this form with the LDAP connection information provided by your system or network administrator.',
+	'entree_informations_connexion_ldap' => 'Please fill this form with the LDAP connection information.
+	These informations should be provided by your system or network admin.',
 	'entree_infos_perso' => 'Who are you?',
 	'entree_infos_perso_2' => 'Who is the author?',
 	'entree_interieur_rubrique' => 'In the section:',
@@ -196,6 +194,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'icone_mes_preferences' => 'Preferences',
 	'icone_modifier_article' => 'Edit this article',
 	'icone_modifier_rubrique' => 'Edit this section',
+	'icone_outils_rapides' => 'Create',
 	'icone_publication' => 'Publish',
 	'icone_relancer_signataire' => 'Contact the signatory again',
 	'icone_retour' => 'Back',
@@ -219,17 +218,18 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_activer_menu_developpement' => 'Show the Development menu',
 	'info_admin_etre_webmestre' => 'Give me web administrator rights',
 	'info_admin_je_suis_webmestre' => 'I am a <b>webmaster</b>',
-	'info_admin_statuer_webmestre' => 'Give webmaster rights to this administrator ',
-	'info_admin_webmestre' => 'This administrator is <b>webmaster</b>',
-	'info_administrateur' => 'Administrator',
-	'info_administrateur_1' => 'Administrator',
+	'info_admin_statuer_webmestre' => 'Give web-master (web-mistress) rights to this admin',
+	'info_admin_webmestre' => 'This admin is <b>webmaster</b>',
+	'info_administrateur' => 'Admin',
+	'info_administrateur_1' => 'Admin',
 	'info_administrateur_2' => 'of the site (<i>use with caution</i>)',
-	'info_administrateur_site_01' => 'If you are a site administrator, please',
+	'info_administrateur_site_01' => 'If you are a site admin, please',
 	'info_administrateur_site_02' => 'click on this link',
-	'info_administrateurs' => 'Administrators',
+	'info_administrateurs' => 'Admin',
 	'info_administrer_rubrique' => 'You can manage this section',
 	'info_adresse' => 'to this address:',
 	'info_adresse_desinscription' => 'Unsubscription address:',
+	'info_adresse_inscription' => 'Registration address:',
 	'info_adresse_url' => 'URL of the public site',
 	'info_afficher_par_nb' => 'Show ',
 	'info_aide_en_ligne' => 'SPIP Online Help',
@@ -269,7 +269,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_chapeau' => 'Introduction',
 	'info_chapeau_2' => 'Introduction:',
 	'info_chemin_acces_1' => 'Options: <b>Access path in directory</b>',
-	'info_chemin_acces_2' => 'You must now configure the access path to the directory information. This information is essential to read the user profiles stored in the directory.',
+	'info_chemin_acces_2' => 'You must now configure the access path to the directory information. This information is essential to read the data stored in the directory.',
 	'info_chemin_acces_annuaire' => 'Options: <b>Access path in directory</b>',
 	'info_choix_base' => 'Third step:',
 	'info_classement_1' => ' out of @liste@',
@@ -304,29 +304,29 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_ecrire_article' => 'Before writing any articles, you must create at least one section.',
 	'info_email_envoi' => 'Sender’s email address (optional)',
 	'info_email_envoi_txt' => 'Enter the sender’s email address used for sending emails (by default, the recipient’s address is used as the sender’s address) :',
-	'info_email_webmestre' => 'Webmaster’s email address',
+	'info_email_webmestre' => 'Web-master’s or web-mistress email address',
 	'info_envoi_email_automatique' => 'Automated mailing',
 	'info_envoyer_maintenant' => 'Send now',
+	'info_erreur_version_base_plus_recente' => 'Installation error',
 	'info_etape_suivante' => 'Go to the next step',
 	'info_etape_suivante_1' => 'You can move on to the next step.',
 	'info_etape_suivante_2' => 'You can move on to the next step.',
 	'info_exceptions_proxy' => 'Exceptions for the proxy',
 	'info_exportation_base' => 'export database to @archive@',
-	'info_facilite_suivi_activite' => 'To simplify monitoring of the site’s editorial;
-  activities, SPIP can send rmail notifications, e.g. to an editors’ mailing list,
-  of publication requests and article validations. Enter one or more adresses separated by commas.',
+	'info_facilite_suivi_activite' => 'To simplify monitoring of the site’s editorial
+  activities, SPIP can send by e-mail, e.g. to a mailing list,
+  notifications of publication requests and articles validations. Enter one or more addresses separated by commas.',
 	'info_fichiers_authent' => 'Authentication file ".htpasswd"',
 	'info_forums_abo_invites' => 'Your site contains forums by subscription; visitors may register for them on the public site.',
+	'info_gauche_admin_bdd' => '<b>This page is available to the persons responsible of the site only.</b><p> It gives access to the various database features. Some of them require a specific authentication process which 
+involves an FTP access to the site.</p>',
 	'info_gauche_admin_tech' => '<b>Only webmasters have access to this page.</b><p> It provides access to various
 maintenance tasks. Some of them require a specific authentication process
-via FTP.</p>',
-	'info_gauche_admin_vider' => '<b>Only webmasters have access to this page.</b><p> It provides access to various
-maintenance tasks. Some of them require a specific authentication process
 via FTP.</p>',
 	'info_gauche_auteurs' => 'All the site authors are listed here.
- The status of each is indicated by the colour of their icon (administrator = green; editor = yellow).',
+ The status of each is indicated by the colour of their icon (admin = green; editor = yellow).',
 	'info_gauche_auteurs_exterieurs' => 'Visiting authors, without any access to the site, are indicated by a blue icon; deleted authors by a grey icon.',
-	'info_gauche_messagerie' => 'Internal messaging lets you exchange messages between editors, keep memos (for personal use) or, display announcements on the admin area’s homepage (if you are an administrator).',
+	'info_gauche_messagerie' => 'Internal messaging lets you exchange messages between accounts, keep memos (for personal use) or, display announcements on the back office homepage (if you are an admin).',
 	'info_gauche_statistiques_referers' => 'This page displays the list of <i>referrers</i>, i.e. websites containing links to your own site, for yesterday and today. The list is reset every 24 hours.',
 	'info_gauche_visiteurs_enregistres' => 'You will find here the visitors registered
  for the public area of the site (subscription-only forums).',
@@ -342,7 +342,7 @@ via FTP.</p>',
 	'info_images_auto' => 'Images calculated automatically',
 	'info_informations_personnelles' => 'Personal information',
 	'info_inscription' => 'Registered on',
-	'info_inscription_automatique' => 'Automatic registration for new editors',
+	'info_inscription_automatique' => 'Automatic registration of new accounts',
 	'info_jeu_caractere' => 'Character set for the site',
 	'info_jours' => 'days',
 	'info_laisser_champs_vides' => 'leave these fields empty)',
@@ -350,7 +350,7 @@ via FTP.</p>',
 	'info_ldap_ok' => 'LDAP authentication is installed.',
 	'info_lien_hypertexte' => 'Hyperlink:',
 	'info_liste_nouveautes_envoyee' => 'The news update list has been sent',
-	'info_liste_redacteurs_connectes' => 'List of editors online',
+	'info_liste_redacteurs_connectes' => 'List of persons on-line',
 	'info_login_existant' => 'This login already exists.',
 	'info_login_trop_court' => 'Login too short.',
 	'info_login_trop_court_car_pluriel' => 'Your login must contain at least @nb@ characters.',
@@ -368,11 +368,12 @@ via FTP.</p>',
 	'info_modification_enregistree' => 'Your changes have been saved',
 	'info_modifier_auteur' => 'Edit author details:',
 	'info_modifier_rubrique' => 'Edit the section:',
+	'info_modifier_statut' => 'Change status',
 	'info_modifier_titre' => 'Edit: @titre@',
 	'info_mon_site_spip' => 'My SPIP site',
 	'info_moyenne' => 'average:',
 	'info_multi_cet_article' => 'Language for this article:',
-	'info_multi_langues_choisies' => 'Please select the languages to be made available to the editors of your site.
+	'info_multi_langues_choisies' => 'Please select the languages to be made available for editing.
   Languages already used on your site (at the top of the list) cannot be disabled.',
 	'info_multi_objets' => '@objets@: activate the language menu',
 	'info_multi_secteurs' => '... only for root-level sections?',
@@ -400,8 +401,8 @@ via FTP.</p>',
 	'info_nouvelle_traduction' => 'New translation:',
 	'info_numero_article' => 'ARTICLE NUMBER:',
 	'info_obligatoire_02' => '(Required)',
-	'info_option_accepter_visiteurs' => 'Allow visitor registration via the public site',
-	'info_option_ne_pas_accepter_visiteurs' => 'Disable visitor registration',
+	'info_option_accepter_visiteurs' => 'Allow the creation of visitors accounts via the public site',
+	'info_option_ne_pas_accepter_visiteurs' => 'Disable visitors’ accounts creation',
 	'info_options_avancees' => 'ADVANCED OPTIONS',
 	'info_ou' => 'or...',
 	'info_page_interdite' => 'Forbidden page',
@@ -419,7 +420,7 @@ via FTP.</p>',
 	'info_post_scriptum' => 'Postscript',
 	'info_post_scriptum_2' => 'Postscript:',
 	'info_pour' => 'for',
-	'info_preview_texte' => 'It is possible to preview the site’s  various editorial elements with at least the "submitted" status, as well as the"editing in progress" elements of which you are the author. Should this preview mode be restricted to administrators, open to all authors, or disabled completely?',
+	'info_preview_texte' => 'It is possible to preview the site’s various editorial elements with at least the "submitted" status, as well as the "editing in progress" elements of which you are the author. for which status should this feature be available?',
 	'info_procedez_par_etape' => 'please proceed step by step',
 	'info_procedure_maj_version' => 'the upgrade procedure must be run to adapt
  the database to this new version of SPIP.',
@@ -427,13 +428,13 @@ via FTP.</p>',
 	'info_ps' => 'P.S.',
 	'info_publier' => 'publish',
 	'info_publies' => 'Your articles published online',
-	'info_question_accepter_visiteurs' => 'If your website’s templates allows visitors to register with no access to the admin area, please activate the following option:',
-	'info_question_inscription_nouveaux_redacteurs' => 'Do you wish to allow new editors to register
- from the public website? If you agree with this, visitors will be able to  register
-  using an automatic form, and then access the admin area to
-  write their own articles. <div class="notice">During the registration process, users usually receive an automatic email
-  giving them their access code for the admin area. Some
-  service providers disallow sending emails from their
+	'info_question_accepter_visiteurs' => 'If your website’s templates allows accounts creation with no access to the back office, please enable the following option:',
+	'info_question_inscription_nouveaux_redacteurs' => 'Do you wish to allow new registrations
+ from the public site? If you agree with this, visitors will be able to  register
+  using an automatic form, and then access the back office to
+  write their own articles. <div class="notice">During the registration process, they usually receive an automatic email
+  giving them their access code for the back office. Some
+  hosting providers disable sending emails from their
   servers: in that case, automated registration is not
   possible.</div>',
 	'info_qui_edite' => '@nom_auteur_modif@ worked on the contents @date_diff@ minutes ago',
@@ -452,7 +453,7 @@ via FTP.</p>',
 	'info_refuses' => 'Your rejected articles ',
 	'info_reglage_ldap' => 'Options: <b>Adjusting LDAP import</b>',
 	'info_renvoi_article' => '<b>Redirection.</b> This article redirects to:',
-	'info_reserve_admin' => 'Only administrators can modify this address.',
+	'info_reserve_admin' => 'Only admins can modify this address.',
 	'info_restreindre_rubrique' => 'Restrict management to section:',
 	'info_resultat_recherche' => 'Search results:',
 	'info_rubriques' => 'Sections',
@@ -471,14 +472,15 @@ via FTP.</p>',
 	'info_sites_proxy' => 'Using a proxy',
 	'info_sites_trouves' => 'Sites found',
 	'info_sous_titre' => 'Subtitle:',
-	'info_statut_administrateur' => 'Administrator',
+	'info_statut' => 'Status',
+	'info_statut_administrateur' => 'Admin',
 	'info_statut_auteur' => 'This author’s status:',
 	'info_statut_auteur_2' => 'I am',
 	'info_statut_auteur_a_confirmer' => 'Registration to be confirmed',
 	'info_statut_auteur_autre' => 'Other status:',
 	'info_statut_redacteur' => 'Editor',
-	'info_statut_utilisateurs_1' => 'Default status for imported users',
-	'info_statut_utilisateurs_2' => 'Choose the status to be attributed to persons present in the LDAP directory when they connect for the first time. You can modify this value for each individual author later on.',
+	'info_statut_utilisateurs_1' => 'Default status for imported accounts',
+	'info_statut_utilisateurs_2' => 'Choose the status to be attributed to persons present in the LDAP directory when they connect for the first time. You can modify this value for each person later on.',
 	'info_suivi_activite' => 'Follow editorial activity',
 	'info_surtitre' => 'Top title:',
 	'info_syndication_integrale_1' => 'Your site provides syndication files (see "<a href="@url@">@titre@</a>").',
@@ -519,12 +521,13 @@ and their status is colour-coded:',
 	'info_url_test_proxy' => 'Test URL',
 	'info_urlref' => 'Hyperlink:',
 	'info_utilisation_spip' => 'SPIP is now ready for use',
+	'info_version_base_plus_recente' => 'SPIP version in the database is more recent than the one you are using. This operation is not supported,please update your installation.',
 	'info_visites_par_mois' => 'Monthly display:',
 	'info_visiteur_1' => 'Visitor',
 	'info_visiteur_2' => 'to the public site',
 	'info_visiteurs' => 'Visitors',
 	'info_visiteurs_02' => 'Public site visitors',
-	'info_webmestre_forces' => 'The web administrators are currently defined in <tt>@file_options@</tt>.',
+	'info_webmestre_forces' => 'The web-masters and web-mistresses are currently defined in <tt>@file_options@</tt>.',
 	'install_adresse_base_hebergeur' => 'Database address attributed by the hosting provider',
 	'install_connect_ok' => 'The new database has been declared using the server name @connect@.',
 	'install_echec_annonce' => 'This installation will probably fail, or damage your site.',
@@ -549,15 +552,16 @@ and their status is colour-coded:',
 	'install_types_db_connus' => 'SPIP can use <b>MySQL</b> (the most common) and <b>SQLite</b>.',
 	'install_types_db_connus_avertissement' => 'The support of <b>PostgreSQL</b is actually proposed as experimental',
 	'instituer_erreur_statut_a_change' => 'The status has already been modified',
+	'instituer_erreur_statut_a_definir' => 'Select a new status',
 	'instituer_erreur_statut_non_autorise' => 'You cannot select this status',
 	'intem_redacteur' => 'editor',
 	'intitule_licence' => 'Licence',
 	'item_accepter_inscriptions' => 'Allow registration',
 	'item_activer_messages_avertissement' => 'Activate warning messages',
-	'item_administrateur_2' => 'administrator',
+	'item_administrateur_2' => 'admin',
 	'item_afficher_calendrier' => 'Display in calendar',
 	'item_autoriser_syndication_integrale' => 'Include entire articles in syndication feeds',
-	'item_choix_administrateurs' => 'administrators',
+	'item_choix_administrateurs' => 'admins',
 	'item_choix_generation_miniature' => 'Generate thumbnails automatically.',
 	'item_choix_non_generation_miniature' => 'Do not generate thumbnails.',
 	'item_choix_redacteurs' => 'editors',
@@ -590,6 +594,7 @@ and their status is colour-coded:',
 	'label_bando_outils' => 'Toolbar',
 	'label_bando_outils_afficher' => 'Show the tools',
 	'label_bando_outils_masquer' => 'Hide the tools',
+	'label_choisir_timezone' => 'Time zone of the site',
 	'label_choix_langue' => 'Choose your language',
 	'label_langue' => 'Language',
 	'label_nom_fichier_connect' => 'Indicate the name for this server',
@@ -727,14 +732,20 @@ and their status is colour-coded:',
 	'protocole_ldap' => 'Protocol version:',
 
 	// Q
+	'queue_args_fonction_label' => 'Arguments passed to the function @fonction@',
+	'queue_args_voir' => 'Show arguments',
 	'queue_executer_maintenant' => 'Run now',
+	'queue_fonction_label' => 'Function',
 	'queue_info_purger' => 'You can delete all pending tasks and reset the list with periodic tasks',
+	'queue_liens_label' => 'links',
 	'queue_nb_jobs_in_queue' => '@nb@ pending tasks',
 	'queue_next_job_in_nb_sec' => 'Next task in @nb@ s',
+	'queue_next_job_scheduled' => 'Next job',
 	'queue_no_job_in_queue' => 'No pending tasks',
 	'queue_one_job_in_queue' => '1 pending task',
 	'queue_priorite_tache' => 'priority',
 	'queue_purger_queue' => 'Reset the tasks queue',
+	'queue_statut_en_cours' => 'In progress',
 	'queue_titre' => 'Background tasks',
 
 	// R
@@ -756,17 +767,17 @@ and their status is colour-coded:',
 	'taille_repertoire_cache' => 'Current cache size ',
 	'text_article_propose_publication' => 'Article submitted for publication.',
 	'texte_acces_ldap_anonyme_1' => 'Some LDAP servers do not allow anonymous access. In this case you must indicate an initial access identifier for future directory searches. However, in most cases the following fields can be left empty.',
-	'texte_admin_effacer_01' => 'This command deletes <i>all</i> content in the database,
-including <i>all</i> the access parameters for editors and administrators. After using it, you must
-reinstall SPIP, create a new database and a new administrator account.',
+	'texte_admin_effacer_01' => 'This command deletes <i>the entire</i> content of the database,
+including <i>all</i> the accesses to the back office. After using it, you must
+reinstall SPIP, to re-create a new database and a new admin access.',
 	'texte_adresse_annuaire_1' => '(If your directory is installed on the same machine as your website, it is probably «localhost».)',
 	'texte_ajout_auteur' => 'The following author was added to the article:',
-	'texte_annuaire_ldap_1' => 'If you have access to a LDAP directory server, you can use it to import users automatically into SPIP.',
+	'texte_annuaire_ldap_1' => 'If you have access to a LDAP directory server, you can use it to import accounts automatically into SPIP.',
 	'texte_article_statut' => 'Article status:',
 	'texte_article_virtuel' => 'Virtual article',
 	'texte_article_virtuel_reference' => '<b>Virtual article:</b> an article on your SPIP website which redirects to another URL. To remove redirection, delete the URL.',
 	'texte_aucun_resultat_auteur' => 'No results for "@cherche_auteur@".',
-	'texte_auteur_messagerie' => 'This site can update the list of editors online in real time, which allows you to be contacted by other users. You can opt not to appear in this list (you are then "invisible" to other users).',
+	'texte_auteur_messagerie' => 'The back office shows connected persons in real time, which allows you to exchange messages directly . You can opt not to appear in this list (you are then "invisible" to others).',
 	'texte_auteurs' => 'THE AUTHORS',
 	'texte_choix_base_1' => 'Select your database:',
 	'texte_choix_base_2' => 'The SQL server contains several databases.',
@@ -798,7 +809,7 @@ reinstall SPIP, create a new database and a new administrator account.',
 	'texte_enrichir_mise_a_jour' => 'You can enrich the layout of your text by using "typographical shortcuts".',
 	'texte_fichier_authent' => '<b>Should SPIP create the special files <tt>.htpasswd</tt>
   and <tt>.htpasswd-admin</tt> in the directory @dossier@?</b>
-<p>These files can be used to restrict access to authors and administrators to other parts of your site (for instance, external statistical programme).</p><p>If you have no need of such files, you can keep this option with its default value (no file creation).</p>',
+<p>These files can be used to restrict access to connected persons to other parts of your site (for instance, external statistical programme).</p><p>If you have no need of such files, you can keep this option with its default value (no file creation).</p>',
 	'texte_informations_personnelles_1' => 'The system will now  create your personal account for this site.',
 	'texte_informations_personnelles_2' => '(Note: if it is a reinstallation, if your former access is still working, you can',
 	'texte_introductif_article' => '(Introductory text for the article.)',
@@ -808,7 +819,7 @@ reinstall SPIP, create a new database and a new administrator account.',
 	'texte_login_ldap_1' => '(Keep empty for anonymous access or enter complete path, for instance «<tt>uid=smith, ou=users, dc=my-domain, dc=com</tt>».)',
 	'texte_login_precaution' => 'Warning! This is the login which you are currently using.
  Use this form with caution...',
-	'texte_messagerie_agenda' => 'A messaging system lets website’s authors communicate directly into the admin area. It is linked to a calendar.',
+	'texte_messagerie_agenda' => 'This messaging system allows the exchange of messages in the back office. It is linked to a calendar.',
 	'texte_mise_a_niveau_base_1' => 'You have just updated SPIP files.
  Now you must upgrade the site
  database.',
@@ -867,13 +878,13 @@ significant modifications to the site’s graphics or structure.',
 	'texte_titre_02' => 'Subject:',
 	'texte_titre_obligatoire' => '<b>Title</b> [Required]',
 	'texte_travail_article' => '@nom_auteur_modif@ edited this article @date_diff@ minutes ago',
-	'texte_travail_collaboratif' => 'If several editors often work on the same article, the system can mark recently "opened" articles in order to avoid multiple simultaneous editing.
+	'texte_travail_collaboratif' => 'If several persons often work on the same article, the system can mark recently "opened" articles in order to avoid multiple simultaneous editing.
   This option is disabled by default to avoid displaying unnecessary warning
   messages.',
 	'texte_vide' => 'empty',
 	'texte_vider_cache' => 'Empty the cache',
+	'titre_admin_bdd' => 'Database',
 	'titre_admin_tech' => 'Technical maintenance',
-	'titre_admin_vider' => 'Technical maintenance',
 	'titre_ajouter_un_auteur' => 'Add an author',
 	'titre_ajouter_un_mot' => 'Add a keyword',
 	'titre_cadre_afficher_article' => 'Show the articles:',
@@ -926,5 +937,5 @@ significant modifications to the site’s graphics or structure.',
 	'utf8_convert_erreur_orig' => 'Error: the character set @charset@ is not supported.',
 
 	// V
-	'version' => 'Version:'
-);
+	'version' => 'Version:',
+];
