@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=km
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'activer_plugin' => '​ធ្វើ​អោយសកម្ម plugin',
@@ -24,7 +20,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'avis_connexion_echec_3' => '<b>ចំណាំសំខាន់</b> លើមួយចំនួនខំព្យូរើបំរើសេវា, អ្នកត្រូវតែ <b>ស្នើ</b> ការធ្វើអោយសកម្ម ការចូលទៅ របស់អ្នក ក្នុងមូលដ្ឋានទិន្នន័យ មុនអាចប្រើប្រាស់វា។ បើអ្នកគ្មានអាចភ្ជាប់ទៅ, អ្នកផ្ទៀង តើអ្នកបានអនុវត្ត ការធ្វើអោយសកម្មនេះ។',
 	'avis_connexion_ldap_echec_1' => 'បញ្ជាប់ទៅ ខំព្យូរើបំរើសេវា LDAP បានបរាជ័យ។',
 	'avis_connexion_ldap_echec_2' => 'ត្រលប់ទៅ ទំព័រមុន, និងផ្ទៀង ពត៌មាន អ្នកបានផ្តល់។',
-	'avis_connexion_ldap_echec_3' => 'តាមជំរើស, កុំ​ប្រើ​ប្រាស់ការ​គាំទ្រ LDAP ដើម្បី​នាំចូលអ្នក​ប្រើប្រាស់។',
+	'avis_connexion_ldap_echec_3' => 'តាមជំរើស, កុំ​ប្រើ​ប្រាស់ការ​គាំទ្រ LDAP ដើម្បី​នាំចូលអ្នក​ប្រើប្រាស់។', # MODIF
 	'avis_deplacement_rubrique' => 'ប្រយត្ន! មាតិកា​នេះ ​មានផ្ទុក @contient_breves@ ពត៌មានសង្ខេប @scb@ ៖ បើ​អ្នក​ប្តូរទីតាំងវា, សូមគូស ប្រអប់បញ្ជាក់ទទួលស្គាល់ នេះ។',
 	'avis_erreur_connexion_mysql' => 'កំហុស​ ភ្ជាប់ទៅ SQL ',
 	'avis_espace_interdit' => '<b>តំបន់ហាម</b> <div>SPIP ធ្លាប់ត្រូវ​បានតំលើង។</div>',
@@ -47,10 +43,10 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'bouton_envoyer_message' => 'សារ​បញ្ចប់ ៖ ផ្ញើ',
 	'bouton_modifier' => 'កែប្រែ',
 	'bouton_radio_afficher' => 'បង្ហាញចេញ',
-	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'លេច​ចេញ ​ក្នុង​បញ្ជី​អ្នកតែងនិពន្ធ ​ដែល​បានភ្ជាប់',
+	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'លេច​ចេញ ​ក្នុង​បញ្ជី​អ្នកតែងនិពន្ធ ​ដែល​បានភ្ជាប់', # MODIF
 	'bouton_radio_envoi_annonces_adresse' => 'ផ្ញើ​ ការប្រកាសដំណឹង ទៅអាសយដ្ឋាន ៖',
 	'bouton_radio_envoi_liste_nouveautes' => 'ផ្ញើ​ ប​ញ្ជី នៃអ្វី ដែលថ្មី',
-	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'មិន​លេច​ចេញ ​ក្នុង​បញ្ជី​ អ្នកតែងនិពន្ធ',
+	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'មិន​លេច​ចេញ ​ក្នុង​បញ្ជី​ អ្នកតែងនិពន្ធ', # MODIF
 	'bouton_radio_non_envoi_annonces_editoriales' => 'មិន​ផ្ញើ​ ការប្រកាសដំណឹង ​ដែល​ផ្សព្វផ្សាយ',
 	'bouton_redirection' => 'បណ្តូរទិស',
 	'bouton_relancer_installation' => 'តំលើង ឡើងវិញ',
@@ -60,7 +56,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'bouton_vider_cache' => 'ពង្រីង សតិភ្ជាប់',
 
 	// C
-	'cache_modifiable_webmestre' => 'អាចផ្លាស់ប្តូរ ប៉ារ៉ាម៉ែត្រ​នេះ​ ដោយអ្នកជំនាញវ៉ែប នៃសៃថ៍។',
+	'cache_modifiable_webmestre' => 'អាចផ្លាស់ប្តូរ ប៉ារ៉ាម៉ែត្រ​នេះ​ ដោយអ្នកជំនាញវ៉ែប នៃសៃថ៍។', # MODIF
 	'calendrier_synchro' => 'បើ​អ្នក​ប្រើ​ប្រាស់ ផ្នែកទន់សៀវភៅកត់ត្រា សមស្រប <b>iCal</b>, អ្នក​អាច សមកាលវា ជាមួយពត៌មាន នៃសៃថ៍នេះ។',
 	'config_activer_champs' => 'ធ្វើអោយសកម្ម វាលខាងក្រោម',
 	'config_choix_base_sup' => 'ដាក់ឈ្មោះ មូលដ្ឋានទិន្នន័យ លើខំព្យូរើបំរើសេវានេះ',
@@ -89,7 +85,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'entree_identifiants_connexion' => 'អត្ដសញ្ញា ​ភ្ជាប់​ របស់​អ្នក​...',
 	'entree_informations_connexion_ldap' => 'បំពេញបែបបទ​នេះ ​ពត៌មានបញ្ជាប់ ទៅបញ្ជីឈ្មោះ LDAP របស់អ្នក។ 
 ​ពត៌មាន​តាំងនេះ ត្រូវតែអាចផ្តល់ទៅអ្នក ​តាមអ្នកអភិបាល នៃប្រព័ន្ធ, 
- ឬ នៃបណ្តាញ។',
+ ឬ នៃបណ្តាញ។', # MODIF
 	'entree_infos_perso' => 'អ្នកជា អ្នកណា?',
 	'entree_interieur_rubrique' => 'ពី​ក្នុង​ផ្នែក ៖',
 	'entree_liens_sites' => '<b>តំណភ្ជាប់ អត្ថបទខ្ពស់</b> (​ឯកសារយោង សៃថ៍​ សំរាប់ចូលមើល...)',
@@ -152,12 +148,12 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'impossible_modifier_pass_auteur' => 'Impossible de modifier le mot de passe.', # MODIF
 	'info_1_article' => 'អត្ថបទ ១',
 	'info_activer_cookie' => 'អ្នអ្នក អាចធ្វើអោយសកម្ម មួយ <b>ខូកឃីឆ្លងឆ្លើយ</b>, វា នឹងអនុញ្ញាតអ្នក ងាយដើរ ពីសៃថ៍សាធារណះ ទៅសៃថ៍ឯកជន។',
-	'info_administrateur' => 'អ្នកគ្រប់គ្រង',
-	'info_administrateur_1' => 'អ្នកគ្រប់គ្រង',
+	'info_administrateur' => 'អ្នកគ្រប់គ្រង', # MODIF
+	'info_administrateur_1' => 'អ្នកគ្រប់គ្រង', # MODIF
 	'info_administrateur_2' => 'នៃសៃថ៍ (<i>ប្រើប្រាស់ ដោយប្រយត្ន</i>)',
-	'info_administrateur_site_01' => 'បើអ្នក ជាអ្នកអភិបាលសៃថ៍, សូម',
+	'info_administrateur_site_01' => 'បើអ្នក ជាអ្នកអភិបាលសៃថ៍, សូម', # MODIF
 	'info_administrateur_site_02' => 'ចុចលើ តំណភ្ជាប់នេះ',
-	'info_administrateurs' => 'អ្នកគ្រប់គ្រង',
+	'info_administrateurs' => 'អ្នកគ្រប់គ្រង', # MODIF
 	'info_administrer_rubrique' => 'អ្នក​អាច​ចាត់ចែង​ផ្នែក​នេះ',
 	'info_adresse' => 'ទៅ​នឹង​អាសយដ្ឋាន ៖',
 	'info_adresse_url' => 'អាសយដ្ឋាន URL នៃសៃថ៍សាធារណះ',
@@ -184,7 +180,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_chapeau' => 'ឧបករ រក្សា​ទិន្នន័យ',
 	'info_chapeau_2' => 'សេចក្ដី​ផ្ដើម ៖',
 	'info_chemin_acces_1' => 'ជម្រើស ៖<b>ច្រកចូល​នៅ​ក្នុង​បញ្ជី​រាយ​ឈ្មោះ</b>',
-	'info_chemin_acces_2' => 'ពីពេលនេះ, អ្នកត្រូវតែកំណត់ទំរង់ ផ្លូវចូលទៅ ពត៌មាននៃថតឯកសារ។ ពត៌មាននេះ មានខ្លឹមសារសំខាន់ សំរាប់អាន ពត៌មានផ្ទាល់ខ្លួន របស់អ្នកប្រើប្រាស់ បានតំកល់ទុក ក្នុងថតឯកសារ។',
+	'info_chemin_acces_2' => 'ពីពេលនេះ, អ្នកត្រូវតែកំណត់ទំរង់ ផ្លូវចូលទៅ ពត៌មាននៃថតឯកសារ។ ពត៌មាននេះ មានខ្លឹមសារសំខាន់ សំរាប់អាន ពត៌មានផ្ទាល់ខ្លួន របស់អ្នកប្រើប្រាស់ បានតំកល់ទុក ក្នុងថតឯកសារ។', # MODIF
 	'info_chemin_acces_annuaire' => 'ជម្រើស ៖<b>ច្រកចូល​នៅ​ក្នុង​បញ្ជី​រាយ​ឈ្មោះ</b>',
 	'info_choix_base' => 'ជំហាន​ទី​បី ៖',
 	'info_classement_1' => ' out of @liste@',
@@ -226,14 +222,13 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_exportation_base' => 'នាំចេញ មូលដ្ឋានទិន្នន័យ ទៅ @archive@',
 	'info_facilite_suivi_activite' => 'សំរាប់សំរួល ការតាមដាន សកម្មភាពបោះផ្សាយ នៃសៃថ៍, SPIP អាចជូនដំណឹង តាមមែវល៍, ជាឧទាហរ ទៅបញ្ជីផ្ញើមែវល៍ របស់ពួកស្មេរ, ជំនូនដំណឹង នៃសំណើ បោះផ្សាយនានា និងភាពសុពលភាព នៃអត្ថបទនានា។', # MODIF
 	'info_fichiers_authent' => 'ហ្វា​ល​យថាភាព \\".htpasswd\\"',
-	'info_forums_abo_invites' => 'វ៉ែបសៃថ៍ របស់អ្នក រួមមាន ទីប្រជុំមតិ តាមរយះការជាវ ; ចឹង ពួកទស្សនាករ អាចចុះឈ្មោះ ចូលរួម ទីប្រជុំមតិទាំងនេះ លើសៃថ៍សាធារណះ។',
+	'info_forums_abo_invites' => 'វ៉ែបសៃថ៍ របស់អ្នក រួមមាន ទីប្រជុំមតិ តាមរយះការជាវ ; ចឹង ពួកទស្សនាករ អាចចុះឈ្មោះ ចូលរួម ទីប្រជុំមតិទាំងនេះ លើសៃថ៍សាធារណះ។', # MODIF
 	'info_gauche_admin_tech' => '<b>ត្រឹម ពួកអ្នកទទួលខុសត្រូវសៃថ៍ អាចចូលទៅ ទំព័រនេះ។</b><p> វាអនុញ្ញាត អោយចូលទៅ មុខងារថែទាំបច្ចេកទេស ដទៃ។ មួយចំនួននៃមុខងារ ផ្តល់ដំណើរ សំគាល់ជាក់លាក់, តំរូវអោយមាន FTP សំរាប់ចូលទៅ វ៉ែបសៃថ៍។</p>', # MODIF
-	'info_gauche_admin_vider' => '<b>ត្រឹម ពួកអ្នកទទួលខុសត្រូវសៃថ៍ អាចចូលទៅ ទំព័រនេះ។</b><p> វាអនុញ្ញាត ចូលទៅ មុខងារថែទាំបច្ចេកទេស ដទៃ។ មួយចំនួននៃមុខងារ ផ្តល់ដំណើរ សំគាល់ជាក់លាក់, តំរូវអោយមាន FTP សំរាប់ចូលទៅ វ៉ែបសៃថ៍។</p>', # MODIF
 	'info_gauche_auteurs' => 'អ្នកនឹងឃើញ ទីនេះ គ្រប់អ្នកនិពន្ធ នៃវ៉ែបសៃថ៍។
- ស្ថានភាព របស់ពួកគេ ត្រូវបានសំគាល់ ដោយ ពណ៌នៃរូបតំណាង (អ្នកអភិបាល = បៃតង; អ្នកបោះផ្សាយ = លឿង;)',
+ ស្ថានភាព របស់ពួកគេ ត្រូវបានសំគាល់ ដោយ ពណ៌នៃរូបតំណាង (អ្នកអភិបាល = បៃតង; អ្នកបោះផ្សាយ = លឿង;)', # MODIF
 	'info_gauche_auteurs_exterieurs' => 'ពួកអ្នកនិពន្ធ ពីខាងក្រៅ, គ្មានអាចចូលទៅ វ៉ែបសៃថ៍, ត្រូវបានសំគាល់ ជារូបតំណាង ពណ៌ខៀវ ;
 ​ ពួកអ្នកនិពន្ធ ត្រូវបានលុបចេញ ដោយធុងសំរាម។', # MODIF
-	'info_gauche_messagerie' => 'ការ​ផ្ញើ​សារ​អនុញ្ញាត​អោយ​អ្នក​ផ្លាស់​ប្ដូរ​សារ​ក្នុង​ចំណោម​បណ្ណាធិកា ដើម្បី​រក្សា​ទុក​អនុស្សរណៈ  (​សម្រាប់​ការ​ប្រើប្រាស់​ផ្ទាល់ខ្លួន​របស់​អ្នក​) ឬ​ដើម្បី​បង្ហាញ​នូវ​សេចក្ដី​ប្រកាស​នៅ​លើ​គេហទំព័រ​នៃ​កន្លែង​ឯកជន (​ប្រសិនបើ​អ្នក​គឺជា​អ្នកគ្រប់គ្រង​) ។',
+	'info_gauche_messagerie' => 'ការ​ផ្ញើ​សារ​អនុញ្ញាត​អោយ​អ្នក​ផ្លាស់​ប្ដូរ​សារ​ក្នុង​ចំណោម​បណ្ណាធិកា ដើម្បី​រក្សា​ទុក​អនុស្សរណៈ  (​សម្រាប់​ការ​ប្រើប្រាស់​ផ្ទាល់ខ្លួន​របស់​អ្នក​) ឬ​ដើម្បី​បង្ហាញ​នូវ​សេចក្ដី​ប្រកាស​នៅ​លើ​គេហទំព័រ​នៃ​កន្លែង​ឯកជន (​ប្រសិនបើ​អ្នក​គឺជា​អ្នកគ្រប់គ្រង​) ។', # MODIF
 	'info_gauche_statistiques_referers' => 'ទំព័រនេះ បង្ហាញ បញ្ជី<i>ឯកសារយោង</i>, បានន័យថា វ៉ែបសៃថ៍ មានផ្ទុកតំណភ្ជាប់ សំដៅសៃថ៍ផ្ទាល់ របស់អ្នក, ត្រឹម ម្សិល និងថ្ងៃនេះ ; បញ្ជីនេះ ត្រូវបានត្រលប់ទៅ សូន្យ រាល់ ២៤ ម៉ោង។',
 	'info_gauche_visiteurs_enregistres' => 'អ្នកនឹង រកឃើញ ទីនេះ ពួកទស្សនាករ
  ក្នុងធ្លាសាធារណះ នៃវ៉ែបសៃថ៍ (​ទីប្រជុំមតិ ជាវប្រចាំ)។',
@@ -245,14 +240,14 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_image_process2' => '<b>ចំណាំ៖</b> <i>បើគ្មានរូបភាព លេចឡើង, ពេលខំព្យូរើបំរើសេវា ដែលទទួលផ្ទុកវ៉ែបសៃថ៍ របស់អ្នក គ្មានត្រូវបានកំណត់ទំរង់ សំរាប់ប្រើប្រាស់ ឧបករបែបចឹង។ បើអ្នក ចង់ប្រើប្រាស់ មុខងារទាំងនេះ, ទាក់ទងអ្នកទទួលខុសត្រូវ ផ្នែកបច្ចេកទេស និងសួរ ផ្នែកបន្ថែម «GD» ឬ «Imagick»</i>', # MODIF
 	'info_images_auto' => 'រូបភាព​ដែល​ត្រូវ​បាន​រាប់​ដោយ​ស្វ័យប្រវត្ដិ',
 	'info_informations_personnelles' => 'ជំហាន​ទី​ប្រាំ ៖ <b>Personal information</b>',
-	'info_inscription_automatique' => 'ការចុះឈ្មោះស្វ័យប្រវត្តិ ពួកស្មេរថ្មី',
+	'info_inscription_automatique' => 'ការចុះឈ្មោះស្វ័យប្រវត្តិ ពួកស្មេរថ្មី', # MODIF
 	'info_jeu_caractere' => 'កញ្ចប់ភាសា នៃសៃថ៍',
 	'info_jours' => 'ថ្ងៃ',
 	'info_laisser_champs_vides' => 'ទុក​ប្រអប់​នេះ​ទំនេរ',
 	'info_langues' => 'ភាសា នៃសៃថ៍',
 	'info_ldap_ok' => 'LDAP បញ្ជាក់​ភាព​ត្រឹមត្រូវ ត្រូវ​បាន​ដំឡើង​។',
 	'info_lien_hypertexte' => 'តំណភ្ជាប់ អត្ថបទខ្ពស់៖',
-	'info_liste_redacteurs_connectes' => 'បញ្ជី​អ្នក​សរសេរ​អត្ថបទ​ដែល​ទាក់ទង',
+	'info_liste_redacteurs_connectes' => 'បញ្ជី​អ្នក​សរសេរ​អត្ថបទ​ដែល​ទាក់ទង', # MODIF
 	'info_login_existant' => 'ការពិនិត្យចូលនេះ មានស្រាប់ហើយ។',
 	'info_login_trop_court' => 'ការពិនិត្យចូល ខ្លីពេក។',
 	'info_logos' => 'រូបសញ្ញា',
@@ -271,7 +266,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_moyenne' => 'មធ្យមៈ',
 	'info_multi_cet_article' => 'ភាសា​ក្នុង​អត្ថបទ​នេះ',
 	'info_multi_langues_choisies' => 'សូមជ្រើសយក ភាសាមានស្រាប់ ខាងក្រោម សំរាប់ ពួកស្មេរ នៃសៃថ៍ របស់អ្នក។
-ភាសា ត្រូវបានប្រើប្រាស់ហើយ ក្នុងសៃថ៍ របស់អ្នក(បង្ហាញ ដំបូង) គ្មានអាចត្រូវបាន អសកម្ម។',
+ភាសា ត្រូវបានប្រើប្រាស់ហើយ ក្នុងសៃថ៍ របស់អ្នក(បង្ហាញ ដំបូង) គ្មានអាចត្រូវបាន អសកម្ម។', # MODIF
 	'info_multi_secteurs' => '...​សំរាប់​តែ​ផ្នែក​ដែល​នៅ​ខាងក្រោម​គេ​ប៉ុណ្ណោះ​?',
 	'info_nom' => 'ឈ្មោះ',
 	'info_nom_destinataire' => 'ឈ្មោះ​អ្នក​ទទួល',
@@ -290,8 +285,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_nouvelle_traduction' => 'អត្ថបទ​បកប្រែ​ថ្មីៈ',
 	'info_numero_article' => 'លេខ​អត្ថបទៈ',
 	'info_obligatoire_02' => '[ចាំបាច់]', # MODIF
-	'info_option_accepter_visiteurs' => 'យល់ព្រម ការចុះឈ្មោះ ពួកទស្សនាករ នៃវ៉ែបសៃថ៍​សាធារណះ',
-	'info_option_ne_pas_accepter_visiteurs' => 'បដិសេធ ការចុះឈ្មោះ របស់ទស្សនាករ',
+	'info_option_accepter_visiteurs' => 'យល់ព្រម ការចុះឈ្មោះ ពួកទស្សនាករ នៃវ៉ែបសៃថ៍​សាធារណះ', # MODIF
+	'info_option_ne_pas_accepter_visiteurs' => 'បដិសេធ ការចុះឈ្មោះ របស់ទស្សនាករ', # MODIF
 	'info_options_avancees' => 'ជំរើស​ពិសេស',
 	'info_ou' => 'ឬ​....',
 	'info_page_interdite' => 'ទំព័រ​ហាមឃាត់',
@@ -315,7 +310,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_ps' => 'បញ្ជាក់(P.S)',
 	'info_publier' => 'ចុះ​ផ្សាយ',
 	'info_publies' => 'រាល់អត្ថបទ របស់អ្នក ត្រូវបានបោះផ្សាយ លើអិនរើណែត',
-	'info_question_accepter_visiteurs' => 'ប្រសិនបើ​ទម្រង់​វ៉ិ​ប​សាយ​របស់​លោក​អ្នក​អនុញ្ញាត​ឱ្យ​អ្នក​ទស្សនា​ចុះ​ឈ្មោះ​ដោយ​មិន​ចាំបាច់​ចូល​ទៅ​ក្នុង​ផ្នែក​ឯកជន សូម​បើកមុខ​ងារ​ជំរើស​ខាងក្រោមៈ',
+	'info_question_accepter_visiteurs' => 'ប្រសិនបើ​ទម្រង់​វ៉ិ​ប​សាយ​របស់​លោក​អ្នក​អនុញ្ញាត​ឱ្យ​អ្នក​ទស្សនា​ចុះ​ឈ្មោះ​ដោយ​មិន​ចាំបាច់​ចូល​ទៅ​ក្នុង​ផ្នែក​ឯកជន សូម​បើកមុខ​ងារ​ជំរើស​ខាងក្រោមៈ', # MODIF
 	'info_question_inscription_nouveaux_redacteurs' => 'តើ​លោក​អ្នក​ត្រូវការ​អនុញ្ញាត​ឱ្យ​អ្នក​សរសេរ​អត្ថបទ​ថ្មី​ចុះ​ឈ្មោះ​ពី​វ៉ិ​ប​សាយ​សាធារណៈ​ដែល​ឬទេ​? ប្រសិនបើ​លោក​អ្នក​យល់ព្រម អ្នក​ទស្សនា​នឹង​អាច​ចុះ​ឈ្មោះ​ដោយ​ប្រើប្រាស់​ទម្រង់​ស្វ័យប្រវត្ដិ​មួយ ហើយ​បន្ទាប់​មក​ចូល​ក្នុង​ផ្នែក​ឯកជន​ដើម្បី​បញ្ចូល​អត្ថបទ​ផ្ទា់ល់​របស់​ពួក​គេ​។ <blockquote> ក្នុង​ពេល​ដំណើរការ​ចុះ​ឈ្មោះ អ្នក​ប្រើប្រាស់​ទទួល​បាន​អ៊ី​ម៉ែ​ល​ស្វ័យប្រវត្ដិ​ដែល​ផ្ដល់​ជូន​ពួក​គេ​នូវ​លេខ​កូដ​ចូល​ទៅ​ក្នុង​ផ្នែក​ឯកជន​។ ក្រុមហ៊ុន​ផ្ដល់​សេវា​មួយ​ចំនួន​មិន​អនុញ្ញាត​ចំពោះ​ការ​ផ្ញើ​អ៊ី​ម៉ែ​ល​ម៉ាស៊ីន​មេ (servers)​របស់​ពួក​គេ​ទេ ៖ ក្នុង​ករណី​នោះ ការ​ចុះ​ឈ្មោះ​ដោយ​ស្វ័យប្រវត្ដិ​គឺ​មិន​អាច​អនុវត្ដ​បាន​ទេ​។', # MODIF
 	'info_racine_site' => 'ឫស នៃវ៉ែបសៃថ៍',
 	'info_recharger_page' => 'សូម​បញ្ចូល​ទំព័រ​នេះ​ជា​ថ្មី​ម្ដងទៀត​នៅ​មួយសន្ទុះ​ក្រោយ',
@@ -329,7 +324,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_refuses' => 'អត្ថបទ របស់អ្នក ត្រូវបានបដិសេធ',
 	'info_reglage_ldap' => 'ជម្រើសៈ<b>Adjusting LDAP import</b>',
 	'info_renvoi_article' => '<b>Redirection.</b> អត្ថបទ​នេះ​ត្រូវ​ប្ដូរ​ទិស​ដៅ​ជា​ថ្មី​ទៅៈ',
-	'info_reserve_admin' => 'ត្រឹម ពួកអ្នកអភិបាល អាចកែប្រែ អាសយដ្ឋាននេះ។',
+	'info_reserve_admin' => 'ត្រឹម ពួកអ្នកអភិបាល អាចកែប្រែ អាសយដ្ឋាននេះ។', # MODIF
 	'info_restreindre_rubrique' => 'កំណត់​ការ​គ្រប់គ្រង​ត្រឹមតែ​ចំពោះ​ផ្នែកៈ',
 	'info_resultat_recherche' => 'លទ្ធផល​នៃ​ការ​ស្វែងរកៈ',
 	'info_rubriques' => 'ផ្នែក',
@@ -348,13 +343,13 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_sites_proxy' => '​ប្រើប្រាស់​ មួយខំព្យូរើបំរើសេវា Proxy',
 	'info_sites_trouves' => 'បានរកឃើញ សៃថ៍',
 	'info_sous_titre' => 'ចំណងជើង​រង៖',
-	'info_statut_administrateur' => 'អ្នកអភិបាល',
+	'info_statut_administrateur' => 'អ្នកអភិបាល', # MODIF
 	'info_statut_auteur' => 'ស្ថានភាព នៃអ្នកនិពន្ធ នេះ៖',
 	'info_statut_auteur_a_confirmer' => 'ការ​ចុះ​ឈ្មោះ​ ដែល​ត្រូវ​បញ្ជាក់ទទួលស្គាល់',
 	'info_statut_auteur_autre' => 'ស្ថានភាព ដទៃ ៖',
 	'info_statut_redacteur' => 'អ្នក​តែងនិពន្ធ',
-	'info_statut_utilisateurs_1' => 'ស្ថានភាព​ លំនាំដើម នៃអ្នក​ប្រើប្រាស់​ ដែល​បានត្រូវនាំចូល',
-	'info_statut_utilisateurs_2' => 'ជ្រើសរើស​ស្ថានភាព​ដែល​បញ្ជាក់​អំពី​បុគ្គល​ដែល​មាននៅ​ក្នុង​បញ្ជី (directory) LDAP នៅ​ពេល​ដែល​ពួក​គេ​ភ្ជាប់​ជា​លើក​ដំបូង​។ ក្រោយមក​លោក​អ្នក​អាច​កែសម្រួល​តម្លៃ​នេះ​សំរាប់​អ្នក​សរសេរ​កម្មវិធី​នីមួយៗ ដោយ​ផ្នែក​លើ​ករណី​មួយៗ​។',
+	'info_statut_utilisateurs_1' => 'ស្ថានភាព​ លំនាំដើម នៃអ្នក​ប្រើប្រាស់​ ដែល​បានត្រូវនាំចូល', # MODIF
+	'info_statut_utilisateurs_2' => 'ជ្រើសរើស​ស្ថានភាព​ដែល​បញ្ជាក់​អំពី​បុគ្គល​ដែល​មាននៅ​ក្នុង​បញ្ជី (directory) LDAP នៅ​ពេល​ដែល​ពួក​គេ​ភ្ជាប់​ជា​លើក​ដំបូង​។ ក្រោយមក​លោក​អ្នក​អាច​កែសម្រួល​តម្លៃ​នេះ​សំរាប់​អ្នក​សរសេរ​កម្មវិធី​នីមួយៗ ដោយ​ផ្នែក​លើ​ករណី​មួយៗ​។', # MODIF
 	'info_suivi_activite' => 'ការតាមដាន សកម្មភាពបោះផ្សាយ',
 	'info_surtitre' => 'ចំណងជើងកំពូល៖',
 	'info_syndication_integrale_1' => 'វ៉ិ​ប​សាយ​របស់​លោក​អ្នក​ផ្ដល់​នូវ​ហ្វា​ល (file) បញ្ចូល(see <a href=\\"@url@\\">@titre@</a>)។',
@@ -407,10 +402,10 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'intitule_licence' => 'អាជ្ញាបណ្ណ',
 	'item_accepter_inscriptions' => 'ព្រមទទួល ការ​ចុះ​ឈ្មោះទាំងឡាយ',
 	'item_activer_messages_avertissement' => 'សកម្ម សារព្រមាន',
-	'item_administrateur_2' => 'អ្នកអភិបាល',
+	'item_administrateur_2' => 'អ្នកអភិបាល', # MODIF
 	'item_afficher_calendrier' => 'បង្ហាញ​ចេញ ក្នុង​ប្រក្រតីទិន',
 	'item_autoriser_syndication_integrale' => 'បញ្ចូល​អត្ថបទ​ទាំងមូល​ទៅ​ក្នុង​ហ្វា​ល (files) បញ្ចូល​។',
-	'item_choix_administrateurs' => 'អ្នកគ្រប់គ្រង​ប្រព័ន្ធ',
+	'item_choix_administrateurs' => 'អ្នកគ្រប់គ្រង​ប្រព័ន្ធ', # MODIF
 	'item_choix_generation_miniature' => 'បង្កើត​ទម្រង់​រូបភាព​សង្ខេប​ច្បាស់ៗ​ដោយ​ស្វ័យប្រវត្ដិ',
 	'item_choix_non_generation_miniature' => 'មិន​បង្កើត​ទម្រង់​រូបភាព​សង្ខេប​ច្បាស់',
 	'item_choix_redacteurs' => 'អ្នក​សរសេរ​អត្ថបទ',
@@ -499,15 +494,15 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'taille_repertoire_cache' => 'ទំហំ​បច្ចុប្បន្ន​នៃ​ថត​លាក់ខ្លួន​។',
 	'text_article_propose_publication' => 'អត្ថបទ ត្រូវបានស្នើបោះផ្សាយ។',
 	'texte_acces_ldap_anonyme_1' => 'ម៉ាស៊ីន​មេLDAP មួយ​ចំនួន​មិន​អនុញ្ញាត​ចំពោះ​ការ​ប្រើប្រាស់​ជា​លក្ខណៈ​អនាមិក​នោះ​ទេ​។ នៅ​ក្នុង​ករណី​នេះ លោក​អ្នក​ត្រូវ​បង្ហាញ​នូវ​អ្នក​កំណត់​អត្ដសញ្ញាណ​ក្នុង​ការ​ប្រើប្រាស់​ដំបូង ដើម្បី​អាច​ស្វែងរក​ព័ត៌មាន​នៅ​ក្នុង​ថត (directory) បន្ទាប់​ពី​នោះ​។ ប៉ុន្ដែ នៅ​ក្នុង​ករណី​ភាគច្រើន​ក្រឡោ​ន​ខាងក្រោម​នេះ​អាច​ទុក​ចំហ​ដដែល​។',
-	'texte_admin_effacer_01' => 'បញ្ជា​នេះ​លុប <i>all</i> ខ្លឹមសារ​នៃ​សំណុំ​ទិន្នន័យ រាប់​បញ្ចូល​ទាំង <i>all</i> លក្ខណៈ​តម្រូវ​សំរាប់​ការ​ប្រើប្រាស់​របស់​អ្នក​សរសេរ​អត្ថបទ និង​អ្នកគ្រប់គ្រង​ប្រព័ន្ធ​។ បន្ទាប់​ពី​ប្រើប្រាស់​វា លោក​អ្នក​ត្រូវ​តំឡើង SPIP ជា​ថ្មី ដើម្បី​បង្កើត​ទិន្នន័យ​ថ្មី និង​ការ​ប្រើប្រាស់​អ្នកគ្រប់គ្រង​លើក​ទី​មួយ​ម្ដងទៀត​។',
+	'texte_admin_effacer_01' => 'បញ្ជា​នេះ​លុប <i>all</i> ខ្លឹមសារ​នៃ​សំណុំ​ទិន្នន័យ រាប់​បញ្ចូល​ទាំង <i>all</i> លក្ខណៈ​តម្រូវ​សំរាប់​ការ​ប្រើប្រាស់​របស់​អ្នក​សរសេរ​អត្ថបទ និង​អ្នកគ្រប់គ្រង​ប្រព័ន្ធ​។ បន្ទាប់​ពី​ប្រើប្រាស់​វា លោក​អ្នក​ត្រូវ​តំឡើង SPIP ជា​ថ្មី ដើម្បី​បង្កើត​ទិន្នន័យ​ថ្មី និង​ការ​ប្រើប្រាស់​អ្នកគ្រប់គ្រង​លើក​ទី​មួយ​ម្ដងទៀត​។', # MODIF
 	'texte_adresse_annuaire_1' => '(​ប្រសិនបើ​ថត​របស់​លោក​អ្នក​ត្រូវ​បាន​តំឡើង​នៅ​ក្នុង​ម៉ាស៊ីន​តែ​មួយ​ដូច​គ្នា​នឹង​វ៉ិ​ប​សាយ​របស់​លោក​អ្នក វា​អាច «localhost»)',
 	'texte_ajout_auteur' => 'អ្នក​សរសេរ​កម្មវិធី​ខាងក្រោម​ត្រូវ​បាន​បញ្ចូល​ទៅ​ក្នុង​អត្ថបទៈ',
-	'texte_annuaire_ldap_1' => 'ប្រសិនបើ​លោក​អ្នក​អាច​ប្រើប្រាស់​ថត (directory) (LDAP) លោក​អ្នក​អាច​ប្រើប្រាស់​វា​ដើម្បី​បញ្ចូល​អ្នក​ប្រើប្រាស់​ក្រោម SPIP ដោយ​ស្វ័យប្រវត្ដិ​។',
+	'texte_annuaire_ldap_1' => 'ប្រសិនបើ​លោក​អ្នក​អាច​ប្រើប្រាស់​ថត (directory) (LDAP) លោក​អ្នក​អាច​ប្រើប្រាស់​វា​ដើម្បី​បញ្ចូល​អ្នក​ប្រើប្រាស់​ក្រោម SPIP ដោយ​ស្វ័យប្រវត្ដិ​។', # MODIF
 	'texte_article_statut' => 'ស្ថានភាព​អត្ថបទ',
 	'texte_article_virtuel' => 'អត្ថបទ​ជាក់ស្ដែង',
 	'texte_article_virtuel_reference' => '<b>Virtual article:</b> អត្ថបទ​យោង​នៅ​ក្នុង​វ៉ិ​ប​សាយ SPIP របស់​លោក​អ្នក ប៉ុន្ដែ​ត្រូវ​កំណត់​ទិស​ដៅ​ថ្មី​ទៅ​កាន់ URL មួយ​ផ្សេង​ទៀត​។ ដើម្បី​លុប​ការ​កំណត់​ទិស​ដៅ​ជា​ថ្មី​នេះ សូម​លុបURL ខាងលើ​។',
 	'texte_aucun_resultat_auteur' => 'គ្មាន​លទ្ធផល​សំរាប់ \\"@cherche_auteur@\\"។',
-	'texte_auteur_messagerie' => 'វ៉ិ​ប​សាយ​នេះ​អាច​តាមដាន​ជា​បន្ដបន្ទាប់​នូវ​បញ្ជី​អ្នក​សរសេរ​អត្ថបទ​ដែល​បាន​ភ្ជាប់ ដែល​អនុញ្ញាត​ឱ្យ​លោក​អ្នក​ដោះ​ដូរ​សារ​តាម​ពេល​ជាក់ស្ដែង​។ លោក​អ្នក​អាច​សំរេច​មិន​បង្ហាញខ្លួន​នៅ​ក្នុង​បញ្ជី​នេះ (​ដូច្នេះ​លោក​អ្នក​ស្ថិត​ក្នុង​សភាព “​មើល​មិនឃើញ​” (\\"invisible\\") សំរាប់​អ្នក​ប្រើប្រាស់​ផ្សេង​ទៀត​។​)',
+	'texte_auteur_messagerie' => 'វ៉ិ​ប​សាយ​នេះ​អាច​តាមដាន​ជា​បន្ដបន្ទាប់​នូវ​បញ្ជី​អ្នក​សរសេរ​អត្ថបទ​ដែល​បាន​ភ្ជាប់ ដែល​អនុញ្ញាត​ឱ្យ​លោក​អ្នក​ដោះ​ដូរ​សារ​តាម​ពេល​ជាក់ស្ដែង​។ លោក​អ្នក​អាច​សំរេច​មិន​បង្ហាញខ្លួន​នៅ​ក្នុង​បញ្ជី​នេះ (​ដូច្នេះ​លោក​អ្នក​ស្ថិត​ក្នុង​សភាព “​មើល​មិនឃើញ​” (\\"invisible\\") សំរាប់​អ្នក​ប្រើប្រាស់​ផ្សេង​ទៀត​។​)', # MODIF
 	'texte_auteurs' => 'អ្នក​សរសេរ​កម្មវិធី',
 	'texte_choix_base_1' => 'ជ្រើសយក មូលដ្ឋានទិន្នន័យ របស់អ្នក៖',
 	'texte_choix_base_2' => 'ម៉ាស៊ីន​មេMySQL មាន​សំណុំ​ទិន្នន័យ​ច្រើន​។',
@@ -575,11 +570,10 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'texte_titre_02' => 'ប្រធានបទៈ',
 	'texte_titre_obligatoire' => '<b>Title</b> [ចាំបាច់]',
 	'texte_travail_article' => 'បាន​ដំណើរការ​លើ​អត្ថបទ​នេះ @date_diff@ នាទី​ក្រោម​មក',
-	'texte_travail_collaboratif' => 'ប្រសិនបើជា​រឿយៗ មាន​អ្នក​សរសេរ​កម្មវិធី​ច្រើន​អាច​ធ្វើការ​ងារ​លើ​អត្ថបទ​តែ​មួយ ប្រព័ន្ធ​អាច​កត់សំគាល់​ការងារ​ថ្មី​ជាងគេ «opened&raquo។ អត្ថបទ​ត្រូវ​រៀបចំ​ឱ្យ​មាន​របៀបរៀបរយ ដើម្បី​ជៀសវាង​ការ​កែប្រែ​រួម​គ្នា​ដែល​ធ្វើ​ឡើង​។ ជម្រើស​នេះ​ត្រូវ​បាន​បិទមុខ​ងារ​ដោយ​ក្រុមហ៊ុន​ផលិត ដើម្បី​ជៀស​វា​ពី​ការ​រំលឹក​មិន​ចាំបាច់​។ សារ​។',
+	'texte_travail_collaboratif' => 'ប្រសិនបើជា​រឿយៗ មាន​អ្នក​សរសេរ​កម្មវិធី​ច្រើន​អាច​ធ្វើការ​ងារ​លើ​អត្ថបទ​តែ​មួយ ប្រព័ន្ធ​អាច​កត់សំគាល់​ការងារ​ថ្មី​ជាងគេ «opened&raquo។ អត្ថបទ​ត្រូវ​រៀបចំ​ឱ្យ​មាន​របៀបរៀបរយ ដើម្បី​ជៀសវាង​ការ​កែប្រែ​រួម​គ្នា​ដែល​ធ្វើ​ឡើង​។ ជម្រើស​នេះ​ត្រូវ​បាន​បិទមុខ​ងារ​ដោយ​ក្រុមហ៊ុន​ផលិត ដើម្បី​ជៀស​វា​ពី​ការ​រំលឹក​មិន​ចាំបាច់​។ សារ​។', # MODIF
 	'texte_vide' => 'ទទេ',
 	'texte_vider_cache' => 'លុបសំអាត សតិភ្ជាប់',
 	'titre_admin_tech' => 'តំហែទាំ បច្ចេកទេស',
-	'titre_admin_vider' => 'តំហែទាំ បច្ចេកទេស',
 	'titre_cadre_afficher_article' => 'បង្ហាញ អត្ថបទ៖',
 	'titre_cadre_afficher_traductions' => 'បង្ហាញ ស្ថានភាពប្រែសំរួល សំរាប់ ភាសាខាងក្រោម ៖',
 	'titre_cadre_ajouter_auteur' => 'បន្ថែម​អ្នក​សរសេរ​កម្មវិធី',
@@ -620,5 +614,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'utf8_convert_erreur_orig' => 'កំហុស ៖ មិនគាំទ្រ កញ្ចប់អក្សរ @charset@។',
 
 	// V
-	'version' => 'កំណែ ៖'
-);
+	'version' => 'កំណែ ៖',
+];
