@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=my
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'activer_plugin' => 'ထပ်ထည့်သည့် pluginကို အ​တည်ပြုရန်',
@@ -23,7 +19,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'avis_connexion_echec_3' => '<b>N.B.</b> MySQL အချက်လက် သိုလှောင်မှုကို  ဆာဗာအမှတ်​စဉ်တွင် အသုံးမပြုမီ အသက်သွင်းရန် <b>လိုအပ်ပါသည်</b> အကယ်၍ ဆက်သွယ်၍မရပါက သင်အမှန်တကယ် လိုအပ်မှုကို သေချာအောင်လုပ်ပါ', # MODIF
 	'avis_connexion_ldap_echec_1' => 'LDAP ဆာဗာသို့ ဆက်သွယ်၍မရပါ',
 	'avis_connexion_ldap_echec_2' => 'အရင်စာမျက်နှာသို့ ပြန်သွားပြီး အချက်လက်များကို ပြန်စစ်ဆေးပါ',
-	'avis_connexion_ldap_echec_3' => 'သုံးစွဲသူအသစ်များ ထည့်သွင်းရန် LDAP ကို တခြားနည်းဖြင့် အသုံးမပြုပါနှင့်',
+	'avis_connexion_ldap_echec_3' => 'သုံးစွဲသူအသစ်များ ထည့်သွင်းရန် LDAP ကို တခြားနည်းဖြင့် အသုံးမပြုပါနှင့်', # MODIF
 	'avis_deplacement_rubrique' => 'သတိပေးချက်။ သည်အပိုင်းတွင် @contient_breves@ သတင်းစကား @scb@ ပါဝင်ပါသည်။ ၄င်းကို ဖယ်ရှားလိုပါက သည်လုပ်ဆောင်ချက်ကို ပြန်လည်အတည်ပြုပါ',
 	'avis_erreur_connexion_mysql' => 'MySQL ချိတ်ဆက်မှု အခက်ခဲဖြစ်သည်',
 	'avis_espace_interdit' => '<b>တားမြစ်နယ်မြေ</b> <div>SPIP ကို ထည့်သွင်းပြီးဖြစ်သည်</div>',
@@ -45,10 +41,10 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'bouton_envoyer_message' => 'နောက်ဆုံးစာကို ပို့ပါ',
 	'bouton_modifier' => 'ပြန်လည်ပြုပြင်မွမ်းမံသည်',
 	'bouton_radio_afficher' => 'ပြပါ',
-	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'ဆက်သွယ်သော စာတည်းများကို ပြပါ',
+	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'ဆက်သွယ်သော စာတည်းများကို ပြပါ', # MODIF
 	'bouton_radio_envoi_annonces_adresse' => 'ကြေငြာချက်များကို ဤလိပ်စာများသို့ ပေးပို့ရန်',
 	'bouton_radio_envoi_liste_nouveautes' => 'နောက်ဆုံးရသတင်း စာရင်းကို ပေးပို့ရန်',
-	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'အချိတ်အဆက်ရှိထားသော စာတည်းများစာရင်းတွင် မ​ပေါ်စေလိုပါ',
+	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'အချိတ်အဆက်ရှိထားသော စာတည်းများစာရင်းတွင် မ​ပေါ်စေလိုပါ', # MODIF
 	'bouton_radio_non_envoi_annonces_editoriales' => 'စာတည်းများ၏ ကြေငြာချက်များ ပေးပို့ရန်မလို',
 	'bouton_redirection' => 'ပြန်လည်ရည်ညွှန်းသည်',
 	'bouton_relancer_installation' => 'ပြန်လည် ထည့်သွင်းရန်',
@@ -58,7 +54,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'bouton_vider_cache' => 'မှတ်ဉာဏ်ကို ပျယ်ဖျက်ရန်',
 
 	// C
-	'cache_modifiable_webmestre' => 'ဤကန့်သတ်ချက်ကို webmasterမှ ပြန်လည်ပြုပြင်မွမ်းမံနိုင်သည်',
+	'cache_modifiable_webmestre' => 'ဤကန့်သတ်ချက်ကို webmasterမှ ပြန်လည်ပြုပြင်မွမ်းမံနိုင်သည်', # MODIF
 	'calendrier_synchro' => '<b>iCal</b> နှင့်အတူ ပြက္ခဒိန် ကိုသင်အသုံးပြုလျှင် ဤဝက်ဘ်ဆိုက်၏ သတင်းအချက်လက်များနှင့် ၄င်းကို ​ချိတ်ဆက်နိုင်ပါသည်',
 	'connexion_ldap' => 'ချိတ်ဆက်မှု',
 
@@ -77,7 +73,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'entree_cle_pgp' => 'သင့် PGP ကီး',
 	'entree_contenu_rubrique' => '(ပါဝင်သည့်အကြောင်းအရာ အကျဉ်းချုပ်)',
 	'entree_identifiants_connexion' => 'သင့်ဆက်သွယ်မှုကို ဆန်းစစ်သူများ၊',
-	'entree_informations_connexion_ldap' => 'LDAP အချက်လက်များဖြင့် ဖြည့်စွက်ပါ၊ လိုအပ်သောအချက်လက်များကို သင့်ကွန်ရက် ကြီးကြပ်သူထံမှ ရနိုင်ပါသည်',
+	'entree_informations_connexion_ldap' => 'LDAP အချက်လက်များဖြင့် ဖြည့်စွက်ပါ၊ လိုအပ်သောအချက်လက်များကို သင့်ကွန်ရက် ကြီးကြပ်သူထံမှ ရနိုင်ပါသည်', # MODIF
 	'entree_infos_perso' => 'သင်ဘယ်သူလဲ?',
 	'entree_interieur_rubrique' => 'အခန်းကဏ္ဍထဲတွင်',
 	'entree_liens_sites' => '<b>ဆက်နွယ်မှု</b> (လေ့လာရန်ကိုး ကားဝက်ဘ်ဆိုက်)',
@@ -138,12 +134,12 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'impossible_modifier_pass_auteur' => 'Impossible de modifier le mot de passe.', # MODIF
 	'info_1_article' => '၁ ဆောင်းပါး',
 	'info_activer_cookie' => 'ကိုယ်ပိုင်နေရာနှင့် အများသုံးဝက်ဘ်ဆိုက်ကြားသို့ အလွယ်တကူကူးနိုင်ရန် သင့်ကိုခွင့်ပြုထားသော  <b>ကြီးကြပ်သူကွတ်ကီး</b>တခုကို သင်အသက်သွင်းနိုင်သည်',
-	'info_administrateur' => 'ကြီးကြပ်သူ',
-	'info_administrateur_1' => 'ကြီးကြပ်သူ',
+	'info_administrateur' => 'ကြီးကြပ်သူ', # MODIF
+	'info_administrateur_1' => 'ကြီးကြပ်သူ', # MODIF
 	'info_administrateur_2' => 'ဝက်ဆိုက်၏ (<i>သတိပေးချက်နှင့်အသုံးပြုပါ</i>)',
-	'info_administrateur_site_01' => 'အကယ်၍သင်သည် ဝက်ဘ်ဆိုက် ကြီးကြပ်သူဖြစ်ပါက',
+	'info_administrateur_site_01' => 'အကယ်၍သင်သည် ဝက်ဘ်ဆိုက် ကြီးကြပ်သူဖြစ်ပါက', # MODIF
 	'info_administrateur_site_02' => 'ဤချိတ်ဆက်မှုပေါ် နှိပ်လိုက်',
-	'info_administrateurs' => 'ဝက်ဘ်ဆိုက် ကြီးကြပ်သူများ',
+	'info_administrateurs' => 'ဝက်ဘ်ဆိုက် ကြီးကြပ်သူများ', # MODIF
 	'info_administrer_rubrique' => 'သင်သည်အခန်းကဏ္ဍကို စီမံခန့်ခွဲနိုင်သည်',
 	'info_adresse' => 'လိပ်စာသို့',
 	'info_adresse_url' => 'အများဆိုင်ရာ ဝက်ဘ်ဆိုက်လိပ်စာ',
@@ -169,7 +165,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_chapeau' => 'စာရေးခုံ',
 	'info_chapeau_2' => 'မိတ်ဆက်ခြင်း',
 	'info_chemin_acces_1' => 'ရွေးချယ်ရန်များ <b>ဖိုင်လမ်းညွှန်ထဲရှိ ဆက်သွယ်ရန်လမ်းကြောင်း</b>',
-	'info_chemin_acces_2' => 'အခုမှစပြီး ဖိုင်တွဲသို့ ဆက်သွယ်ရန် လိပ်စာလမ်းကြောင်းကို တပ်ဆင်ရမည်။ ဤလိပ်စာသည် သုံးစွဲသူ သိမ်းဆည်းထားသော ကိုယ်ရေးရာဇဝင် ဖိုင်များကို ရယူရန် မရှိမဖြစ်လိုအပ်ပါသည်။',
+	'info_chemin_acces_2' => 'အခုမှစပြီး ဖိုင်တွဲသို့ ဆက်သွယ်ရန် လိပ်စာလမ်းကြောင်းကို တပ်ဆင်ရမည်။ ဤလိပ်စာသည် သုံးစွဲသူ သိမ်းဆည်းထားသော ကိုယ်ရေးရာဇဝင် ဖိုင်များကို ရယူရန် မရှိမဖြစ်လိုအပ်ပါသည်။', # MODIF
 	'info_chemin_acces_annuaire' => 'ရွေးချယ်ရန်များ <b>ဖိုင်လမ်းညွှန်ထဲရှိ ဆက်သွယ်ရန်လမ်းကြောင်း</b>',
 	'info_choix_base' => 'တတိယအဆင့်',
 	'info_classement_1' => ' out of @liste@',
@@ -206,12 +202,11 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_exportation_base' => 'အချက်အလက် သိုလှောင်မှုကို @archive@သို့ပို့ပါ',
 	'info_facilite_suivi_activite' => 'To facilitate the follow-up of the site’s editorial;  activities, SPIP can send notification by email, to an editor’s mailing list for instance, of publication requests and article validations.', # MODIF
 	'info_fichiers_authent' => 'ဖိုင်\\".htpasswd\\"ကို အတည်ပြုပါ',
-	'info_forums_abo_invites' => 'သင့်ဝက်ဘ်ဆိုက် ဖိုရမ်မှာ အခမဲ့ဖြစ်သည်၊ ဝင်ရောက်ကြည့်ရှုသူများက အများသုံး ဝက်ဘ်ဆိုက်ပေါ်တွင် မှတ်ပုံတင်လိမ့်မည်',
+	'info_forums_abo_invites' => 'သင့်ဝက်ဘ်ဆိုက် ဖိုရမ်မှာ အခမဲ့ဖြစ်သည်၊ ဝင်ရောက်ကြည့်ရှုသူများက အများသုံး ဝက်ဘ်ဆိုက်ပေါ်တွင် မှတ်ပုံတင်လိမ့်မည်', # MODIF
 	'info_gauche_admin_tech' => '<b>ဝက်ဘ်ဆိုက်ကြီးကြပ်သူသာ ဤစာမျက်နှာသို့ဝင်နိုင်သည်၊</b><p> သည်ဟာက လုပ်ငန်းများစွာကို ထိန်းသိမ်းရန်အတွက် အထောက်ကူပြုသည်၊  အချို့က ဝက်ဘ်ဆိုက်ပေါ်တွင် လိုအပ်သော FTP ဆက်သွယ်မှုကို လုပ်ဆောင်စေနိုင်သည်</p>', # MODIF
-	'info_gauche_admin_vider' => '<b>ဝက်ဘ်ဆိုက်ကြီးကြပ်သူသာ ဤစာမျက်နှာသို့ဝင်နိုင်သည်၊</b><p> သည်ဟာက လုပ်ငန်းများစွာကို ထိန်းသိမ်းရန်အတွက် အထောက်ကူပြုသည်၊  အချို့က ဝက်ဘ်ဆိုက်ပေါ်တွင် လိုအပ်သော FTP ဆက်သွယ်မှုကို လုပ်ဆောင်စေနိုင်သည်</p>', # MODIF
-	'info_gauche_auteurs' => 'ဝက်ဘ်ဆိုက်အားလုံး၏ စာရေးသူများကို သည်မှာမြင်နိုင်သည်၊ ၎င်းတို့တခုစီ၏ အနေအထားများကို ရောင်စုံပုံဖြင့် ဖော်ပြထားသည် (ဝက်ဘ်ဆိုက်ကြီးကြပ်သူ = စိမ်းရောင်။ စာတည်း = အဝါရောင်)',
+	'info_gauche_auteurs' => 'ဝက်ဘ်ဆိုက်အားလုံး၏ စာရေးသူများကို သည်မှာမြင်နိုင်သည်၊ ၎င်းတို့တခုစီ၏ အနေအထားများကို ရောင်စုံပုံဖြင့် ဖော်ပြထားသည် (ဝက်ဘ်ဆိုက်ကြီးကြပ်သူ = စိမ်းရောင်။ စာတည်း = အဝါရောင်)', # MODIF
 	'info_gauche_auteurs_exterieurs' => 'ဝက်ဘ်ဆိုက်နှင့် ဆက်သွယ်မှုမရှိသော ပြင်ပစာရေးသူများကို အပြာရောင်ဖြင့်ဖော်ပြသည်၊ အမှိုက်ပုံးထဲ ထည့်၍ ၎င်းစာရေးသူများကို ဖျက်ပစ်ပါ', # MODIF
-	'info_gauche_messagerie' => 'စာပေးပို့ခြင်းက စာတည်းများကြားတွင် စာများကိုကာကွယ်ရန် စာအပြန်အလှန်ဖလှယ်ခြင်း (သင့်ကိုယ်ပိုင်သုံးရန်) သို့မဟုတ် ကိုယ်ပိုင်နေရာ၏ ကနဦးစာမျက်နှာတွင် ကြေငြာချက်များကို ဖော်ပြရန်ခွင့်ပြူသည် (အကယ်၍သင်သည် ကြီးကြပ်သူဖြစ်ခဲ့လျှင်ပေါ့)',
+	'info_gauche_messagerie' => 'စာပေးပို့ခြင်းက စာတည်းများကြားတွင် စာများကိုကာကွယ်ရန် စာအပြန်အလှန်ဖလှယ်ခြင်း (သင့်ကိုယ်ပိုင်သုံးရန်) သို့မဟုတ် ကိုယ်ပိုင်နေရာ၏ ကနဦးစာမျက်နှာတွင် ကြေငြာချက်များကို ဖော်ပြရန်ခွင့်ပြူသည် (အကယ်၍သင်သည် ကြီးကြပ်သူဖြစ်ခဲ့လျှင်ပေါ့)', # MODIF
 	'info_gauche_statistiques_referers' => 'ဤစာမျက်နှာတွင်  <i>အကိုးကားယူသည့်နေရာများ</i> စာရင်းကို ဖော်ပြမည်။ ၄င်းသည် သင့်ကိုယ်ပိုင်ဝက်ဘ်ဆိုက်သို့ ချိတ်ဆက်ထားသော ဝက်ဘ်​ဆိုက်များဖြစ်ပြီး မနေ့နှင့် ဒီနေ့အတွက်တရက်ချင်းစာရင်းဖြစ်သည်',
 	'info_gauche_visiteurs_enregistres' => 'ဤဝက်ဆိုက်၏ အများသုံးနေရာ အတွင်းဝင်ရောက်ကြည့်ရှုသူများမှတ်ပုံတင်ကို သင်မြင်မည်(ဖိုရမ်များ ခွင့်ပြုချက်ဖြင့်)',
 	'info_generation_miniatures_images' => 'ရုပ်ပုံများကို မြင်သာရန်ဖန်တီးနေသည်',
@@ -222,14 +217,14 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_image_process2' => '<b>N.B.</b> <i>ပုံရိပ်တခုမှ မတွေ့ရလျှင်၊ သင့်ဆာဗာသည် အဲဒီအတွက် တပ်ဆင်ထားခြင်း မရှိလို့ဖြစ်ပါမည်။ ဤလုပ်ဆောင်မှုကို သင်အလိုရှိတယ်ဆိုရင် ဝက်ဘ်ဝန်ဆောင်မှုကို ဆက်သွယ်ပြီးတော့ «GD» သို့မဟုတ် «Imagick» extensions ကို ထည့်သွင်းပေးပါရန် တောင်းဆိုပါ။</i>', # MODIF
 	'info_images_auto' => 'ပုံများကို အလိုအလျောက်တွက်ချက်သည်',
 	'info_informations_personnelles' => 'ပဉ္စမအဆင့် <b>ကိုယ်ရေးကိုယ်တာအချက်လက်</b>',
-	'info_inscription_automatique' => 'စာတည်များကို ​အလိုအလျေက်မှတ်ပုံတင်ခြင်း',
+	'info_inscription_automatique' => 'စာတည်များကို ​အလိုအလျေက်မှတ်ပုံတင်ခြင်း', # MODIF
 	'info_jeu_caractere' => 'ဝက်ဘ်ဆိုက်သွင်ပြင်လက္ခဏာစု',
 	'info_jours' => 'ရက်များ',
 	'info_laisser_champs_vides' => '(ဤဖိုင်ကို ဗလာဖြစ်အောင်လုပ်ပါ)',
 	'info_langues' => 'ဝက်ဘ်ဆိုက်ဘာသာစကားများ',
 	'info_ldap_ok' => 'LDAP မှန်ကန်မှု စစ်ဆေးခြင်းကို စတင်ထည့်သွင်းနေသည်',
 	'info_lien_hypertexte' => 'ဆက်နွယ်မှု',
-	'info_liste_redacteurs_connectes' => 'ဆက်သွယ်သည့် စာတည်းစာရင်းများ',
+	'info_liste_redacteurs_connectes' => 'ဆက်သွယ်သည့် စာတည်းစာရင်းများ', # MODIF
 	'info_login_existant' => 'ဝင်ရောက်မှုကို ပိတ်ပင်ထားပြီး',
 	'info_login_trop_court' => 'ဝင်ရောက်မှုတိုလွန်းသည်',
 	'info_maximum' => 'အများဆုံး',
@@ -244,7 +239,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_mon_site_spip' => 'SPIP ဆိုက်',
 	'info_moyenne' => 'ပျမ်းမျှ',
 	'info_multi_cet_article' => 'သည်ဆောင်းပါး ဘာသာစကား',
-	'info_multi_langues_choisies' => 'အောက်ဖော်ပြပါ ဘာသာစကားများကို စားတည်းများ​ ​ရွေးချယ်နိုင်အောင် ပြုလုပ်ပါ။ သင့်ဆိုက်တွင် အသုံးပြုနေသော ဘာသာစကားများကို ပြန်လည် ပိတ်ပင်၍ မရနိုင်တော့ပါ။',
+	'info_multi_langues_choisies' => 'အောက်ဖော်ပြပါ ဘာသာစကားများကို စားတည်းများ​ ​ရွေးချယ်နိုင်အောင် ပြုလုပ်ပါ။ သင့်ဆိုက်တွင် အသုံးပြုနေသော ဘာသာစကားများကို ပြန်လည် ပိတ်ပင်၍ မရနိုင်တော့ပါ။', # MODIF
 	'info_multi_secteurs' => 'ဆိုက်၏ ပထမဆုံး စာမျက်နှာတွင်တွင် အခန်းကဏ္ဍများကိုသာ မြင်စေလိုပါသလား',
 	'info_nom' => 'အမည်',
 	'info_nom_destinataire' => 'ပါဝင်သူအမည်',
@@ -262,8 +257,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_nouvelle_traduction' => 'ဘာသာပြန်အသစ်',
 	'info_numero_article' => 'ဆောင်းပါးနံပါတ်',
 	'info_obligatoire_02' => '[လိုအပ်ပါသည်]', # MODIF
-	'info_option_accepter_visiteurs' => 'ဝင်ရောက်လည်ပတ်သူများအား အ​များသုံးဝက်ဘ်ဆိုက်မှ မှတ်ပုံတင်ရန်ခွင့်ပြုသည်',
-	'info_option_ne_pas_accepter_visiteurs' => 'ဝင်ရောက်လည်ပတ်သူမှတ်ပုံတင်ခြင်းကို ငြင်းဆိုသည်',
+	'info_option_accepter_visiteurs' => 'ဝင်ရောက်လည်ပတ်သူများအား အ​များသုံးဝက်ဘ်ဆိုက်မှ မှတ်ပုံတင်ရန်ခွင့်ပြုသည်', # MODIF
+	'info_option_ne_pas_accepter_visiteurs' => 'ဝင်ရောက်လည်ပတ်သူမှတ်ပုံတင်ခြင်းကို ငြင်းဆိုသည်', # MODIF
 	'info_options_avancees' => 'အဆင့်မြှင့်ရွေးချယ်မှုများ',
 	'info_ou' => 'သို့မဟုတ်',
 	'info_page_interdite' => 'တားမြစ်စာမျက်နှာ',
@@ -287,7 +282,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_ps' => 'စာကြွင်း',
 	'info_publier' => 'ထုတ်ဝေပါ',
 	'info_publies' => 'သင့်ဆောင်းပါးများကို အွန်လိုင်​တွင်ထုတ်လွင့်သည်',
-	'info_question_accepter_visiteurs' => 'သင့်ဝက်ဘ်ဆိုက်သို့ ဝင်ရောက်လည်ပတ်သူများကို ကိုယ်ပိုင်နေရာသို့ ဝင်စရာမလိုဘဲ မှတ်ပုံတင်ရန်ခွင့်ပြုထားပါက အောက်ပါရွေးချယ်မှုများကို ပြူလုပ်ပါ',
+	'info_question_accepter_visiteurs' => 'သင့်ဝက်ဘ်ဆိုက်သို့ ဝင်ရောက်လည်ပတ်သူများကို ကိုယ်ပိုင်နေရာသို့ ဝင်စရာမလိုဘဲ မှတ်ပုံတင်ရန်ခွင့်ပြုထားပါက အောက်ပါရွေးချယ်မှုများကို ပြူလုပ်ပါ', # MODIF
 	'info_question_inscription_nouveaux_redacteurs' => 'စာတည်းအသစ်များ မှတ်ပုံတင်ခွင့်ကို အများဆိုင်နေရာမှ လုပ်ဆောင်ခွင့် ပေးလိုပါသလား? သင်ခွင့်ပြုမည်ဆိုလျှင် လာလည်သူများသည်လည်း အလိုအလျှောက် ဖောင်ကိုအသုံးပြု၍ မှတ်ပုံတင်နိုင်မည်ဖြစ်သည်။ သူတို့ဖန်တီးထားသော ဆောင်းပါးများကို တိုက်ရိုက်မွမ်းမံ နိုင်မည်ဖြစ်သဖြင့် နှစ်သက်ပါလိမ့်မည်။<blockquote><i> မှတ်ပုံတင်ခြင်းလုပ်ဆောင်နေစဉ် ကိုယ်ပိုင်ကန့်သတ်နေရာသို့ ဝင်ရောက်နိုင်ရန် လိုအပ်သော အချက်အလက်များကို အလိုအလျှောက်အီးမေးလ်မှ ရောက်လာပါလိမ့်မည်။ တချို့သော ဝက်ဘ်ဝန်ဆောင်မှုလုပ်ငန်းများသည် ဤအလိုအလျှောက် စာပို့ခြင်းကို လက်မခံကြပေ၊ ဤသို့ဖြစ်နေလျှင် ဤစာပို့ခြင်းသည် အ​ဆင်ပြေမည်မဟုတ်ပါ။', # MODIF
 	'info_racine_site' => 'ဝက်ဘ်ဆိုက် ပင်မဇစ်မြစ်',
 	'info_recharger_page' => 'မိနစ်အနည်းငယ်အတွင်း ဤစာမျက်နှာကို ပြန်ဖွင့်ပါ',
@@ -301,7 +296,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_refuses' => 'သင့်ဆောင်းပါးကို ငြင်းပယ်သည်',
 	'info_reglage_ldap' => 'ရွေးချယ်ရန်များ - <b>LDAP တင်သွင်းမှုကို ညှိနေသည်</b>',
 	'info_renvoi_article' => '<b>လမ်းကြောင်းလွဲခြင်း</b> ဤဆောင်ပါးသည် () သို့လမ်းလွဲနေသည်',
-	'info_reserve_admin' => 'ကြီးကြပ်သူကသာ ဤလိပ်စာများကို ပြုပြင်မွမ်းမံခွင့်ရှိသည်',
+	'info_reserve_admin' => 'ကြီးကြပ်သူကသာ ဤလိပ်စာများကို ပြုပြင်မွမ်းမံခွင့်ရှိသည်', # MODIF
 	'info_restreindre_rubrique' => 'ကဏ္ဍများ စီမံခန့်ခွဲမှု ကန့်သတ်ချက်',
 	'info_resultat_recherche' => 'ရှာဖွေမှုရလာဒ်များ',
 	'info_rubriques' => 'ကဏ္ဍများ',
@@ -320,13 +315,13 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_sites_proxy' => 'ကြားခံဆာဗာကို အသုံးပြုနေသည်',
 	'info_sites_trouves' => 'ဝက်ဘ်ဆိုက်များကို တွေ့သည်',
 	'info_sous_titre' => 'ခေါင်းစဉ်ခွဲ',
-	'info_statut_administrateur' => 'ကြီးကြပ်သူ',
+	'info_statut_administrateur' => 'ကြီးကြပ်သူ', # MODIF
 	'info_statut_auteur' => 'ဤစာရေးသူ၏ အခြေနေ', # MODIF
 	'info_statut_auteur_a_confirmer' => 'အတည်ပြုရန် မှတ်တမ်းတင်ခြင်း',
 	'info_statut_auteur_autre' => 'အခြားအ​ခြေနေ',
 	'info_statut_redacteur' => 'စာတည်း',
-	'info_statut_utilisateurs_1' => 'တင်သွင်ထားသောအသုံးပြုသူများဿ သတ်မှတ်မထားသောအခြေနေ',
-	'info_statut_utilisateurs_2' => 'LDAP လမ်းညွှန်ထဲသို့ ပထမဆုံးအကြိမ် တင်ဆက်သော ပုဂ္ဂိုလ်၏ နေအထားကို ရွေးချယ်ပါ။ နောက်နောင်မှာလည်း အမှုစီတိုင်းပေါ်မူတည်ပြီး စာရေးသူ တယေက်ချင်းစီအတွက် ပြန်လည်မွမ်းမံနိုင်ပါသည်။',
+	'info_statut_utilisateurs_1' => 'တင်သွင်ထားသောအသုံးပြုသူများဿ သတ်မှတ်မထားသောအခြေနေ', # MODIF
+	'info_statut_utilisateurs_2' => 'LDAP လမ်းညွှန်ထဲသို့ ပထမဆုံးအကြိမ် တင်ဆက်သော ပုဂ္ဂိုလ်၏ နေအထားကို ရွေးချယ်ပါ။ နောက်နောင်မှာလည်း အမှုစီတိုင်းပေါ်မူတည်ပြီး စာရေးသူ တယေက်ချင်းစီအတွက် ပြန်လည်မွမ်းမံနိုင်ပါသည်။', # MODIF
 	'info_suivi_activite' => 'စာတည်းလုပ်ငန်း နောက်ဆက်တွဲ',
 	'info_surtitre' => 'ထိပ်စည်းခေါင်းစဉ်',
 	'info_syndication_integrale_1' => 'သင့်ဝက်ဘ်ဆိုက်တွင် အကျိုးတူဖိုင် (ကြည့်ရန် <a href=\\"@url@\\">@titre@</a>) ကို အခမဲ့ ကြည့်ရှုခွင့်ပေးသည်',
@@ -370,10 +365,10 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'intem_redacteur' => 'စာတည်း',
 	'item_accepter_inscriptions' => 'မှတ်ပုံတင်ခြင်းများကို ခွင့်ပြုသည်',
 	'item_activer_messages_avertissement' => 'သတိပေးတားမြစ်စာများကို အသက်သွင်းပါ',
-	'item_administrateur_2' => 'ကြီးကြပ်သူများ',
+	'item_administrateur_2' => 'ကြီးကြပ်သူများ', # MODIF
 	'item_afficher_calendrier' => 'ပြက္ခဒိန်တွင် ဖော်ပြပါ',
 	'item_autoriser_syndication_integrale' => 'ပူးတွဲချိတ်ဆက်မှုထဲတွင် ဆောင်းပါးအားလုံးပါဝင်သည်',
-	'item_choix_administrateurs' => 'ကြီးကြပ်သူများ',
+	'item_choix_administrateurs' => 'ကြီးကြပ်သူများ', # MODIF
 	'item_choix_generation_miniature' => 'ပုံများကို အလိုအလျောက် မြင်နိုင်ရန် ပြုလုပ်ပါ',
 	'item_choix_non_generation_miniature' => 'ပုံများကို မြင်နိုင်အောင်မလုပ်ပါ',
 	'item_choix_redacteurs' => 'စာတည်းများ',
@@ -453,15 +448,15 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'taille_repertoire_cache' => 'မှတ်ဉာဏ်၏ လက်ရှိအရွယ်စား',
 	'text_article_propose_publication' => 'ဆောင်းပါးကို ထုတ်ဝေရန် ထည့်သွင်းပြီးဖြစ်သည်၊ ဤဆောင်းပါးတွင် ဖိုရမ်မှသင့်အမြင်ကို တင်ပြနိုင်ပါသည်၊ (စာမျက်နှာအောက်တွင်)', # MODIF
 	'texte_acces_ldap_anonyme_1' => 'အချို့ LDAP ဆာဗာများသည် အမည်မသိသော ဝင်ရောက်မှုကို ခွင့်မပြုပါ။ ဤကိစ္စတွင် သတင်းအချက်အလက်များကို နောက်နောင်တွင် လမ်းညွှန်ထဲ၌ ရှာဖွေမှု ပြုနိုင်ရန် ဆက်သွယ်မှု အမှတ်အသားကို ​အရင်ဖော်ပြသင့်သည်။ သို့သော် ဖြစ်စဉ်အများစုတွင် အောက်ပါနေရာများကို ဗလာဖြစ်စေနိုင်သည်',
-	'texte_admin_effacer_01' => 'ဤစေခိုင်းချက်သည် အ​ချက်လက်သိုလှောင်မှုတွင် ပါဝင်သော အကြောင်းအရာ  <i>အားလုံး</i>  ကို ဖျက်ပစ်ပါ<i>all</i> စီမံကြီးကြပ်သူနှင့် စားတည်းများ ဝင်ရောက်ဆက်သွယ်ရန် အချက်အလက်များ။ ဤအရာကို စီရင်ပြီးရင်တော့ သိုလှောင်မှုအသစ်ကို ဖန်တီးရန်နှင့် စီမံကြီးကြပ်သူများ ပထမဆုံး ဝင်ရောက်နိုင်ရန် SPIP ကိုပြန်လည် ထည့်သွင်းရန်လိုအပ်သည်။',
+	'texte_admin_effacer_01' => 'ဤစေခိုင်းချက်သည် အ​ချက်လက်သိုလှောင်မှုတွင် ပါဝင်သော အကြောင်းအရာ  <i>အားလုံး</i>  ကို ဖျက်ပစ်ပါ<i>all</i> စီမံကြီးကြပ်သူနှင့် စားတည်းများ ဝင်ရောက်ဆက်သွယ်ရန် အချက်အလက်များ။ ဤအရာကို စီရင်ပြီးရင်တော့ သိုလှောင်မှုအသစ်ကို ဖန်တီးရန်နှင့် စီမံကြီးကြပ်သူများ ပထမဆုံး ဝင်ရောက်နိုင်ရန် SPIP ကိုပြန်လည် ထည့်သွင်းရန်လိုအပ်သည်။', # MODIF
 	'texte_adresse_annuaire_1' => '(သင့်လမ်းညွှန်ကို စက်တခုထဲတွင် ထည့်သွင်းထားပါက ဤသို့ပေါ် «localhost»လိမ့်မည်။)',
 	'texte_ajout_auteur' => 'အောက်ပါစာ​ရေးသူကို ဆောင်းပါးနှင့်ချိတ်ဆက်ပြီးဖြစ်သည်',
-	'texte_annuaire_ldap_1' => '(LDAP) အညွှန်းကိုအသုံးပြုနိုင်ပါက အောက်ရှိ တင်သွင်းထားသော အသစ်သုံးစွဲသူများကို အလိုအလျောက် အသုံးပြုနိုင်သည်',
+	'texte_annuaire_ldap_1' => '(LDAP) အညွှန်းကိုအသုံးပြုနိုင်ပါက အောက်ရှိ တင်သွင်းထားသော အသစ်သုံးစွဲသူများကို အလိုအလျောက် အသုံးပြုနိုင်သည်', # MODIF
 	'texte_article_statut' => 'ဆောင်းပါးအဆင့်',
 	'texte_article_virtuel' => 'အရေးကြီးသော ဆောင်းပါး',
 	'texte_article_virtuel_reference' => '<b>အရေးကြီးသော ​ဆောင်းပါ</b> သင့် ဆိုက်ရှိကိုးကား ဆောင်းပါးဖြစ်သော်လည်း အခြားဝက်ဘ်ဆိုက်လိပ်စာသို့ လမ်းလွဲနေသည်၊ အထက်ပါဝက်ဘ်ဆိုက်လိပ်စာကို ဖျက်ပစ်ခြင်းဖြင့် ပြန်တည့်နိုင်သည်',
 	'texte_aucun_resultat_auteur' => '\\"@cherche_auteur@\\"အတွက်ရလာဒ်မရှိပါ',
-	'texte_auteur_messagerie' => 'ဤဆိုက်သည် ချိတ်ဆက်​ထားသော စာတည်းများကို အဆက်မပြတ်​ စောင့်ကြည့်နိုင်သည်၊ ဤလုပ်ဆောင်ချက်သည် သတင်းစကားများကို ချက်ချင်းဖလှယ်နိုင်ရန် လုပ်ဆောင်ပေးသည်။ ဤစာရင်းထဲတွင် သင့်နာမည် မပါအောင် သင့်မှာရွေးချယ်ခွင့်ရှိသည်။ (သင့်ကိုတခြားသူများမှ မြင်နိုင်မည် မဟုတ်တော့ပါ)',
+	'texte_auteur_messagerie' => 'ဤဆိုက်သည် ချိတ်ဆက်​ထားသော စာတည်းများကို အဆက်မပြတ်​ စောင့်ကြည့်နိုင်သည်၊ ဤလုပ်ဆောင်ချက်သည် သတင်းစကားများကို ချက်ချင်းဖလှယ်နိုင်ရန် လုပ်ဆောင်ပေးသည်။ ဤစာရင်းထဲတွင် သင့်နာမည် မပါအောင် သင့်မှာရွေးချယ်ခွင့်ရှိသည်။ (သင့်ကိုတခြားသူများမှ မြင်နိုင်မည် မဟုတ်တော့ပါ)', # MODIF
 	'texte_auteurs' => 'စာရေးဆရာများ',
 	'texte_choix_base_1' => 'သင့်အချက်လက်သိုလှောင်မှုကိုရွေးချယ်ပါ',
 	'texte_choix_base_2' => 'MySQL ဆာဗာတွင် အချက်လက်သိုလှောင်မှုများ များစွာပါဝင်သည်',
@@ -528,11 +523,10 @@ proxy လိပ်စာကို အောက်တွင်​ဖော်ပ
 	'texte_titre_02' => 'အကြောင်းအရာ',
 	'texte_titre_obligatoire' => '<b>ခေါင်းစဉ်</b> [လိုအပ်ပါသည်]',
 	'texte_travail_article' => '@nom_auteur_modif@သည် ဤဆောင်းပါးတွင် လွန်ခဲ့သော မိနစ် @date_diff@ ကအလုပ်လုပ်ပြီးပြီ',
-	'texte_travail_collaboratif' => 'စာတည်းများ ဆောင်းပါးတပုဒ်ပေါ်တွင် အတူတူလုပ်ဆောင်နေပါက၊ မှားယွင်းသော လုပ်ဆောင်မှုများ မဖြစ်ရန်၊ နောက်ဆုံး စာတည်း «opened&raquo ဟုဖော်ပြပါမည်။ ဒီသတိပေး စာစောင်ဟာ အနောက်အယှက်များ မဖြစ်စေရန် ကနဦးမှ ပိတ်ပင်ထားပါသည်။',
+	'texte_travail_collaboratif' => 'စာတည်းများ ဆောင်းပါးတပုဒ်ပေါ်တွင် အတူတူလုပ်ဆောင်နေပါက၊ မှားယွင်းသော လုပ်ဆောင်မှုများ မဖြစ်ရန်၊ နောက်ဆုံး စာတည်း «opened&raquo ဟုဖော်ပြပါမည်။ ဒီသတိပေး စာစောင်ဟာ အနောက်အယှက်များ မဖြစ်စေရန် ကနဦးမှ ပိတ်ပင်ထားပါသည်။', # MODIF
 	'texte_vide' => 'မရှိပါ',
 	'texte_vider_cache' => 'မှတ်ထားချက်မရှိပါ',
 	'titre_admin_tech' => 'နည်းပညာထိန်းသိမ်းမှု',
-	'titre_admin_vider' => 'နည်းပညာထိန်းသိမ်းမှု',
 	'titre_cadre_afficher_article' => 'ဆောင်းပါးများကို ပြပါ',
 	'titre_cadre_afficher_traductions' => 'ဝက်ဘ်ဆိုက်အတွက် ဘာသာပြန်ထားသော အောက်ပါဘာသာစကားများကို ဖော်ပြပါ',
 	'titre_cadre_ajouter_auteur' => 'စာရေးသူတဦး​ပေါင်းထည့်ပါ',
@@ -572,5 +566,5 @@ proxy လိပ်စာကို အောက်တွင်​ဖော်ပ
 	'utf8_convert_erreur_orig' => 'အမှား- အက္ခရာထားရှိမှု @charset@ ကို သုံး၍မရပါ',
 
 	// V
-	'version' => 'မူကွဲ'
-);
+	'version' => 'မူကွဲ',
+];
