@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dist?lang_cible=ja
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// D
 	'dist_description' => 'SPIP 3で配布されたテンプレートセットです。',
-	'dist_slogan' => 'SPIP 3用のデフォルトテンプレートです。'
-);
+	'dist_slogan' => 'SPIP 3用のデフォルトテンプレートです。',
+];
