@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dist?lang_cible=oc_ni_mis
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// D
 	'dist_description' => 'Juec d’esquèletrou distribuit embé SPIP 3.',
-	'dist_slogan' => 'Esquèletrou predefinit de SPIP 3'
-);
+	'dist_slogan' => 'Esquèletrou predefinit de SPIP 3',
+];
