@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=oc_ni
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'accueil_site' => 'Acuèlh',
@@ -117,5 +113,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	// V
 	'ver_imprimer' => 'Version d’estampar',
 	'voir_en_ligne' => 'Vejatz en linha',
-	'voir_squelette' => 'veire l’esqueleta d’aquela pàgina'
-);
+	'voir_squelette' => 'veire l’esqueleta d’aquela pàgina',
+];
