@@ -16,6 +16,7 @@
  * onClose: 		(Function:null) The callback function used in place of SimpleModal's close
  * className: 		(String:null) Classes ajoutées au conteneur général
  * sideBar: 		(String:null) Active le mode sidebar : start | end | top | bottom
+ * ajaxReloadOnClose: 	(string|null) Blocs ajax à recharger à la fermeture, identifiants ou sélecteurs CSS séparés par des virgules.
  *
  */
 
@@ -47,7 +48,8 @@
 			"max-height":"maxHeight",
 			"caption-state":"defaultCaptionState",
 			"sidebar":"sideBar",
-			"class":"className"
+			"class":"className",
+			"ajaxreload-on-close":"ajaxReloadOnClose",
 		};
 		var v;
 		for (var o in data2options) {
