@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mediabox?lang_cible=eo
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// M
 	'mediabox_description' => 'Defaŭlte, ĉiujn ligilojn al bildoj (kun atributo „type“, kiu difinas la bildan MIME-tipon) kaj la ligilojn kun la klaso <code>.mediabox</code> pliriĉigas la plurmedia skatolo.
@@ -24,5 +20,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	
 	Tiu kromprogramo funkcias ĉe la skeletoj, kiuj uzas la markon <code>#INSERT_HEAD</code>.',
 	'mediabox_nom' => 'MediaBox',
-	'mediabox_slogan' => 'Plurmedia skatolo'
-);
+	'mediabox_slogan' => 'Plurmedia skatolo',
+];
