@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mediabox?lang_cible=fa
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// M
 	'mediabox_nom' => 'مدياباكس',
-	'mediabox_slogan' => 'صندوق چندرسانه‌اي'
-);
+	'mediabox_slogan' => 'صندوق چندرسانه‌اي',
+];
