@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mediabox?lang_cible=fr_tu
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// M
 	'mediabox_description' => 'Par défaut, tous les liens vers des images (avec un attribut type décrivant le mime/type de l’image) ainsi que les liens avec la classe <code>.mediabox</code> sont enrichis par la boîte multimédia.
@@ -24,5 +20,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	
 	Ce plugin fonctionne sur les squelettes disposant de la balise <code>#INSERT_HEAD</code>',
 	'mediabox_nom' => 'MediaBox',
-	'mediabox_slogan' => 'Boîte multimédia'
-);
+	'mediabox_slogan' => 'Boîte multimédia',
+];
