@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mediabox?lang_cible=it
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// M
 	'mediabox_description' => 'Per impostazione predefinita, tutti i collegamenti alle immagini (con un attributo che descrive il tipo mime/tipo di foto) e
@@ -22,5 +18,5 @@ Un pannello di configurazione permette di modificare le impostazioni generali a
 
 Questo plugin funziona su scheletri che hanno la <code> INSERT_HEAD # </ code> tag.',
 	'mediabox_nom' => 'MediaBox',
-	'mediabox_slogan' => 'Media box'
-);
+	'mediabox_slogan' => 'Media box',
+];
