@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mediabox?lang_cible=lb
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// M
 	'mediabox_description' => 'Par défaut hunn all Linken op Biller (mat Attribut mime/type) a Linke mat der Klass <code>.mediabox</code> Zougrëff op d’Mediabox.
@@ -20,5 +16,5 @@ All Link ka mat zousätzleche Klassen agestallt ginn:
 D’Astellung erlaabt de generelle Layout festzeleen, op Basis vun e puer Virlagen.
 Dëse Plugin fonktionnéiert mat Skeletter déi den Tag <code>#INSERT_HEAD</code> hun.',
 	'mediabox_nom' => 'MediaBox',
-	'mediabox_slogan' => 'Mediabox'
-);
+	'mediabox_slogan' => 'Mediabox',
+];
