@@ -448,6 +448,29 @@
 					var content = cfg.handlers[cfg.handler](target, instance);
 				}
 			}
+		},
+		// Rechargement ajax d'une liste d'éléments séparés par des virgules
+		ajaxReloadElements: function(elements) {
+			const targets = elements
+				.split(',')
+				.map(s => s.trim())
+				.filter(Boolean);
+			targets.forEach(function(target) {
+				try {
+					// Soit c'est un sélecteur CSS (autre qu'une balise) : .truc #truc [truc]
+					if (/^[.#[]/.test(target)) {
+						const $element = $(target);
+						if ($element.length) {
+							$element.ajaxReload();
+						}
+					// Soit c'est un identifiant ajax
+					} else {
+						ajaxReload(target);
+					}
+				} catch (e) {
+					console.warn("Mediabox ajaxReloadElements : erreur lors du traitement de '" + target + "'.", e);
+				}
+			});
 		}
 	}
 
@@ -609,6 +632,12 @@
 				if (callback) {
 					callback(event, instance);
 				}
+				// Option ajaxReloadonClose
+				let options = instance.options();
+				let ajaxReloadArgs = options.ajaxReloadOnClose;
+				if (ajaxReloadArgs && typeof(ajaxReloadArgs) === 'string') {
+					litySpip.ajaxReloadElements(ajaxReloadArgs);
+				}
 			}
 		});
 		$(document).on('lity:remove', function(event, instance) {
