@@ -233,9 +233,9 @@ function mediabox_insert_head_css($flux) {
 				$js_config['splash_days'] = $config['splash_days'];
 			}
 		}
-		$configmediabox = '<script type="text/javascript">/* <![CDATA[ */
+		$configmediabox = '<script>
 var mediabox_settings=' . json_encode(mediabox_echappe_js_config($js_config), JSON_INVALID_UTF8_IGNORE) . ';' . "\n";
-		$flux = $configmediabox . '/* ]]> */</script>' . "\n" . $flux;
+		$flux = $configmediabox . '</script>' . "\n" . $flux;
 	}
 
 	return $flux;
