@@ -98,7 +98,7 @@ function action_ajouter_un_document_dist($id_document, $file, $objet, $id_objet,
 	// Sécurité : si jamais il existe deja une entrée dans la BDD avec ce chemin de document, remettre le document dans tmp, ce qui permettra ensuite qu'il soit dupliqué, et qu'il n'y ait pas deux entrées en base avec la même ligne 'fichier'.
 	// Cela n'arrive que si $file indique un document qui se trouve déjà dans IMG.
 	while (sql_getfetsel('fichier', 'spip_documents', 'fichier='.sql_quote(set_spip_doc($file['tmp_name'])))) {
-		$tmp = tempnam(_DIR_TRANSFERT, $file['tmp_name']);
+		$tmp = tempnam(is_dir(_DIR_TRANSFERT) ? _DIR_TRANSFERT : _DIR_TMP, $file['tmp_name']);
 		if (deplacer_fichier_upload($file['tmp_name'], $tmp)) {
 			$file['tmp_name'] = $tmp;
 		} else {
