@@ -31,8 +31,8 @@ function medias_declarer_tables_interfaces($interfaces) {
 
 	$interfaces['exceptions_des_tables']['documents']['type_document'] = ['types_documents', 'titre'];
 	$interfaces['exceptions_des_tables']['documents']['extension_document'] = ['types_documents', 'extension'];
-	$interfaces['exceptions_des_tables']['documents']['mime_type'] = ['types_documents', 'mime_type'];
-	$interfaces['exceptions_des_tables']['documents']['media_document'] = ['types_documents', 'media'];
+	$interfaces['exceptions_des_tables']['documents']['mime_type_extension'] = ['types_documents', 'mime_type'];
+	$interfaces['exceptions_des_tables']['documents']['media_document'] = ['types_documents', 'media_defaut'];
 
 	$interfaces['exceptions_des_jointures']['spip_documents']['id_forum'] = ['spip_documents_liens', 'id_forum'];
 	$interfaces['exceptions_des_jointures']['spip_documents']['vu'] = ['spip_documents_liens', 'vu'];
@@ -268,7 +268,7 @@ function creer_base_types_doc($serveur = '', $champ_media = 'media_defaut') {
 			}
 		}
 
-		// type de media
+		// type de media (par defaut)
 		$media = 'file';
 		if (preg_match(',^image/,', $type_mime) or in_array($type_mime, ['application/illustrator'])) {
 			$media = 'image';
