@@ -127,13 +127,14 @@ function vignette_automatique($img, $doc, $lien, $x = 0, $y = 0, $align = '', $c
 			$f = charger_fonction('vignette', 'inc');
 			$img = $f($e, $doc['media'] ?? '');
 			$size = @spip_getimagesize($img);
-			$img = "<img src='$img' " . $size[3] . ' />';
+			$img = "<img src='".attribut_url(timestamp($img))."' " . $size[3] . ' />';
 			$class .= ' spip_document_icone';
 		}
 	} else {
 		$size = @spip_getimagesize($img);
-		$img = "<img src='$img' " . $size[3] . ' />';
+		$img = "<img src='".attribut_url(timestamp($img))."' " . $size[3] . ' />';
 	}
+
 	// on appelle image_reduire independamment de la presence ou non
 	// des librairies graphiques
 	// la fonction sait se debrouiller et faire de son mieux dans tous les cas
@@ -159,7 +160,7 @@ function vignette_automatique($img, $doc, $lien, $x = 0, $y = 0, $align = '', $c
 	$mime = $type['mime_type'];
 	$titre = attribut_html(couper($type['titre'] . $titre, 80));
 
-	return "<a href='$lien' type='$mime' title='$titre'>$img</a>";
+	return "<a href='".attribut_url($lien)."' type='$mime' title='$titre'>$img</a>";
 }
 
 /**
