@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=ca
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'aucun_audio' => 'No hi ha banda sonora', # MODIF
@@ -50,7 +46,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'des_images' => '@nb@ imatges',
 	'des_utilisations' => '@nb@ usos',
 	'des_videos' => '@nb@ seqüències',
-	'descriptif' => 'Descripció',
+	'descriptif' => 'Descripció', # MODIF
 	'document_attache_succes' => 'El document s’ha afegit correctament',
 	'document_copie_locale_succes' => 'El fitxer s’ha copiat al lloc correctament',
 	'document_installe_succes' => 'El fitxer s’ha carregat correctament',
@@ -108,5 +104,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'upload_zip_conserver' => 'Conservar l’arxiu desprès de l’extracció', # MODIF
 	'upload_zip_decompacter' => 'descomprimit i cada element que conté instal·lat en el lloc Web. Els fitxers que llavors seran instal·lat en el lloc Web són:',
 	'upload_zip_telquel' => 'instal·lat tal qual, com a arxiu comprimit Zip;',
-	'upload_zip_titrer' => 'Titular segons el nom dels fitxers'
-);
+	'upload_zip_titrer' => 'Titular segons el nom dels fitxers',
+];
