@@ -1,11 +1,8 @@
 <?php
 // This is a SPIP language file  --  Ceci est un fichier langue de SPIP
 // Fichier source, a modifier dans https://git.spip.net/spip/medias.git
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
 
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'affichage_documents_en_cases' => 'Affichage en cases',
@@ -211,5 +208,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	// V
 	'verifier_documents_brises' => 'Vérifier les fichiers manquants',
 	'verifier_documents_inutilises' => 'Vérifier les liens des documents',
-	'vignette_supprimee' => 'La vignette a été supprimée'
-);
+	'vignette_supprimee' => 'La vignette a été supprimée',
+];
