@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=is
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// B
 	'bouton_ajouter_document' => 'BÆTA SKJALI VIÐ', # MODIF
@@ -22,5 +18,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'image_tourner_droite' => 'Snúa um 90° til hægri',
 	'image_tourner_gauche' => 'Snúa um 90° til vinstri',
 	'info_document' => 'Skjal',
-	'info_documents' => 'Skjöl'
-);
+	'info_documents' => 'Skjöl',
+];
