@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=ru
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'aucun_audio' => 'Аудио файлов нет',
@@ -50,7 +46,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'des_images' => '@nb@ файлов изображений',
 	'des_utilisations' => 'Используется @nb@ раз(а)',
 	'des_videos' => '@nb@ видео файлов',
-	'descriptif' => 'Описание',
+	'descriptif' => 'Описание', # MODIF
 	'document_attache_succes' => 'Документ (файл) добавлен успешно',
 	'document_copie_locale_succes' => 'Файл успешно скопирован на сайт',
 	'document_installe_succes' => 'Файл добавлен успешно',
@@ -191,5 +187,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	// V
 	'verifier_documents_brises' => 'Проверить недостающие файлы',
 	'verifier_documents_inutilises' => 'Проверить использование документа',
-	'vignette_supprimee' => 'Миниатюра удалена'
-);
+	'vignette_supprimee' => 'Миниатюра удалена',
+];
