@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-medias?lang_cible=br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// M
 	'medias_description' => 'Merañ ar mediaoù SPIP',
-	'medias_slogan' => 'Merañ ar mediaoù e SPIP'
-);
+	'medias_slogan' => 'Merañ ar mediaoù e SPIP',
+];
