@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-medias?lang_cible=oc_ni_mis
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// M
 	'medias_description' => 'Gestioun dei media de SPIP',
-	'medias_slogan' => 'Gestioun dei media en SPIP'
-);
+	'medias_slogan' => 'Gestioun dei media en SPIP',
+];
