@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-medias?lang_cible=sk
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// M
 	'medias_description' => 'Správa multimédií v SPIPe',
-	'medias_slogan' => 'Správa multimédií v SPIPe'
-);
+	'medias_slogan' => 'Správa multimédií v SPIPe',
+];
