@@ -20,6 +20,8 @@
 			'mejs.time-slider': 'Слайдер времени',
 			'mejs.time-help-text': 'Используйте Левую/Правую клавиши со стрелками, чтобы продвинуться на одну секунду, клавиши со стрелками Вверх/Вниз, чтобы продвинуться на десять секунд.',
 			'mejs.live-broadcast' : 'Прямая трансляция',			
+			'mejs.current': 'Текущее время',
+			'mejs.duration': 'Общее время',			
 			'mejs.volume-help-text': 'Используйте клавиши со стрелками Вверх/Вниз, чтобы увеличить или уменьшить громкость.',
 			'mejs.unmute': 'Включить звук',
 			'mejs.mute': 'Отключить звук',
