@@ -263,6 +263,92 @@ function critere_DOCUMENTS_carre_dist($idb, &$boucles, $crit) {
 }
 
 
+/**
+ * Balise `#MIME_TYPE`
+ *
+ * Calculer la balise mime_type qui peut avoir un contenu variable pour une meme extension
+ * cf mp4 notamment
+ *
+ * @param Spip\Compilateur\Noeud\Champ $p
+ * @return Spip\Compilateur\Noeud\Champ
+ */
+function balise_MIME_TYPE_dist($p) {
+
+	$_mime_type = champ_sql('mime_type', $p, '($Pile[0][\'mime_type\'] ?? \'\')');
+
+	// Dans la table spip_types_documents, on renvoie le champ SQL tel quel
+	if ($p->type_requete === 'types_documents') {
+		$p->code = $_mime_type;
+		return $p;
+	}
+
+	$_id_document = champ_sql('id_document', $p);
+	$_extension = champ_sql('extension', $p, '($Pile[0][\'extension\'] ?? \'\')');
+
+	// Dans la table spip_documents, on renvoie le mime_type calculé
+	if ($p->type_requete === 'documents') {
+		$p->code = sprintf('medias_mime_type_document(%s, %s)',  $_id_document, $_extension);
+		return $p;
+	}
+
+	// En dehors de cas standards, on cherche un id_document (+ extension) pour calculer le mime type,
+	// et sinon, on récupèrere un mime_type en remontant la pile jusqu’au env.
+	$p->code = sprintf('(%s === null ? %s : medias_mime_type_document(%s, %s))', $_id_document, $_mime_type, $_id_document, $_extension);
+
+	return $p;
+}
+
+function medias_mime_type_document(int $id_document, string $extension = ''): string {
+	if (!$id_document) {
+		return '';
+	}
+	if (empty($extension)) {
+		$extension = sql_getfetsel(
+			'extension',
+			'spip_documents',
+			'id_document = ' . intval($id_document)
+		);
+	}
+	$mime_type = sql_getfetsel(
+		'mime_type',
+		'spip_types_documents',
+		'extension = ' . sql_quote($extension)
+	);
+	// document introuvable ?
+	if ($mime_type === null) {
+		return '';
+	}
+	$mime_type_sanitized = preg_replace('/\W/', '_', $mime_type);
+	if ($calculer_mime_type = charger_fonction('calculer_mime_type_' . $mime_type_sanitized, 'inc', true)) {
+		$mime_type_document = $calculer_mime_type($id_document, $extension, $mime_type);
+		// la fonction peut renvoyer null pour laisser le mime_type initial intact
+		if ($mime_type_document) {
+			$mime_type = $mime_type_document;
+		}
+	}
+
+	return $mime_type;
+}
+
+function filtre_titre_mime_type_dist(int $id_document, string $extension): string {
+	static $types = null;
+	if (is_null($types)) {
+		$types = sql_allfetsel('extension,titre,mime_type', 'spip_types_documents');
+		$types = array_combine(array_column($types, 'extension'), $types);
+	}
+	if (!empty($types[$extension])) {
+		$titre = $types[$extension]['titre'];
+		$mime_type = medias_mime_type_document($id_document, $extension);
+		if ($mime_type !== $types[$extension]['mime_type'] && str_starts_with($types[$extension]['mime_type'], 'application/')) {
+			$mime_type = explode('/', $mime_type);
+			$titre .= " " . ucfirst(reset($mime_type));
+		}
+	}
+
+	return $titre ?? '';
+}
+
+
 /**
  * Calcule la vignette d'une extension (l'image du type de fichier)
  *
@@ -571,3 +657,27 @@ function medias_str_repeat_log($num, $base = 2, $string = 'x', $remove = 0) {
 	$pad = str_repeat($string, (int)log($num, $base));
 	return substr($pad, $remove);
 }
+
+/*
+ * Compile la balise #URL_DOCUMENT_FICHIER, mais en cherchant bien un id_document dans la boucle (et non pas un id_document_fichier)
+ */
+function balise_URL_DOCUMENT_FICHIER_dist($p) {
+	include_spip('balise/url_');
+
+	$_id = interprete_argument_balise(1, $p);
+
+	if (!$_id) {
+		$_id = champ_sql('id_document', $p);
+	}
+
+	$nom = $p->nom_champ;
+	$code = generer_generer_url_arg('document_fichier', $p, $_id);
+	$code = champ_sql($nom, $p, $code);
+	$p->code = $code;
+	if (!$p->etoile) {
+		$p->code = "vider_url($code)";
+	}
+	$p->interdire_scripts = false;
+
+	return $p;
+}
