@@ -25,7 +25,6 @@ if (!defined('_ECRIRE_INC_VERSION')) {
  *    Le tableau comprenant les différentes metas à mettre en base
  */
 function metadata_video($file) {
-	$id3 = [];
 	$meta = [];
 
 	include_spip('lib/getid3/getid3');
@@ -36,10 +35,11 @@ function metadata_video($file) {
 	$file_info = $getID3->analyze($file);
 
 	/**
-	 * Les pistes vidéos
+	 * Si il y a du contenu video
 	 */
-	if (isset($file_info['video'])) {
-		$id3['hasvideo'] = 'oui';
+	if (!empty($file_info['video'])) {
+		// marquer le media comme video si on est appelé par metadata/mp4 ou autre
+		$meta['media'] = 'video';
 		if (isset($file_info['video']['resolution_x'])) {
 			$meta['largeur'] = $file_info['video']['resolution_x'];
 		}
