@@ -7,7 +7,6 @@
  *  Arnaud Martin, Antoine Pitrou, Philippe Rivière, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribué sous licence GNU/GPL.     *
- *  Pour plus de détails voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
 /**
@@ -138,12 +137,11 @@ function formulaires_editer_mot_identifier_dist(
  * return array
  *     Configuration pour le formulaire
  */
-function mots_edit_config($row) {
-	global $spip_ecran, $spip_lang;
+function mots_edit_config(array $row): array {
 
-	$config = $GLOBALS['meta'];
-	$config['lignes'] = ($spip_ecran == 'large') ? 8 : 5;
-	$config['langue'] = $spip_lang;
+	$config = [];
+	$config['lignes'] = 8;
+	$config['langue'] = $GLOBALS['spip_lang'];
 	$config['restreint'] = false;
 
 	return $config;
@@ -255,7 +253,7 @@ function formulaires_editer_mot_traiter_dist(
 		$id_mot = $res['id_mot'];
 
 		if (!strncmp($retour, 'javascript:', 11) == 0) {
-			if (!strlen(parametre_url($retour, 'id_mot'))) {
+			if (!strlen(parametre_url($retour, 'id_mot') ?? '')) {
 				$res['redirect'] = parametre_url($res['redirect'], 'id_mot', '');
 			}
 		}
