@@ -1,11 +1,8 @@
 <?php
 // This is a SPIP language file  --  Ceci est un fichier langue de SPIP
 // Fichier source, a modifier dans https://git.spip.net/spip/mots.git
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
 
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// B
 	'bouton_associer' => 'Associer',
@@ -44,5 +41,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'result_fusionner_ok' => 'Vous pouvez maintenant supprimer ce mot : tous les liens ont été transférés sur l’autre @mot@.',
 
 	// T
-	'titre_formulaire_administrer_mot' => 'Administrer le mot'
-);
+	'titre_formulaire_administrer_mot' => 'Administrer le mot',
+];
