@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=is
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// I
 	'icone_mots_cles' => 'Lykilorð',
@@ -17,5 +13,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_titre_mot_cle' => 'Nafn eða titill lykilorðs',
 
 	// L
-	'logo_mot_cle' => 'TÁKN LYKILORÐSINS'
-);
+	'logo_mot_cle' => 'TÁKN LYKILORÐSINS',
+];
