@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mots?lang_cible=br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// M
 	'mots_description' => 'Gerioù ha strolladoù ger',
-	'mots_slogan' => 'Merañ gerioù hag strolladoù ger e  SPIP'
-);
+	'mots_slogan' => 'Merañ gerioù hag strolladoù ger e  SPIP',
+];
