@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mots?lang_cible=de
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// M
 	'mots_description' => 'Schlagworte und Schlagwortgruppen',
-	'mots_slogan' => 'Verwaltung von Schlagworten und Schlagwortgruppen mit  SPIP'
-);
+	'mots_slogan' => 'Verwaltung von Schlagworten und Schlagwortgruppen mit  SPIP',
+];
