@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mots?lang_cible=eo
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// M
 	'mots_description' => 'Ŝlosilvortoj kaj grupoj de ŝlosilvortoj',
-	'mots_slogan' => 'Mastrumado de ŝlosilvortoj kaj grupoj de ŝlosilvortoj en SPIP'
-);
+	'mots_slogan' => 'Mastrumado de ŝlosilvortoj kaj grupoj de ŝlosilvortoj en SPIP',
+];
