@@ -1,13 +1,10 @@
 <?php
 // This is a SPIP language file  --  Ceci est un fichier langue de SPIP
 // Fichier source, a modifier dans https://git.spip.net/spip/mots.git
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
 
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// M
 	'mots_description' => 'Mots et Groupes de mots',
-	'mots_slogan' => 'Gestion des mots et groupes de mots dans SPIP'
-);
+	'mots_slogan' => 'Gestion des mots et groupes de mots dans SPIP',
+];
