@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mots?lang_cible=it
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// M
 	'mots_description' => 'Parole e Gruppi di parole',
-	'mots_slogan' => 'Gestione delle parole e dei gruppi di parole di SPIP'
-);
+	'mots_slogan' => 'Gestione delle parole e dei gruppi di parole di SPIP',
+];
