@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mots?lang_cible=lb
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// M
 	'mots_description' => 'Schlësselwierder a Gruppen',
-	'mots_slogan' => 'Gestioun vun de Schlësselwierder a Gruppen am SPIP'
-);
+	'mots_slogan' => 'Gestioun vun de Schlësselwierder a Gruppen am SPIP',
+];
