@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mots?lang_cible=oc_ni_mis
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// M
 	'mots_description' => 'Mot e Group de mot',
-	'mots_slogan' => 'Gestioun dei mot e group de mot en SPIP'
-);
+	'mots_slogan' => 'Gestioun dei mot e group de mot en SPIP',
+];
