@@ -3,14 +3,10 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-plan?lang_cible=ja
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// P
 	'plan_description' => 'このプラグインは、折りたたみ可能な構造を表示し、記事のステータスでソートすることによって、管理エリアのページ「サイトマップ」を改善します。',
 	'plan_nom' => '管理エリアのサイトマップ',
-	'plan_slogan' => '管理エリアのサイトマップを改善する。'
-);
+	'plan_slogan' => '管理エリアのサイトマップを改善する。',
+];
