@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/plan?lang_cible=fr_tu
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// C
 	'confirmer_deplacement' => 'Es-tus sûr de vouloir déplacer ces éléments ?',
@@ -33,5 +29,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'suggerer_deplier' => 'Cela peut provenir du déplacement d’un grand groupe : dans ce cas la liste de ses enfants n’est pas chargée. Tu dois déplier le bloc (il se chargera), le replier, puis le redéplacer.',
 
 	// T
-	'tous_les_statuts' => 'Tous les statuts'
-);
+	'tous_les_statuts' => 'Tous les statuts',
+];
