@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/plan?lang_cible=it
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// C
 	'confirmer_deplacement' => 'Sei sicuro di voler spostare questi elementi?',
@@ -33,5 +29,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'suggerer_deplier' => 'Questo potrebbe essere causato dallo spostamento di un gruppo di oggetti numeroso: in questo caso l’elenco dei suoi "figli" non viene caricato. È necessario aprire il blocco (si caricherà), richiuderlo e quindi riposizionarlo.',
 
 	// T
-	'tous_les_statuts' => 'Tutti gli stati'
-);
+	'tous_les_statuts' => 'Tutti gli stati',
+];
