@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/plan?lang_cible=pt_br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// C
 	'confirmer_deplacement' => 'Você quer realmente deslocar estes elementos?',
@@ -33,5 +29,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'suggerer_deplier' => 'Isso poder ocorrer devido à deslocação de um grande grupo: neste caso a lista dos seus subordinados não é carregada. Você deve expandir o bloco (ele se carregará), retraí-lo de novo e, então, deslocá-lo.',
 
 	// T
-	'tous_les_statuts' => 'Todos os statuts'
-);
+	'tous_les_statuts' => 'Todos os statuts',
+];
