@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// B
 	'barre_a_accent_grave' => 'Enlakaat un À',
@@ -106,5 +102,5 @@ Neuze, forzh penaos vefe renket ar forom, pe kreionoù ha pluginoù, benveg Quil
 	'label_barre_outils_public_oui' => 'Kargañ skriptoù ar barennoù benveg e-barzh al lec’hienn foran.',
 
 	// V
-	'voir' => 'Gwelet en araok'
-);
+	'voir' => 'Gwelet en araok',
+];
