@@ -1,11 +1,8 @@
 <?php
 // This is a SPIP language file  --  Ceci est un fichier langue de SPIP
 // Fichier source, a modifier dans https://git.spip.net/spip/porte_plume.git
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
 
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// B
 	'barre_a_accent_grave' => 'Insérer un À',
@@ -106,5 +103,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'label_barre_outils_public_oui' => 'Charger les scripts de barre d’outils sur l’espace public',
 
 	// V
-	'voir' => 'Voir'
-);
+	'voir' => 'Voir',
+];
