@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=fr_fem
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// B
 	'barre_a_accent_grave' => 'Insérer un À',
@@ -108,5 +104,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'label_barre_outils_public_oui' => 'Charger les scripts de barre d’outils sur l’espace public',
 
 	// V
-	'voir' => 'Voir'
-);
+	'voir' => 'Voir',
+];
