@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=it
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// B
 	'barre_a_accent_grave' => 'Inserisci una A con accento grave maiuscolo',
@@ -105,5 +101,5 @@ In questo caso, qualunque sia la configurazione dei forum, pennarelli o plugin,
 	'label_barre_outils_public_oui' => 'Caricare gli script della barra di testo sullo spazio pubblico',
 
 	// V
-	'voir' => 'Vedi'
-);
+	'voir' => 'Vedi',
+];
