@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=pt
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// B
 	'barre_a_accent_grave' => 'Inserir À',
@@ -101,5 +97,5 @@ Assim, em qualquer configuração dos fóruns, crayons ou plugins, nenhuma barra
 	'label_barre_outils_public_oui' => 'Carregar os scripts de barras de ferramentas no sítio público.',
 
 	// V
-	'voir' => 'Visualizar'
-);
+	'voir' => 'Visualizar',
+];
