@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=sk
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// B
 	'barre_a_accent_grave' => 'Vložiť À',
@@ -105,5 +101,5 @@ Preto bez ohľadu na nastavenia diskusných fóra, crayonov alebo zásuvných m
 	'label_barre_outils_public_oui' => 'Na verejne prístupnej stránke spúšťať skripty nástrojov',
 
 	// V
-	'voir' => 'Ukážka'
-);
+	'voir' => 'Ukážka',
+];
