@@ -3,14 +3,10 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-porte_plume?lang_cible=de
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// P
 	'porte_plume_description' => 'Der Federhalter ist eine erweiterbare Werkzeugleiste für SPIP auf Grundlage der Javascript-Bibiliothek [MarkItUp->http://markitup.jaysalvat.com/home/]',
 	'porte_plume_nom' => 'Federhalter',
-	'porte_plume_slogan' => 'Eine Menüleiste zum Formatieren der Texte'
-);
+	'porte_plume_slogan' => 'Eine Menüleiste zum Formatieren der Texte',
+];
