@@ -3,14 +3,10 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-porte_plume?lang_cible=es
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// P
 	'porte_plume_description' => 'Porta pluma es una barra de herramientas extensible para SPIP que utiliza la librería javascript [MarkItUp->http://markitup.jaysalvat.com/home/]',
 	'porte_plume_nom' => 'Porta pluma',
-	'porte_plume_slogan' => 'Una barra de herramientas para escribir bien'
-);
+	'porte_plume_slogan' => 'Una barra de herramientas para escribir bien',
+];
