@@ -1,14 +1,11 @@
 <?php
 // This is a SPIP language file  --  Ceci est un fichier langue de SPIP
 // Fichier source, a modifier dans https://git.spip.net/spip/porte_plume.git
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
 
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// P
 	'porte_plume_description' => 'Porte plume est une barre d’outils extensible pour SPIP qui utilise la bibliothèque javascript [MarkItUp->http://markitup.jaysalvat.com/home/]',
 	'porte_plume_nom' => 'Porte plume',
-	'porte_plume_slogan' => 'Une barre d’outils pour bien écrire'
-);
+	'porte_plume_slogan' => 'Une barre d’outils pour bien écrire',
+];
