@@ -1235,7 +1235,7 @@ function balise_GRAND_TOTAL_dist($p) {
  * tel que `var_mode`.
  *
  * @note
- *     Attention dans un `INCLURE()` ou une balise dynamique, on n'a pas le droit de
+ *     Attention dans un `INCLURE` ou une balise dynamique, on n'a pas le droit de
  *     mettre en cache `#SELF` car il peut correspondre à une autre page (attaque XSS)
  *     (Dans ce cas faire <INCLURE{self=#SELF}> pour différencier les caches.)
  *
@@ -2035,6 +2035,49 @@ function balise_INCLURE_dist($p) {
 }
 
 
+/**
+ * Compile la balise `#TRAD` qui traduit une clé de langue
+ *
+ * Signature:
+ * `#TRAD{module:cle, #ARRAY{arg,val,...}}` ou `#TRAD{module:cle, #ARRAY{arg,val,...}, #ARRAY{sanitize,0}}`
+ *
+ * @balise
+ *
+ * @example
+ *     ```
+ *     #TRAD{voir_en_ligne}
+ *     [(#TRAD{forum:message, #ARRAY{lang,en}})]
+ *     ```
+ * @uses _T()
+ * @param Champ $p
+ * @return Champ
+ */
+function balise_TRAD_dist($p) {
+	$id_boucle = $p->id_boucle;
+
+	$args = '';
+	$_chaine = interprete_argument_balise(1, $p);
+	$_contexte = interprete_argument_balise(2, $p);
+	if (!empty($_contexte)) {
+		$args = ',' . $_contexte;
+		$_options = interprete_argument_balise(3, $p);
+		if (!empty($_options)) {
+			$args .= ',' . $_options;
+		}
+	}
+
+	if ($_chaine === null || $_chaine === "''") {
+		$msg = ['zbug_balise_sans_argument', ['balise' => ' TRAD']];
+		erreur_squelette($msg, $p);
+	}
+	else {
+		$p->code = "_T({$_chaine}{$args})";
+	}
+
+	$p->interdire_scripts = false; // la securite est assuree par _T
+	return $p;
+}
+
 /**
  * Compile la balise `#MODELE` qui inclut un résultat de squelette de modèle
  *
@@ -2831,13 +2874,20 @@ function balise_PRODUIRE_dist($p) {
 }
 
 /**
- * Compile la balise `#LARGEUR_ECRAN` qui définit la largeur d'écran
- * dans l'espace privé
+ * Compile la balise `#LAYOUT_PRIVE` relative à la disposition de l'espace privé.
+ *
+ * - Avec param : pour définir une nouvelle disposition.
+ * - Sans param : pour récupérer la classe correspondante à la disposition
+ *   courante sous la forme 'layout-<disposition>'
+ *
+ * Les dispositions possibles sont listées dans la CSS layout.css
+ * Cette balise n'a pas vocation à être utilisée en dehors du privé.
  *
  * @balise
  * @example
  *     ```
- *     #LARGEUR_ECRAN{pleine_largeur}
+ *     #LAYOUT_PRIVE{pleine-largeur} : définit une nouvelle valeur
+ *     #LAYOUT_PRIVE : retourne la valeur actuelle
  *     ```
  *
  * @param Champ $p
@@ -2845,17 +2895,32 @@ function balise_PRODUIRE_dist($p) {
  * @return Champ
  *     Pile complétée par le code à générer
  */
-function balise_LARGEUR_ECRAN_dist($p) {
-	$_class = interprete_argument_balise(1, $p);
-	if (!$_class) {
-		$_class = 'null';
-	}
-	$p->code = "(is_string($_class)?vide(\$GLOBALS['largeur_ecran']=$_class):(isset(\$GLOBALS['largeur_ecran'])?\$GLOBALS['largeur_ecran']:''))";
+function balise_LAYOUT_PRIVE_dist($p) {
+	$_identifiant = interprete_argument_balise(1, $p) ?? 'null';
+	$p->code = "calculer_balise_LAYOUT_PRIVE($_identifiant)";
 
 	return $p;
 }
 
 
+/**
+ * Compile la balise `#LARGEUR_ECRAN` qui définit ou renvoie la disposition
+ * dans l'espace privé
+ *
+ * @deprecated 4.4 Utiliser `#LAYOUT_PRIVE`
+ * @uses balise_LAYOUT_PRIVE_dist()
+ *
+ * @param Champ $p
+ *     Pile au niveau de la balise
+ * @return Champ
+ *     Pile complétée par le code à générer
+ */
+function balise_LARGEUR_ECRAN_dist($p) {
+	trigger_deprecation('spip', '4.4', 'Using "%s" tag is deprecated, use "%s" tag instead', '#LARGEUR_ECRAN', '#LAYOUT_PRIVE');
+	return balise_LAYOUT_PRIVE_dist($p);
+}
+
+
 /**
  * Compile la balise `#CONST` qui retourne la valeur de la constante passée en argument
  *
@@ -2879,3 +2944,20 @@ function balise_CONST_dist($p) {
 
 	return $p;
 }
+
+/**
+ * Affiche un paramètre public du container SPIP.
+ */
+function balise_PARAM_dist(Champ $p): Champ {
+	$param = interprete_argument_balise(1, $p);
+	if (!strlen($param ?? '')) {
+		$p->code = "''";
+	}
+	else {
+		$p->code = '\SpipLeague\Component\Kernel\param(' . $param . ')';
+	}
+
+	$p->interdire_scripts = false;
+
+	return $p;
+}
