@@ -83,6 +83,19 @@ function phraser_inclure($texte, $ligne, $result) {
 		$champ->ligne = $ligne;
 		$ligne += substr_count($match[0], "\n");
 		$fichier = $match[2];
+		if ($fichier) {
+			$lieu = '?';
+			foreach (debug_backtrace() as $trace) {
+				if (
+					str_starts_with($trace['function'] ?? '', 'public_phraser_html')
+					&& isset($trace['args'][3]['sourcefile'])
+				) {
+					$lieu = $trace['args'][3]['sourcefile'];
+					break;
+				}
+			}
+			trigger_deprecation('spip', '4.4', 'Using "%s" in "%s" is deprecated , use "%s" instead', '<INCLURE(' . $fichier . ')>', $lieu, '<INCLURE{fond=...}>');
+		}
 		# assurer ici la migration .php3 => .php
 		# et de l'ancienne syntaxe INCLURE(page.php3) devenue surperflue
 		if ($fichier and preg_match(',^(.*[.]php)3$,', $fichier, $r)) {
@@ -100,7 +113,21 @@ function phraser_inclure($texte, $ligne, $result) {
 			normaliser_inclure($champ);
 		}
 		$texte = substr($texte, strpos($texte, '>', $pos_apres) + 1);
-		$texte = preg_replace(',^</INCLU[DR]E>,', '', $texte);
+		$count = 0;
+		$texte = preg_replace(',^</INCLU[DR]E>,', '', $texte, -1, $count);
+		if ($count) {
+			$lieu = '?';
+			foreach (debug_backtrace() as $trace) {
+				if (
+					str_starts_with($trace['function'] ?? '', 'public_phraser_html')
+					&& isset($trace['args'][3]['sourcefile'])
+				) {
+					$lieu = $trace['args'][3]['sourcefile'];
+					break;
+				}
+			}
+			trigger_deprecation('spip', '4.4', 'Using "%s" in "%s" is deprecated , remove it.', '</INCLURE>', $lieu);
+		}
 		$result[] = $champ;
 	}
 
@@ -172,6 +199,10 @@ function phraser_idiomes($texte, $ligne, $result) {
 		$match = array_pad($match, 8, null);
 		$p = strpos($texte, (string) $match[0]);
 		$ko = (!$match[3] && ($match[5][0] !== '='));
+		$chaine = strtolower($match[3]);
+		if ($chaine != $match[3]) {
+			trigger_deprecation('spip', '4.4', sprintf('La chaine de langue « %s » a été basculée en minuscule. À partir de SPIP 5.0, les chaînes de langues seront sensibles à la casse.', $match[3]));
+		}
 		$debut = substr($texte, 0, $p + ($ko ? strlen($match[0]) : 0));
 		if ($debut) {
 			$result = phraser_champs($debut, $ligne, $result);
@@ -502,7 +533,7 @@ function phraser_champs_interieurs($texte, $ligne, $sep, $result) {
 			$champ->apres = phraser_champs_exterieurs($debut, $n, $sep, $result);
 
 			// reinjecter la boucle si c'en est une
-			phraser_boucle_placeholder($champ);
+			phraser_placeholder_reinjecter($champ);
 
 			$result[$i] = $champ;
 			$i++;
@@ -978,55 +1009,134 @@ function public_trouver_fin_boucle($texte, $id_parent, $boucle, $pos_debut_texte
 	return $boucle;
 }
 
+/**
+ * Définir un placeholder avec un hash unique pour substitution dans un texte donné
+ * on s'assure de n'avoir aucune occurence existante dans le texte
+ * @param string $texte
+ * @param string $placeholder_prefixe
+ * @return string
+ */
+function phraser_placeholder_hash(string &$texte, string $placeholder_prefixe) {
+	// definir un placholder pour les boucles dont on est sur d'avoir aucune occurence dans le squelette
+	do {
+		$placeholder = $placeholder_prefixe . strtoupper(substr(md5(uniqid()),0,8));
+	} while (str_contains($texte, $placeholder));
+	return $placeholder;
+}
+
 
 /**
+ * Mémorise un morceau de code du squelette en le remplaçant par un placeholder, ou reinjecte les morceaux de codes à la place des placeholders.
  * @param object|string $champ
- * @param null|string $boucle_placeholder
- * @param null|object $boucle
+ * @param ?string $nom_champ_placeholder
+ * @param ?object $boucle_ou_champ
+ * @internal
+ * @see phraser_placeholder_memoriser()
+ * @see phraser_placeholder_reinjecter()
  */
-function phraser_boucle_placeholder(&$champ, $boucle_placeholder = null, $boucle = null) {
-	static $boucles_connues = [];
+function phraser_placeholder_memoriser_ou_reinjecter(&$champ, ?string $nom_champ_placeholder = null, $boucle_ou_champ = null) {
+	static $placeholder_connus = [];
 	// si c'est un appel pour memoriser une boucle, memorisons la
-	if (is_string($champ) and !empty($boucle_placeholder) and !empty($boucle)) {
-		$boucles_connues[$boucle_placeholder][$champ] = &$boucle;
-	}
-	else {
-		if (!empty($champ->nom_champ) and !empty($boucles_connues[$champ->nom_champ])) {
-			$placeholder = $champ->nom_champ;
-			$id = reset($champ->param[0][1]);
-			$id = $id->texte;
-			if (!empty($boucles_connues[$placeholder][$id])) {
-				$champ = $boucles_connues[$placeholder][$id];
+	if (is_string($champ) && !empty($nom_champ_placeholder) && !empty($boucle_ou_champ)) {
+		$placeholder_connus[$nom_champ_placeholder][$champ] = &$boucle_ou_champ;
+	} else {
+		if (!empty($champ->nom_champ) && !empty($placeholder_connus[$champ->nom_champ])) {
+			$nom_champ_placeholder = $champ->nom_champ;
+			$id = '';
+			if (!empty($champ->param[0][1])) {
+				$id = reset($champ->param[0][1]);
+				$id = $id->texte;
+			}
+			if (!empty($placeholder_connus[$nom_champ_placeholder][$id])) {
+				$champ = $placeholder_connus[$nom_champ_placeholder][$id];
 			}
 		}
 	}
 }
 
+/**
+ * @deprecated 4.4
+ * @see phraser_placeholder_memoriser_ou_reinjecter()
+ */
+function phraser_boucle_placeholder(&$champ, $boucle_placeholder = null, $boucle = null) {
+	trigger_deprecation('spip', '4.4', 'Using "%s" is deprecated, use "%s" or "%s" instead', 'phraser_boucle_placeholder', 'phraser_placeholder_memoriser', 'phraser_placeholder_reinjecter');
+	phraser_placeholder_memoriser_ou_reinjecter($champ, $boucle_placeholder, $boucle);
+}
 
 /**
- * Generer une balise placeholder qui prend la place de la boucle pour continuer le parsing des balises
- * @param string $id_boucle
- * @param $boucle
- * @param string $boucle_placeholder
- * @param int $nb_lignes
+ * Memoriser un champ ou une boucle associé a son placeholder
+ * @param string $champ
+ * @param string $nom_champ_placeholder
+ * @param $boucle_ou_champ
+ * @uses phraser_placeholder_memoriser_ou_reinjecter()
+ */
+function phraser_placeholder_memoriser(string $champ, string $nom_champ_placeholder, $boucle_ou_champ) {
+	phraser_placeholder_memoriser_ou_reinjecter($champ, $nom_champ_placeholder, $boucle_ou_champ);
+}
+
+/**
+ * Reinejcter un champ ou une boucle associé a son placeholder
+ * @param &$champ
+ * @uses phraser_placeholder_memoriser_ou_reinjecter()
+ */
+function phraser_placeholder_reinjecter(&$champ) {
+	phraser_placeholder_memoriser_ou_reinjecter($champ);
+}
+
+
+
+/**
+ * Generer une balise placeholder qui prend la place d'une boucle ou d'un champ pour continuer le parsing des balises
+ * utilisé pour remplacer une boucle ou un idiome
+ * @param Boucle|Champ $boucle
  * @return string
  */
-function public_generer_boucle_placeholder($id_boucle, &$boucle, $boucle_placeholder, $nb_lignes) {
-	$placeholder = "[(#{$boucle_placeholder}{" . $id_boucle . '})' . str_pad('', $nb_lignes, "\n") . ']';
-	//memoriser la boucle a reinjecter
-	$id_boucle = "$id_boucle";
-	phraser_boucle_placeholder($id_boucle, $boucle_placeholder, $boucle);
+function public_placeholder_generer(string $nom_structure, &$boucle_ou_champ, string $placeholder_pattern, int $nb_lignes, bool $force_balise_etendue = false): string {
+	if ($nb_lignes || $force_balise_etendue) {
+		$nom_champ = $placeholder_pattern;
+		$placeholder = "[(#{$nom_champ}{" . $nom_structure . '})' . str_pad('', $nb_lignes, "\n") . ']';
+		phraser_placeholder_memoriser($nom_structure, $nom_champ, $boucle_ou_champ);
+	} else {
+		$placeholder_suite = "_" . strtoupper(md5($nom_structure));
+		$nom_champ = "{$placeholder_pattern}{$placeholder_suite}";
+		$placeholder = "#{$nom_champ}";
+		$nom_structure = '';
+		//memoriser e champ a reinjecter
+		phraser_placeholder_memoriser($nom_structure, $nom_champ, $boucle_ou_champ);
+	}
 	return $placeholder;
 }
 
-function public_phraser_html_dist($texte, $id_parent, &$boucles, $descr, $ligne_debut_texte = 1, $boucle_placeholder = null) {
+/**
+ * Generer une balise placeholder qui prend la place de la boucle pour continuer le parsing des balises
+ * @deprecated 4.4
+ * @uses public_placeholder_generer()
+ */
+function public_generer_boucle_placeholder($id_boucle, &$boucle, $boucle_placeholder, $nb_lignes) {
+	trigger_deprecation('spip', '4.4', 'Using "%s" is deprecated, use "%s" instead', 'public_generer_boucle_placeholder', 'public_placeholder_generer');
+	return public_placeholder_generer($id_boucle, $boucle, $boucle_placeholder, $nb_lignes);
+}
+
+/**
+ * Analyseur syntaxique des squelettes HTML SPIP
+ * On commence par analyser les boucles, les mémoriser, et les remplacer dans le texte par des placeholder
+ * qui ne genent pas la suite de l'analyse des balises et autres
+ *
+ * @param array<string,Boucle> $boucles
+ */
+function public_phraser_html_dist(
+	string $texte,
+	string $id_parent,
+	array &$boucles,
+	array $descr,
+	int $ligne_debut_texte = 1,
+	?string $boucle_placeholder = null
+): array {
 
 	$all_res = [];
 	// definir un placholder pour les boucles dont on est sur d'avoir aucune occurence dans le squelette
-	if (is_null($boucle_placeholder)) {
-		do {
-			$boucle_placeholder = 'BOUCLE_PLACEHOLDER_' . strtoupper(md5(uniqid()));
-		} while (strpos($texte, $boucle_placeholder) !== false);
+	if ($boucle_placeholder === null) {
+		$boucle_placeholder = phraser_placeholder_hash($texte, 'PLACEHOLDER_BOUCLE_');
 	}
 
 	$ligne_debut_initial = $ligne_debut_texte;
@@ -1267,7 +1377,7 @@ function public_phraser_html_dist($texte, $id_parent, &$boucles, $descr, $ligne_
 		}
 
 		// remplacer la boucle par un placeholder qui compte le meme nombre de lignes
-		$placeholder = public_generer_boucle_placeholder($id_boucle, $boucles[$id_boucle], $boucle_placeholder, $ligne_suite - $ligne_debut_texte);
+		$placeholder = public_placeholder_generer($id_boucle, $boucles[$id_boucle], $boucle_placeholder, $ligne_suite - $ligne_debut_texte, true);
 		$longueur_boucle = $pos_courante - $boucle['debut_boucle'];
 		$texte = substr_replace($texte, $placeholder, $boucle['debut_boucle'], $longueur_boucle);
 		$pos_courante = $pos_courante - $longueur_boucle + strlen($placeholder);
