@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-revisions?lang_cible=en
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// R
 	'revisions_description' => 'Tracking changes of editorial objects',
-	'revisions_slogan' => 'Tracking changes of editorial objects'
-);
+	'revisions_slogan' => 'Tracking changes of editorial objects',
+];
