@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-revisions?lang_cible=fr_fem
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// R
 	'revisions_description' => 'Suivi des modifications des objets éditoriaux',
-	'revisions_slogan' => 'Suivi des modifications des objets éditoriaux'
-);
+	'revisions_slogan' => 'Suivi des modifications des objets éditoriaux',
+];
