@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-revisions?lang_cible=nl
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// R
 	'revisions_description' => 'De revisies van de editoriale objecten volgen', # Robert & Van Dale: revisie de (v.) 1 herziening - révision (v.) -  context: revisie van de drukproef, révision, correction de l'épreuve 2 periodieke controle - révision (v.) vérification (v.)  Vu la similarité avec le fr je opense que c'est le meilleur terme (Wijzigingen = changements, c'est pas pareil)
-	'revisions_slogan' => 'Revisies laat je toe de  veranderingen van de editorialen objecten zien en volgen.'
-);
+	'revisions_slogan' => 'Revisies laat je toe de  veranderingen van de editorialen objecten zien en volgen.',
+];
