@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=ast
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// D
 	'diff_para_ajoute' => 'Párrafu amestau',
@@ -24,5 +20,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 
 	// V
 	'version_deplace_rubrique' => 'Desasitiáo de <b>« @from@ »</b> pa <b>« @to@ »</b>.',
-	'version_initiale' => 'Versión d’entamu'
-);
+	'version_initiale' => 'Versión d’entamu',
+];
