@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=fon
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// D
 	'diff_para_ajoute' => 'gɔ wěkpaxwé ná',
@@ -23,5 +19,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_historique_titre' => 'mi zé ɖìdyɔ sín àfɔ ɖìɖè xlɛ',
 
 	// V
-	'version_initiale' => 'wàlɔ bìbɛ tɔn'
-);
+	'version_initiale' => 'wàlɔ bìbɛ tɔn',
+];
