@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=my
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// D
 	'diff_para_ajoute' => 'စာပိုဒ်ထပ်ဖြည့်ပါ',
@@ -23,5 +19,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_historique_titre' => 'ခြေရာပြန်ကောက်ကြည့်ရန်',
 
 	// V
-	'version_initiale' => 'မူကွဲအစ'
-);
+	'version_initiale' => 'မူကွဲအစ',
+];
