@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=oc_ni_la
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// D
 	'diff_para_ajoute' => 'Paragraf apondut',
@@ -23,5 +19,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_historique_titre' => 'Seguiment dei revisions',
 
 	// V
-	'version_initiale' => 'Version iniciala'
-);
+	'version_initiale' => 'Version iniciala',
+];
