@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=rn
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// D
 	'diff_para_ajoute' => 'Paragraphe ajouté',
@@ -15,5 +11,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'diff_para_supprime' => 'Paragraphe supprimé',
 	'diff_texte_ajoute' => 'Texte ajouté',
 	'diff_texte_deplace' => 'Texte déplacé',
-	'diff_texte_supprime' => 'Texte supprimé'
-);
+	'diff_texte_supprime' => 'Texte supprimé',
+];
