@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=tr
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// D
 	'diff_para_ajoute' => 'Eklenmiş paragraf ',
@@ -24,5 +20,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 
 	// V
 	'version_deplace_rubrique' => '<b>« @from@ »</b> den <b>« @to@ »</b> ye taşınmış.',
-	'version_initiale' => 'İlk sürüm'
-);
+	'version_initiale' => 'İlk sürüm',
+];
