@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=zh
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// D
 	'diff_para_ajoute' => '增加的段落',
@@ -23,5 +19,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_historique_titre' => '修订跟踪',
 
 	// V
-	'version_initiale' => '原版本'
-);
+	'version_initiale' => '原版本',
+];
