@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-safehtml?lang_cible=ar
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// S
 	'safehtml_description' => 'حماية المنتديات من هجمات من نوع الأوامرالعابرة للمواقع ',
-	'safehtml_slogan' => 'حماية المنتديات من الأوامرالعابرة للمواقع '
-);
+	'safehtml_slogan' => 'حماية المنتديات من الأوامرالعابرة للمواقع ',
+];
