@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-safehtml?lang_cible=eo
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// S
 	'safehtml_description' => 'Ŝirmilo por la forumoj kontraŭ transreteja atakoj',
-	'safehtml_slogan' => 'Ŝirmilo por la forumoj kontraŭ transreteja atakoj'
-);
+	'safehtml_slogan' => 'Ŝirmilo por la forumoj kontraŭ transreteja atakoj',
+];
