@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-safehtml?lang_cible=pt_br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// S
 	'safehtml_description' => 'Proteção dos foruns contra ataques do tipo cross-site scripting',
-	'safehtml_slogan' => 'Proteção dos foruns contra cross-site scripting'
-);
+	'safehtml_slogan' => 'Proteção dos foruns contra cross-site scripting',
+];
