@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-sites?lang_cible=br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// S
 	'sites_description' => 'Lec’hioù ha sindikadur e SPIP (prevez ha publik)',
-	'sites_slogan' => 'Merañ al lec’hioù ha sindikadur e SPIP'
-);
+	'sites_slogan' => 'Merañ al lec’hioù ha sindikadur e SPIP',
+];
