@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-sites?lang_cible=de
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// S
 	'sites_description' => 'Verwaltung verlinkter und syndizierter Websites mit  SPIP (im öffentlichen und Redaktionsbereich)',
-	'sites_slogan' => 'Verwaltung verlinkter und syndizierter Websites mit  SPIP'
-);
+	'sites_slogan' => 'Verwaltung verlinkter und syndizierter Websites mit  SPIP',
+];
