@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-sites?lang_cible=eo
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// S
 	'sites_description' => 'Retejoj kaj abonrilato en SPIP (privata kaj publika)',
-	'sites_slogan' => 'Mastrumado de retejoj kaj de abonrilato en SPIP'
-);
+	'sites_slogan' => 'Mastrumado de retejoj kaj de abonrilato en SPIP',
+];
