@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-sites?lang_cible=es
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// S
 	'sites_description' => 'Sitios y sindicación en SPIP (privado y público)',
-	'sites_slogan' => 'Administración de los sitios y de la sindicación en SPIP'
-);
+	'sites_slogan' => 'Administración de los sitios y de la sindicación en SPIP',
+];
