@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-sites?lang_cible=fa
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// S
 	'sites_description' => 'سايت‌ها و مشترك‌سازي‌ها در اسپسپ (خصوصي و همگاني)',
-	'sites_slogan' => 'مديريت سايت‌ها و مشترك‌سازي در اسپيپ'
-);
+	'sites_slogan' => 'مديريت سايت‌ها و مشترك‌سازي در اسپيپ',
+];
