@@ -1,13 +1,10 @@
 <?php
 // This is a SPIP language file  --  Ceci est un fichier langue de SPIP
 // Fichier source, a modifier dans https://git.spip.net/spip/sites.git
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
 
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// S
 	'sites_description' => 'Sites et syndication dans SPIP (privé et public)',
-	'sites_slogan' => 'Gestion des sites et de la syndication dans SPIP'
-);
+	'sites_slogan' => 'Gestion des sites et de la syndication dans SPIP',
+];
