@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-sites?lang_cible=fr_fem
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// S
 	'sites_description' => 'Sites et syndication dans SPIP (privé et public)',
-	'sites_slogan' => 'Gestion des sites et de la syndication dans SPIP'
-);
+	'sites_slogan' => 'Gestion des sites et de la syndication dans SPIP',
+];
