@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-sites?lang_cible=it
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// S
 	'sites_description' => 'Siti e syndication in SPIP (privato e pubblica)',
-	'sites_slogan' => 'Gestione dei siti e syndication in SPIP'
-);
+	'sites_slogan' => 'Gestione dei siti e syndication in SPIP',
+];
