@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-sites?lang_cible=pt
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// S
 	'sites_description' => 'Sítios e vinculação em SPIP (privado e público)',
-	'sites_slogan' => 'Gestão dos sítios e da vinculação em SPIP'
-);
+	'sites_slogan' => 'Gestão dos sítios e da vinculação em SPIP',
+];
