@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=ar
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'articles_dispo' => 'بالانتظار',
@@ -156,5 +152,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'tout_voir' => 'عرض كل المقالات المرخصة',
 
 	// U
-	'un_article_syndic' => 'مقال مرخص واحد'
-);
+	'un_article_syndic' => 'مقال مرخص واحد',
+];
