@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=hac
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'avis_echec_syndication_01' => 'ارتباط با سايتهاى ديگر برقرار نشد : يا فايل بك اند نا خوانا ست يا هيچ مقاله اى ندارد',
@@ -27,5 +23,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_site_refuse' => 'سايت پذيرفته نشده',
 	'info_sites_referencer' => 'ارجاع يك سايت',
 	'info_syndication' => ':هامبەشکەردەی',
-	'info_syndication_articles' => 'بابەت(ی)'
-);
+	'info_syndication_articles' => 'بابەت(ی)',
+];
