@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=pt
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'articles_dispo' => 'Em espera',
@@ -157,5 +153,5 @@ a partir do seu sítio.</i></blockquote>',
 	'tout_voir' => 'Ver todos os artigos vinculados',
 
 	// U
-	'un_article_syndic' => '1 artigo vinculado'
-);
+	'un_article_syndic' => '1 artigo vinculado',
+];
