@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=pt_br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'articles_dispo' => 'Na fila',
@@ -154,5 +150,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'tout_voir' => 'Ver todas as matérias sindicadas',
 
 	// U
-	'un_article_syndic' => '1 matéria sindicada'
-);
+	'un_article_syndic' => '1 matéria sindicada',
+];
