@@ -24,8 +24,8 @@ class SyndicsMaj extends Command
 		include_spip('genie/syndic');
 
 		if ($input->getOption('id')) {
-			$this->io->care('Mise à jour RSS site ' . $input);
-			syndic_a_jour($input);
+			$this->io->care('Mise à jour RSS site ' . $input->getOption('id'));
+			syndic_a_jour($input->getOption('id'));
 			$this->io->check('done');
 		} else {
 			$syndics = sql_allfetsel('id_syndic', 'spip_syndic', 'syndication = "oui"');
