@@ -121,16 +121,12 @@ function analyser_backend($rss, $url_syndic = '') {
 	$langue_du_site = '';
 
 	if (
-		(preg_match(
-			',<([^>]*xml:)?lang(uage)?' . '>([^<>]+)<,i',
-			$header,
-			$match
-		) and $l = $match[3])
-		or ($l = extraire_attribut(extraire_balise($header, 'feed'), 'xml:lang'))
+		preg_match(',<([^>]*xml:)?lang(uage)?' . '>([^<>]+)<,i', $header, $match) && ($l = $match[3])
+		|| ($l = extraire_attribut(extraire_balise($header, 'feed'), 'xml:lang'))
 	) {
 		$langue_du_site = $l;
-	} // atom
-	elseif (preg_match(',<feed\s[^>]*xml:lang=[\'"]([^<>\'"]+)[\'"],i', $header, $match)) {
+	} elseif (preg_match(',<feed\s[^>]*xml:lang=[\'"]([^<>\'"]+)[\'"],i', $header, $match)) {
+		// atom
 		$langue_du_site = $match[1];
 	}
 
@@ -231,17 +227,17 @@ function analyser_backend($rss, $url_syndic = '') {
 		}
 
 		// Titre (semi-obligatoire)
+		$data['titre'] = '';
 		if (preg_match(',<title[^>]*>(.*?)</title>,ims', $item, $match)) {
-			$data['titre'] = $match[1];
-		} else {
-			if (
-				preg_match(',<link[[:space:]][^>]*>,Uims', $item, $mat)
-				and $title = extraire_attribut($mat[0], 'title')
-			) {
-				$data['titre'] = $title;
+			$data['titre'] = trim($match[1]);
+		} elseif (preg_match(',<link[[:space:]][^>]*>,Uims', $item, $mat)) {
+			$title = extraire_attribut($mat[0], 'title');
+			if ($title) {
+				$data['titre'] = trim($title);
 			}
 		}
-		if (!strlen($data['titre'] = trim($data['titre']))) {
+
+		if ($data['titre'] === '') {
 			$data['titre'] = _T('ecrire:info_sans_titre');
 		}
 
