@@ -3,14 +3,10 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-stats?lang_cible=de
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// S
 	'stats_description' => 'SPIP Statistiken',
 	'stats_nom' => 'Statistiken',
-	'stats_slogan' => 'Verwlatung der SPIIP-Statistiken'
-);
+	'stats_slogan' => 'Verwlatung der SPIIP-Statistiken',
+];
