@@ -3,14 +3,10 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-stats?lang_cible=es
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// S
 	'stats_description' => 'Estadísticas de SPIP',
 	'stats_nom' => 'Estadísticas',
-	'stats_slogan' => 'Administración de las estadísticas de SPIP'
-);
+	'stats_slogan' => 'Administración de las estadísticas de SPIP',
+];
