@@ -1,14 +1,11 @@
 <?php
 // This is a SPIP language file  --  Ceci est un fichier langue de SPIP
 // Fichier source, a modifier dans https://git.spip.net/spip/statistiques.git
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
 
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// S
 	'stats_description' => 'Statistiques de SPIP',
 	'stats_nom' => 'Statistiques',
-	'stats_slogan' => 'Gestion des statistiques dans SPIP'
-);
+	'stats_slogan' => 'Gestion des statistiques dans SPIP',
+];
