@@ -3,14 +3,10 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-stats?lang_cible=nl
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// S
 	'stats_description' => 'Statistieken van SPIP',
 	'stats_nom' => 'Statistieken',
-	'stats_slogan' => 'Beheer van de bezoekenstatistieken in SPIP'
-);
+	'stats_slogan' => 'Beheer van de bezoekenstatistieken in SPIP',
+];
