@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// B
 	'bouton_effacer_statistiques' => 'Diverkañ ar stadegoù', # MODIF
@@ -45,5 +41,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'titre_evolution_visite' => 'Emdroadur ar gweladennoù',
 	'titre_liens_entrants' => 'Liammoù davet al lec’hienn',
 	'titre_page_statistiques' => 'Stadegoù dre rubrikennoù',
-	'titre_page_statistiques_visites' => 'Stadegoù gweladenniñ'
-);
+	'titre_page_statistiques_visites' => 'Stadegoù gweladenniñ',
+];
