@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=hac
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// I
 	'icone_repartition_actuelle' => 'نمايش توزيع كنونى',
@@ -26,5 +22,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'resume' => 'Resume', # MODIF
 
 	// T
-	'titre_liens_entrants' => 'به‌سته‌رى لڤایچووه‌ری'
-);
+	'titre_liens_entrants' => 'به‌سته‌رى لڤایچووه‌ری',
+];
