@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=he
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// B
 	'bouton_effacer_statistiques' => 'מחק סטטיסטיקות', # MODIF
@@ -36,5 +32,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'resume' => 'Resume', # MODIF
 
 	// T
-	'titre_liens_entrants' => 'קישורים נכנסים'
-);
+	'titre_liens_entrants' => 'קישורים נכנסים',
+];
