@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=it_fem
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// B
 	'bouton_effacer_statistiques' => 'Cancellare le statistiche', # MODIF
@@ -51,5 +47,5 @@ quando si passa con il mouse sopra al titolo.',
 	'titre_evolution_visite' => 'Evoluzione delle visite',
 	'titre_liens_entrants' => 'I link odierni al tuo sito',
 	'titre_page_statistiques' => 'Statistiche per rubrica',
-	'titre_page_statistiques_visites' => 'Statistiche delle visite'
-);
+	'titre_page_statistiques_visites' => 'Statistiche delle visite',
+];
