@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=no
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// B
 	'bouton_effacer_statistiques' => 'Delete the statistics', # MODIF
@@ -18,5 +14,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'item_gerer_statistiques' => ' Gérer les statistiques',
 
 	// R
-	'resume' => 'Resume' # MODIF
-);
+	'resume' => 'Resume', # MODIF
+];
