@@ -3,20 +3,17 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=pt_br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
+	'admin_conseil_sauvegarde' => 'É recomendável fazer um backup prévio da base de dados.',
+	'admin_description' => 'Esta página oferece ferramentas para limpar, arquivar ou excluir as estatísticas do site.',
+	'admin_operations_irreversibles' => 'Estas operações são irreversíveis!',
 	'archiver' => 'Arquivar',
 	'archiver_concatener_explications' => 'Esta operação vai concatenar as estatísticas de visitasção das matérias',
 	'archiver_concatener_ignorer' => 'As visitas com menos de @nb@ anos N#ao serão alteradas.',
 	'archiver_concatener_par_an' => 'As visitas com mais de @nb@ anos serão concatenadas, para cada matéria, no primeiro dia do ano.',
 	'archiver_concatener_par_mois' => 'As visitas com mais de @nb@ anos serão concatenadas, para cada matéria, no primeiro dia de cada mês.',
-	'archiver_conseil_sauvegarde' => 'É recomendável fazer um backup prévio da base de dados.',
-	'archiver_description' => 'Esta página fornece as ferramentas para limpar ou arquivar as estat’isticas do site.',
 	'archiver_et_nettoyer' => 'Arquivar e limpar',
 	'archiver_nettoyer' => 'Limpar',
 	'archiver_nettoyer_explications' => 'Remove as linhas dos "referenciadores" ou das "visitas" das matérias que não existem (mais) na base de dados.',
@@ -24,7 +21,6 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'archiver_nettoyer_visites_articles' => 'Limpar visites_articles',
 	'archiver_nombre_lignes' => 'Número de linhas',
 	'archiver_operation_longue' => 'Esta operação pode ser muito demorada, especialmente na primeira execução.',
-	'archiver_operations_irreversibles' => 'Estas operações são irreversíveis!',
 
 	// B
 	'bouton_effacer_referers' => 'Apagar somente os links de entrada',
@@ -94,5 +90,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'visites_annuelles' => 'Número de visitas por ano',
 	'visites_hebdomadaires' => 'Número de visitas por semana',
 	'visites_journalieres' => 'Número de visitas por dia',
-	'visites_mensuelles' => 'Número de visitas por mês'
-);
+	'visites_mensuelles' => 'Número de visitas por mês',
+];
