@@ -123,8 +123,9 @@ function public_stats_dist($contexte = null, $referer = null) {
 	}
 
 	// 2. Plafonner le nombre de hits pris en compte pour un IP (robots etc.)
+	// un visiteur identifié avec un id_auteur non nul n'est jamais considéré comme flooder ici
 	// et ecrire la session
-	if (count($content) < 200) {
+	if (count($content) < 200 || !empty($GLOBALS['visiteur_session']['id_auteur'])) {
 		// Identification de l'element
 		if (isset($contexte['id_article'])) {
 			$log_type = 'article';
