@@ -26,7 +26,7 @@ if (!defined('_SVP_VERSION_SPIP_MAX')) {
 	 * Version SPIP maximale
 	 *
 	 * Pour l'instant on ne connait pas la borne sup exacte */
-	define('_SVP_VERSION_SPIP_MAX', '4.3.999');
+	define('_SVP_VERSION_SPIP_MAX', '4.4.999');
 }
 
 /**
@@ -47,7 +47,8 @@ $GLOBALS['infos_branches_spip'] = [
 	'4.0' => ['4.0.0-alpha', '4.0.999'],
 	'4.1' => ['4.1.0-alpha', '4.1.999'],
 	'4.2' => ['4.2.0-alpha', '4.2.999'],
-	'4.3' => ['4.3.0-alpha', _SVP_VERSION_SPIP_MAX],
+	'4.3' => ['4.3.0-alpha', '4.3.999'],
+	'4.4' => ['4.4.0-beta', _SVP_VERSION_SPIP_MAX],
 ];
 
 /**
