@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-svp?lang_cible=en
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// S
 	'svp_description' => 'On one hand, this plugin provides an API to perform multi-criteria searches, to collect and present information on SPIP plugins (functional modules, themes, and skeletons) and on the other hand, proposes a new administration interface to manage the dependencies between plugins.',
-	'svp_slogan' => 'Information and download server of plugins'
-);
+	'svp_slogan' => 'Information and download server of plugins',
+];
