@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-svp?lang_cible=eo
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// S
 	'svp_description' => 'Tiu kromprogramo disponigas, unue, API-on ebligante plurkriterie serĉi, kolekti kaj prezenti informojn pri SPIP-kromprogramoj (funkciaj, aspektaj kaj skeletaj), kaj, due, nova interfacon de mastrumado de kromprogramoj, kiu zorgas pri la dependeco inter la kromprogramoj.',
-	'svp_slogan' => 'SerVilo pri Informo kaj elŝuto de kromProgramoj'
-);
+	'svp_slogan' => 'SerVilo pri Informo kaj elŝuto de kromProgramoj',
+];
