@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-svp?lang_cible=it
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// S
 	'svp_description' => 'Da un lato, questo plugin fornisce un’API per eseguire ricerche multi-criteri, per raccogliere e presentare informazioni su SPIP plugin (moduli funzionali, temi e scheletri) e, dall’altro, propone una nuova interfaccia di amministrazione per gestire le dipendenze tra i plugin.',
-	'svp_slogan' => 'Informazioni e server per il download dei plugin'
-);
+	'svp_slogan' => 'Informazioni e server per il download dei plugin',
+];
