@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/svp?lang_cible=fr_fem
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'action_patienter' => 'Les actions sont en cours de traitement. Veuillez patienter…',
@@ -125,7 +121,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_contributions_hebergees' => '@total_autres@ autre(s) contribution(s) hébergée(s)',
 	'info_critere_phrase' => 'Saisissez les mots-clés à chercher dans le préfixe, le nom, le slogan, la description et les auteurs des plugins',
 	'info_depots_disponibles' => '@total_depots@ dépôt(s)',
-	'info_fichier_depot' => 'Saisissez l’url du fichier de description du dépôt à ajouter.<br />Pour ajouter le dépôt « SPIP-Zone - Plugins » cliquez sur ce lien : ',
+	'info_fichier_depot' => 'Saisissez l’url du fichier de description du dépôt à ajouter.<br />Pour ajouter le dépôt « SPIP-Zone - Plugins » cliquez sur ce lien : ', # MODIF
 	'info_logiciel_version' => '@logiciel@ @signe@ @version@',
 	'info_logiciel_version_intervalle' => '@logiciel@ @signe_min@ @version_min@ et @signe_max@ @version_max@',
 	'info_nb_depots' => '@nb@ dépôts',
@@ -290,5 +286,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'titre_plugins' => 'Plugins',
 	'tout_cocher' => 'Tout cocher',
 	'tout_cocher_up' => 'Cocher les mises à jour',
-	'tout_decocher' => 'Tout décocher'
-);
+	'tout_decocher' => 'Tout décocher',
+];
