@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/svp?lang_cible=fr_tu
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'action_patienter' => 'Les actions sont en cours de traitement. Patience…',
@@ -89,6 +85,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'etat_obsolete' => 'Obsolète',
 	'etat_verrouille' => 'Verrouillé',
 	'explication_destination' => 'Le chemin sera calculé depuis le nom de l’archive si tu ne le remplis pas.',
+	'explication_mot_passe' => 'Saisis ton mot de passe pour sécuriser l’installation',
 
 	// F
 	'fieldset_debug' => 'Débug',
@@ -125,7 +122,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_contributions_hebergees' => '@total_autres@ autre(s) contribution(s) hébergée(s)',
 	'info_critere_phrase' => 'Saisis les mots-clés à chercher dans le préfixe, le nom, le slogan, la description et les auteurs des plugins',
 	'info_depots_disponibles' => '@total_depots@ dépôt(s)',
-	'info_fichier_depot' => 'Saisis l’url du fichier de description du dépôt à ajouter.<br />Pour ajouter le dépôt « SPIP-Zone - Plugins » clique sur ce lien : ',
+	'info_fichier_depot' => 'Saisis l’url du fichier de description du dépôt à ajouter.<br />Pour ajouter le dépôt « git.spip.net - extensions » clique sur ce lien : ',
 	'info_logiciel_version' => '@logiciel@ @signe@ @version@',
 	'info_logiciel_version_intervalle' => '@logiciel@ @signe_min@ @version_min@ et @signe_max@ @version_max@',
 	'info_nb_depots' => '@nb@ dépôts',
@@ -290,5 +287,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'titre_plugins' => 'Plugins',
 	'tout_cocher' => 'Tout cocher',
 	'tout_cocher_up' => 'Cocher les mises à jour',
-	'tout_decocher' => 'Tout décocher'
-);
+	'tout_decocher' => 'Tout décocher',
+];
