@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/svp?lang_cible=it
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'action_patienter' => 'Le azioni sono in corso di esecuzione. Attendere prego ...',
@@ -89,6 +85,7 @@ Devi confermare questa azione.',
 	'etat_verrouille' => 'Bloccato',
 	'explication_destination' => 'Il percorso calcolato dal nome delle archivio se non viene compilato.
 ',
+	'explication_mot_passe' => 'Inserisci la tua password per proteggere l’installazione',
 
 	// F
 	'fieldset_debug' => 'Debug',
@@ -123,7 +120,7 @@ Se vuoi disabilitarla, per favore contatta il webmaster del sito oppure controll
 	'info_contributions_hebergees' => '@total_autres@ contributi da altri host',
 	'info_critere_phrase' => 'Inserire le parole chiave per cercare nei prefissi, nel nome, lo slogan, la descrizione e gli autori del plugin.',
 	'info_depots_disponibles' => '@total_depots@ repository',
-	'info_fichier_depot' => 'Digita nell’url del file di descrizione del repository da aggiungere.<br />Per aggiungere il repository «SPIP-Zone - Plugins» cliccate su questo link: ',
+	'info_fichier_depot' => 'Digita nell’url del file di descrizione del repository da aggiungere.<br />Per aggiungere il repository «SPIP-Zone - Plugins» cliccate su questo link: ', # MODIF
 	'info_logiciel_version' => '@logiciel@ @signe@ @version@',
 	'info_logiciel_version_intervalle' => '@logiciel@ @signe_min@ @version_min@ e @signe_max@ @version_max@',
 	'info_nb_depots' => '@nb@ repository',
@@ -287,5 +284,5 @@ Se vuoi disabilitarla, per favore contatta il webmaster del sito oppure controll
 	'titre_plugins' => 'Plugin',
 	'tout_cocher' => 'Controlla tutto',
 	'tout_cocher_up' => 'Controlla per aggiornamenti',
-	'tout_decocher' => 'Deseleziona tutto'
-);
+	'tout_decocher' => 'Deseleziona tutto',
+];
