@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/svp?lang_cible=sk
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'action_patienter' => 'Vykonávajú sa akcie. Prosím, počkajte.',
@@ -132,7 +128,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_contributions_hebergees' => '@total_autres@ iný(ch) príspevok (-kov) na serveri',
 	'info_critere_phrase' => 'Zadajte kľúčové slová, ktoré sa majú vyhľadávať v predpone, názve, slogane, opise a menách autorov zásuvných modulov',
 	'info_depots_disponibles' => '@total_depots@ depozitár(ov/e)',
-	'info_fichier_depot' => 'Zadajte adresu súboru s opisom depozitára, ktorý sa má pridať.<br />Ak chcete pridať depozitár "SPIP-Zone – Plugins", kliknite na tento odkaz: ',
+	'info_fichier_depot' => 'Zadajte adresu súboru s opisom depozitára, ktorý sa má pridať.<br />Ak chcete pridať depozitár "SPIP-Zone – Plugins", kliknite na tento odkaz: ', # MODIF
 	'info_logiciel_version' => '@logiciel@ @signe@ @version@',
 	'info_logiciel_version_intervalle' => '@logiciel@ @signe_min@ @version_min@ a @signe_max@ @version_max@',
 	'info_nb_depots' => '@nb@ depozitárov',
@@ -291,5 +287,5 @@ alebo vytvoriť tento priečinok a nastaviť mu povolenie na zápis.',
 	'titre_plugins' => 'Zásuvné moduly',
 	'tout_cocher' => 'Označiť všetky',
 	'tout_cocher_up' => 'Vyhľadať aktualizácie',
-	'tout_decocher' => 'Odznačiť všetky'
-);
+	'tout_decocher' => 'Odznačiť všetky',
+];
