@@ -22,6 +22,13 @@ return [
 	'bouton_activer' => 'Увімкнути',
 	'bouton_actualiser' => 'Поновити',
 	'bouton_actualiser_tout' => 'Поновити репозиторії',
+	'bouton_afficher' => 'Показати',
+	'bouton_afficher_plugins_coches' => 'Вибрані плагіни',
+	'bouton_afficher_plugins_forces' => 'Плагіни в режимі сумісності',
+	'bouton_afficher_plugins_incompatibles' => 'Несумісні плагіни',
+	'bouton_afficher_plugins_maj' => 'Плагіни, для яких є оновленння',
+	'bouton_afficher_plugins_tout' => 'Всі плагіни',
+	'bouton_annuler_filtres' => 'Очистити фільтри',
 	'bouton_appliquer' => 'Застосувати',
 	'bouton_configurer' => 'Налаштування',
 	'bouton_confirmer' => 'Підтвердити',
@@ -81,6 +88,7 @@ return [
 	'etat_obsolete' => 'Застарілий',
 	'etat_verrouille' => 'Заблокований',
 	'explication_destination' => 'Якщо ви не заповните, то шлях буде задано за ім’ям архівного файлу.',
+	'explication_mot_passe' => 'Введіть свій пароль',
 
 	// F
 	'fieldset_debug' => 'Налагодження',
@@ -115,7 +123,7 @@ repertoire_plugins_dist">документації</a>.',
 	'info_contributions_hebergees' => '@total_autres@ інших розробок',
 	'info_critere_phrase' => 'Задайте слово для пошуку в назві, описі, слогані, префіксі або серед імен розробників плагінів.',
 	'info_depots_disponibles' => '@total_depots@ репозиторіїв',
-	'info_fichier_depot' => 'Вкажіть посилання на XML-файл репозиторія. <br />Аби додати репозиторій  „Плагіни SPIP-Zone” просто натисніть на посилання: ', # MODIF
+	'info_fichier_depot' => 'Вкажіть посилання на XML-файл репозиторія. <br />Щоб додати репозиторій „git.spip.net - extensions” просто натисніть на посилання: ',
 	'info_logiciel_version' => '@logiciel@ @signe@ @version@',
 	'info_logiciel_version_intervalle' => '@logiciel@ @signe_min@ @version_min@ і @signe_max@ @version_max@',
 	'info_nb_depots' => '@nb@ репозиторіїв',
