@@ -1,9 +1,15 @@
 <?php
 
 // Les URLs brutes sont converties en <a href='url'>url</a>
-function tw_autoliens($t) {
+function tw_autoliens(?string $t): string {
 
-	defined('_EXTRAIRE_LIENS') || define('_EXTRAIRE_LIENS', ',' . '\[[^\[\]]*(?:<-|->).*?\]' . '|<a\b.*?</a\b' . '|<\w.*?>' . '|((?:https?:/|www\.)[^"\'\s\[\]\}\)<>]*)' . ',imsS');
+	if (!defined('_EXTRAIRE_LIENS')) {
+		define('_EXTRAIRE_LIENS', ',' . '\[[^\[\]]*(?:<-|->).*?\]' . '|<a\b.*?</a\b' . '|<\w.*?>' . '|((?:https?:/|www\.)[^"\'\s\[\]\}\)<>]*)' . ',imsS');
+	}
+
+	if ($t === null) {
+		return '';
+	}
 
 	$t = preg_replace_callback(_EXTRAIRE_LIENS, 'tw_traiter_autoliens', $t);
 
