@@ -213,6 +213,12 @@ function typo($letexte, $echapper = true, $connect = null, $env = []) {
 	if (!$letexte and (!is_scalar($letexte) or !strlen((string)$letexte))) {
 		return '';
 	}
+	// si $env['lang'] est renseigné il faut l'ignorer car il correspond au env du squelette appelant
+	// mais pas forcément à l'endroit où on a appelé propre.
+	// C'est la globales spip_lang qui fait foi
+	if (isset($env['lang'])) {
+		unset($env['lang']);
+	}
 
 	// les appels directs a cette fonction depuis le php de l'espace
 	// prive etant historiquement ecrit sans argment $connect
@@ -825,6 +831,12 @@ function propre($t, $connect = null, $env = []) {
 	static $wheel;
 
 	$args = func_get_args();
+	// si $env['lang'] est renseigné il faut l'ignorer car il correspond au env du squelette appelant
+	// mais pas forcément à l'endroit où on a appelé propre.
+	// C'est la globales spip_lang qui fait foi
+	if (isset($env['lang'])) {
+		unset($env['lang']);
+	}
 
 	// les appels directs a cette fonction depuis le php de l'espace
 	// prive etant historiquement ecrits sans argment $connect
@@ -983,4 +995,4 @@ function safe_public_traiter_echap_code_dist($regs, $options) {
 		return $html;
 	}
 	return '';
-}
+}
\ No newline at end of file
