@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-tw?lang_cible=ar
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// T
 	'tw_description' => 'دمج TextWheel في SPIP',
-	'tw_slogan' => 'إدارة الكتابة في SPIP بواسطة TextWheel'
-);
+	'tw_slogan' => 'إدارة الكتابة في SPIP بواسطة TextWheel',
+];
