@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-tw?lang_cible=de
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// T
 	'tw_description' => 'Integration von TextWheel in SPIP',
-	'tw_slogan' => 'Typographie in SPIP mit TextWheel steuern'
-);
+	'tw_slogan' => 'Typographie in SPIP mit TextWheel steuern',
+];
