@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-tw?lang_cible=fr_fem
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// T
 	'tw_description' => 'Intégrer TextWheel dans SPIP',
-	'tw_slogan' => 'Gestion de la typographie SPIP avec TextWheel'
-);
+	'tw_slogan' => 'Gestion de la typographie SPIP avec TextWheel',
+];
