@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-tw?lang_cible=oc_ni_mis
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// T
 	'tw_description' => 'Integrà TextWheel en SPIP',
-	'tw_slogan' => 'Gestioun de la tipougrafìa SPIP embé TextWheel'
-);
+	'tw_slogan' => 'Gestioun de la tipougrafìa SPIP embé TextWheel',
+];
