@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-tw?lang_cible=ru
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// T
 	'tw_description' => 'Интегрировать TextWheel в SPIP',
-	'tw_slogan' => 'Управлять оформлением SPIP c помощью TextWheel'
-);
+	'tw_slogan' => 'Управлять оформлением SPIP c помощью TextWheel',
+];
