@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-tw?lang_cible=sk
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// T
 	'tw_description' => 'Integrovať TextWheel do SPIPu',
-	'tw_slogan' => 'Správa typografie SPIPu s modulom TextWheel'
-);
+	'tw_slogan' => 'Správa typografie SPIPu s modulom TextWheel',
+];
