@@ -1,14 +1,11 @@
 <?php
 // This is a SPIP language file  --  Ceci est un fichier langue de SPIP
 // Fichier source, a modifier dans https://git.spip.net/spip/textwheel.git
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
 
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// R
 	'retour_ligne_auto' => 'Retour ligne automatique',
 	'retour_ligne_ignore' => 'Retour ligne ignoré',
-	'retour_ligne_manuel' => 'Retour ligne manuel'
-);
+	'retour_ligne_manuel' => 'Retour ligne manuel',
+];
