@@ -91,28 +91,6 @@ class TextwheelPropreTest extends TestCase {
 		$this->assertEquals($expected, static::propreNotes($source));
 	}
 
-	/**
-	 * Provider pour propre() sur du texte avec des raccourcis math
-	 * @return array
-	 */
-	public function providerPropreMath() {
-		return static::providerData('math');
-	}
-
-	/**
-	 * @dataProvider providerPropreMath
-	 */
-	public function testPropreMath($source, $expected) {
-
-		$result = static::propreNotes($source);
-
-		// on ignore width et height qui dependent de la police utilisee sur le serveur
-		$expected = preg_replace(',(width|height)="\d+",','', $expected);
-		$result = preg_replace(',(width|height)="\d+",','', $result);
-
-		$this->assertEquals($expected, $result);
-	}
-
 
 	/**
 	 * Provider pour propre() sur du modeles de type block
@@ -152,4 +130,4 @@ class TextwheelPropreTest extends TestCase {
 		$GLOBALS['class_spip_plus'] = static::$class_spip_plus;
 		$GLOBALS['class_spip'] = static::$class_spip;
 	}
-}
+}
\ No newline at end of file
