@@ -270,11 +270,14 @@ function url_insert(&$set, $confirmer, $separateur) {
 
 	// si url perma, poser le flag sur la seule url qu'on vient de mettre (au sein de celles qui ont la meme langue)
 	if ($perma) {
-		sql_update(
+		$res = sql_update(
 			'spip_urls',
 			['perma' => "($where_thisurl)"],
 			'type=' . sql_quote($set['type']) . ' AND id_objet=' . intval($set['id_objet']) . ' AND langue=' . sql_quote($set['langue'])
 		);
+		if (false !== $res) {
+			ecrire_meta('cache_bot_invalide', time());
+		}
 	}
 
 	spip_log("Creation de l'url propre '" . $set['url'] . "' pour "
