@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-urls?lang_cible=br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// U
 	'urls_description' => 'Merañ an adstummoù URL sklaer pe ket',
-	'urls_slogan' => 'Merañ an adstummoù URL sklaer pe ket'
-);
+	'urls_slogan' => 'Merañ an adstummoù URL sklaer pe ket',
+];
