@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-urls?lang_cible=es
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// U
 	'urls_description' => 'Gestión de las variantes de URL significativas o no',
-	'urls_slogan' => 'Gestión de las variantes de URL significativas o no'
-);
+	'urls_slogan' => 'Gestión de las variantes de URL significativas o no',
+];
