@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-urls?lang_cible=nl
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// U
 	'urls_description' => 'Beheer van de URL’s varianten (betekenisdragend of niet)  ',
-	'urls_slogan' => 'Beheer van de URL varianten (betekenisdragend of niet)'
-);
+	'urls_slogan' => 'Beheer van de URL varianten (betekenisdragend of niet)',
+];
