@@ -3,14 +3,10 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/urls?lang_cible=ast
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// T
 	'texte_type_urls' => 'Embaxo pues escoyer el mou de cálculu de les señes de les páxines.',
 	'texte_type_urls_attention' => 'Atención esti axuste nun funcionará más que si l’archivu @htaccess@ ta correutamente instaláu na raiz del sitiu.',
-	'titre_type_urls' => 'Tipu de señes URL'
-);
+	'titre_type_urls' => 'Tipu de señes URL',
+];
